package com.bcxin.sp.config.aspect;

import cn.hutool.core.date.DatePattern;
import cn.hutool.core.date.DateUtil;
import com.baomidou.mybatisplus.toolkit.IdWorker;
import com.bcxin.sp.config.annotation.AuditLogAn;
import com.bcxin.sp.work.dao.activity.base.ActivityMapper;
import com.bcxin.sp.work.dao.activity.history.ActivityHistoryMapper;
import com.bcxin.sp.work.dao.log.AuditLogMapper;
import com.bcxin.sp.work.entity.domain.activity.base.Activity;
import com.bcxin.sp.work.entity.domain.activity.history.ActivityHistory;
import com.bcxin.sp.work.entity.domain.log.AuditLog;
import com.bcxin.sp.work.entity.domain.user.LoginUserDetail;
import com.bcxin.sp.work.entity.dto.AjaxResult;
import com.bcxin.sp.work.util.Const.DictConst;
import com.bcxin.sp.work.util.Const.GlobalConst;
import com.bcxin.sp.work.util.HttpContextUtils;
import com.bcxin.sp.work.util.StringUtil;
import com.bcxin.sp.work.util.WebUtil;
import com.google.common.base.CharMatcher;
import com.google.common.collect.Lists;
import org.aspectj.lang.ProceedingJoinPoint;
import org.aspectj.lang.annotation.Around;
import org.aspectj.lang.annotation.Aspect;
import org.aspectj.lang.annotation.Pointcut;
import org.aspectj.lang.reflect.CodeSignature;
import org.aspectj.lang.reflect.MethodSignature;
import org.springframework.stereotype.Component;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;
import java.lang.reflect.Method;
import java.util.Enumeration;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * 操作日志切面
 */
@Aspect
@Component
public class AuditLogAspect {

    @Resource
    private AuditLogMapper auditLogMapper;

    @Resource
    private ActivityMapper activityMapper;

    @Resource
    private ActivityHistoryMapper activityHistoryMapper;

    private static List<String> ignoreParams = Lists.newArrayList("iSortCol_","sEcho"
            ,"bSortable_","sColumns","iColumns","dto","mDataProp_","iSortingCols"
            ,"iDisplayLength","iDisplayStart","sSortDir_","mDataProp_","_");

    @Pointcut("@annotation(com.bcxin.sp.config.annotation.AuditLogAn)")
    public void logPointCut() {
    }

    @Around("logPointCut()")
    public Object around(ProceedingJoinPoint point) {
        AuditLog auditLog = null;
        Object result = null;
        //保存日志
        HttpServletRequest request = HttpContextUtils.getHttpServletRequest();
        Object userObj = request.getSession().getAttribute(GlobalConst.LOGIN_USER_DETAIL);
        if (userObj == null) {
            return null;
        }
        try {
            //调用目标方法
            result = point.proceed();
            // 生成操作日志
            auditLog = createLog(point, userObj, DictConst.Y);
            // 是否ajax请求
            if (WebUtil.isAjaxRequest(request)) {
                if (result instanceof AjaxResult) {
                    AjaxResult ajaxResult = (AjaxResult) result;
                    if (ajaxResult.isSuccessful()) {
                        auditLog.setOperate_Result(DictConst.Y);
                    } else {
                        auditLog.setOperate_Result(DictConst.N);
                    }
                }
            }
        } catch (Throwable e) {
            e.printStackTrace();
            //保存日志
            auditLog = createLog(point, userObj, DictConst.N);
        }

        if (auditLog != null) {
            auditLogMapper.insert(auditLog);
        }
        return result;
    }

    /**
     * 生成操作日志
     *
     * @param point
     * @param result
     * @return
     */
    public AuditLog createLog(ProceedingJoinPoint point, Object userObj,String result) {
        MethodSignature signature = (MethodSignature) point.getSignature();
        Method method = signature.getMethod();
        AuditLogAn auditLogAn = method.getAnnotation(AuditLogAn.class);
        if (auditLogAn == null) {
            return null;
        }
        String menuName = auditLogAn.menuName();
        String[] menuNames = menuName.split("\\|");
        String menuOperation = "获取当前用户权限范围内的数据";
        if (menuNames.length > 1) {
            menuOperation = menuNames[1];
        }
        LoginUserDetail userDetail = (LoginUserDetail) userObj;
        AuditLog log = new AuditLog();
        Map<String,Object> paramMap = getParams(point);
        StringBuilder builder = new StringBuilder();
        builder.append("真实姓名=").append(userDetail.getUserName()).append(" and 身份证 = ").append(userDetail.getUserId())
                .append(" and 操作=").append(menuOperation).append(" ");

        if (paramMap.get("activityId")!= null) {
            String activityId = paramMap.get("activityId").toString();
            String fullName= "";
            if(menuName.contains("公安备案")){
                ActivityHistory activityHistory = activityHistoryMapper.selectById(Long.parseLong(activityId));
                fullName= activityHistory.getFullName();
            }else{
                try {
                    Activity activity = activityMapper.selectById(Long.parseLong(activityId));
                    fullName= activity.getFullName();
                }catch (Exception e){

                }
            }
            builder.append(" and 活动名称=").append(fullName).append(" and ");
        }

        for (String key:paramMap.keySet()) {
            if (paramMap.get(key) == null) {
                continue;
            }
            if (StringUtil.isEmpty(paramMap.get(key).toString())) {
                continue;
            }
            if (ignoreParams.contains(CharMatcher.DIGIT.removeFrom(key))) {
                continue;
            }
            builder.append(key).append("=").append(paramMap.get(key)).append(" and ");
        }
        String condition = null;
        if (builder.toString().endsWith("and ")) {
            condition = builder.substring(0,builder.toString().length()-5);
        } else {
            condition = "无";
        }


        log.setNum_ID(IdWorker.getId()+"");
        log.setOrganization(userDetail.getOrganization());
        log.setTerminal_ID(userDetail.getTerminalID());
        log.setUser_Name(userDetail.getUserName());
        log.setUser_ID(userDetail.getUserId());
        log.setOperate_Name(menuNames[0]);
        log.setOperate_Type(auditLogAn.operateType());
        log.setOperate_Time(DateUtil.format(DateUtil.date(), DatePattern.PURE_DATETIME_FORMAT) );
        log.setOperate_Condition(condition);
        log.setOperate_Result(result);

        return log;
    }


    /**
     * 获取参数
     * @param joinPoint
     * @return
     */
    public Map<String, Object> getParams(ProceedingJoinPoint joinPoint) {
        try {
            Object[] args = joinPoint.getArgs();
            String[] paramNames = ((CodeSignature) joinPoint.getSignature()).getParameterNames();

            Map<String, Object> map = new HashMap<>();
            for (int i = 0; i < paramNames.length; i++) {
                if (args[i] instanceof HttpServletRequest) {
                    HttpServletRequest req=(HttpServletRequest)args[i];
                    Enumeration<String> reqParams= req.getParameterNames();
                    while (reqParams.hasMoreElements()){
                        String key=reqParams.nextElement();
                        map.put(key, req.getParameter(key));
                    }
                    continue;
                }
                map.put(paramNames[i], args[i]);
            }
            return map;
        } catch (Exception e) {
            e.printStackTrace();
            return null;
        }
    }

    public static void main(String[] args) {
        System.out.println("活动管理-许可活动|获取当前用户可以审批的活动列表".split("\\|")[1]);
    }

}
