package com.bcxin.sp.config.filter;

import com.alibaba.fastjson.JSONObject;
import com.bcxin.sp.config.interceptor.XssHttpServletRequestWrapper;
import com.bcxin.sp.work.service.third.anbao.AnbaoUserService;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.stereotype.Component;

import javax.annotation.Resource;
import javax.servlet.*;
import javax.servlet.annotation.WebFilter;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import javax.servlet.http.HttpSession;
import java.io.IOException;

/**
 * CrosXss拦截过滤
 *
 * @author ZXF
 * @create 2022-07-28 16:00
 */
@WebFilter("/*")
@Component
public class CrosXssFilter implements Filter {

    @Resource
    private AnbaoUserService anbaoUserService;

    private static Logger logger = LoggerFactory.getLogger(CrosXssFilter.class);

    @Override
    public void doFilter(ServletRequest request, ServletResponse response, FilterChain chain) throws IOException, ServletException {
//        request.setCharacterEncoding("utf-8");
//        response.setContentType("text/html;charset=utf-8");
        HttpServletResponse httpResponse = (HttpServletResponse) response;
        //sql、xss过滤
        HttpServletRequest httpRequest = (HttpServletRequest) request;
        //跨域设置
        if(response instanceof HttpServletResponse){
            //通过在响应header中设置‘*’来允许来自所有域的跨域请求
//            httpResponse.setHeader("Access-Control-Allow-Origin","*");
            //设置请求方式
//            httpResponse.setHeader("Access-Control-Allow-Methods","*");
//            httpResponse.setHeader("Access-Control-Max-Age", "86400");
//            httpResponse.setHeader("Access-Control-Allow-Headers", "*");
            httpResponse.setHeader("Access-Control-Allow-Origin", "*");
            httpResponse.setHeader("Access-Control-Allow-Methods", "*");
            httpResponse.setHeader("Access-Control-Allow-Credentials", "true");
            httpResponse.setHeader("Access-Control-Allow-Headers",
                    "x-requested-with,content-type,Content-type,authorization,x-csrf-token,access_token");
            httpResponse.setHeader("Content-type", "application/x-www-form-urlencoded; charset=UTF-8");
        }

        String url = httpRequest.getServletPath().replace("/","");
        /*if(url.contains("font-awesomecss")){
            httpResponse.setStatus(HttpServletResponse.SC_FOUND);
            httpResponse.setHeader("Location", "https://in.test.pss360.cn");
            httpResponse.setHeader("Connection", "close");
        }*/
        XssHttpServletRequestWrapper xssHttpServletRequestWrapper = new XssHttpServletRequestWrapper(httpRequest);
        //是登录地址并且有携带token，属于安保单点业务走自建session
//        if(!httpRequest.getRequestURI().contains("login")&&httpRequest.getRequestURI().contains("thirdBusiness/anBao")){
//            String access_token = request.getParameter("access_token");
//            if(StringUtils.isNotEmpty(access_token)){
//                HttpSession session = httpRequest.getSession();
//                anbaoUserService.session(access_token,session);
//            }
//        }
        chain.doFilter(xssHttpServletRequestWrapper,httpResponse);
        logger.info("CrosXssFilter..........doFilter url:{},ParameterMap:{}",xssHttpServletRequestWrapper.getRequestURI(), JSONObject.toJSONString(xssHttpServletRequestWrapper.getParameterMap()));
    }

    @Override
    public void init(FilterConfig config) throws ServletException {

    }

    @Override
    public void destroy() {

    }

}
