package com.bcxin.sp.config.interceptor;

import com.bcxin.sp.work.util.Const.GlobalConst;
import com.bcxin.sp.work.util.sys.ConfigUtil;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;
import org.springframework.web.servlet.config.annotation.InterceptorRegistration;
import org.springframework.web.servlet.config.annotation.InterceptorRegistry;
import org.springframework.web.servlet.config.annotation.PathMatchConfigurer;
import org.springframework.web.servlet.config.annotation.WebMvcConfigurerAdapter;
import org.springframework.web.servlet.handler.HandlerInterceptorAdapter;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import javax.servlet.http.HttpSession;

/**
 *
 */
@Configuration
public class WebSecurityConfig extends WebMvcConfigurerAdapter {

    @Bean
    public SecurityInterceptor getSecurityInterceptor() {
        return new SecurityInterceptor();
    }

    /**
     * -设置url后缀模式匹配规则
     * -该设置匹配所有的后缀，使用.do或.action都可以
     */
    @Override
    public void configurePathMatch(PathMatchConfigurer configurer) {
        configurer.setUseSuffixPatternMatch(true)    //设置是否是后缀模式匹配,即:/test.*
                .setUseTrailingSlashMatch(true);    //设置是否自动后缀路径模式匹配,即：/test/
    }


    @Override
    public void addInterceptors(InterceptorRegistry registry) {
        InterceptorRegistration addInterceptor = registry.addInterceptor(getSecurityInterceptor());

        // 排除配置
//        addInterceptor.excludePathPatterns("/thirdBusiness/**");
//        addInterceptor.excludePathPatterns("/thirdBusiness/anBaoUser/login");
        addInterceptor.excludePathPatterns("/zj/sso**");
        addInterceptor.excludePathPatterns("/business/getRegion/**");
        addInterceptor.excludePathPatterns("/nx/even**");
        addInterceptor.excludePathPatterns("/error");
        addInterceptor.excludePathPatterns("/security/login**");
        addInterceptor.excludePathPatterns("/repair**");
        addInterceptor.excludePathPatterns("/static**");
        addInterceptor.excludePathPatterns("/getResource**");
        addInterceptor.excludePathPatterns("/tdtimg**");
        addInterceptor.excludePathPatterns("/communicate**");//用于内外网ftp摆渡

        addInterceptor.excludePathPatterns("/bim/**");


        // 拦截配置
        addInterceptor.addPathPatterns("/business/**","/operate/**");
    }

    /**
     * 登录拦截校验
     */
    private class SecurityInterceptor extends HandlerInterceptorAdapter {
        @Override
        public boolean preHandle(HttpServletRequest request, HttpServletResponse response, Object handler)
                throws Exception {
            HttpSession session = request.getSession();
            Object logUser = session.getAttribute(GlobalConst.LOGIN_USER);
            if (logUser != null) {
                return true;
            }
            System.out.println("=======> 没有用户状态----------------------------");
            // 跳转登录
            /* 浙江 */
            if (GlobalConst.ENVI_ZHEJIANG.equals(ConfigUtil.getValue("envi"))) {
                String url = "/security/login";
                response.sendRedirect(url);
                return false;
            }
            String url = "/security/login";
            response.sendRedirect(url);
            return false;
        }
    }
}