package com.bcxin.sp.work.controller.activity.approve;

import cn.hutool.core.date.DateUtil;
import com.alibaba.fastjson.JSON;
import com.bcxin.sp.config.annotation.AuditLogAn;
import com.bcxin.sp.work.controller.sys.BaseController;
import com.bcxin.sp.work.entity.domain.sys.ConfigApproveLimit;
import com.bcxin.sp.work.entity.domain.sys.Region;
import com.bcxin.sp.work.entity.dto.AjaxResult;
import com.bcxin.sp.work.entity.dto.SearchDto;
import com.bcxin.sp.work.service.sys.ConfigService;
import com.bcxin.sp.work.util.BcxinFileUtil;
import com.bcxin.sp.work.util.Const.DictConst;
import com.bcxin.sp.work.util.Const.GlobalConst;
import com.bcxin.sp.work.util.Const.MenuConst;
import com.bcxin.sp.work.util.DESUtil;
import com.bcxin.sp.work.util.StringUtil;
import com.bcxin.sp.work.util.sys.ConfigUtil;
import com.google.common.collect.Maps;
import com.google.common.io.Files;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.servlet.ModelAndView;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;
import java.io.File;
import java.util.List;
import java.util.Map;
import java.util.Objects;

/**
 * 活动人数审批流转管理
 */
@Controller
@RequestMapping("/business/approvelimit")
public class ApproveLimitController extends BaseController {

    @Resource
    private ConfigService configService;

    /**
     * 审批配置文件
     */
    private final static String SPCONFIG = "_spconfig_";

    /**
     * 同步审批结果文件夹名称
     */
    private final static String SPJG_FOLDER = "spjg";


    @RequestMapping("/list")
    public ModelAndView list(HttpServletRequest request) {
        return new ModelAndView("/sys/approvelimit");
    }

    @AuditLogAn(operateType = DictConst.OP_SELECT,menuName = MenuConst.XTPZ_SPGMPZ)
    @RequestMapping("findData")
    @ResponseBody
    public SearchDto<ConfigApproveLimit> findData(SearchDto<ConfigApproveLimit> dto){
        List<ConfigApproveLimit> list = configService.approveLimitList();
        SearchDto<ConfigApproveLimit> result = new SearchDto<ConfigApproveLimit>();
        result.setData(list);
        result.setIDisplayStart(dto.getIDisplayStart());
        result.setIDisplayLength(dto.getIDisplayLength());
        result.setITotalRecords(list.size());
        result.setITotalDisplayRecords(list.size());
        return result;
    }

    @RequestMapping("/findChildLimit/{regionid}")
    public @ResponseBody
    List<ConfigApproveLimit> findChildLimit(@PathVariable("regionid") long regionid) {
        return configService.findChildLimitByParentId(regionid);
    }

    @AuditLogAn(operateType = DictConst.OP_UPDATE,menuName = MenuConst.XTPZ_SPGMPZ_XGGM)
    @RequestMapping("update")
    @ResponseBody
    public AjaxResult update(@RequestParam long regionId, @RequestParam int approveLimit, @RequestParam String childLimits) {
        System.out.println(childLimits);
        configService.updateApproveLimit(regionId,approveLimit,childLimits);
        if (!String.valueOf(regionId).endsWith("0000")) {
            syncAreaLimitPerson(regionId + "_approve_limit_area", approveLimit + "");
        }
        AjaxResult result = new AjaxResult();
        result.setSuccessful(true);
        result.setMsg("操作成功");
        return result;
    }

    /**
     * 同步修改的阀值到子站，方便子站展示审批机构
     * @param areaLimit
     */
     private void syncAreaLimitPerson(String areaKey,String areaLimit){
         /*文件生成，同步*/
         if (Objects.equals("file", ConfigUtil.getValue("pss-communicate-mode"))) {
             String spDir = ConfigUtil.getValue("spjg_folder");
             String uploadPath = ConfigUtil.getValue("stuff-path");
             // 组装文件夹
             String[] folderPath = new String[]{uploadPath, spDir, DateUtil.today(), SPJG_FOLDER};
             if (StringUtil.isNotEmpty( ConfigUtil.getValue("profile_envi"))
                     && ConfigUtil.getValue("profile_envi").startsWith("pre")) {
                 folderPath = new String[]{uploadPath, spDir,ConfigUtil.getValue("envi") ,DateUtil.today(), SPJG_FOLDER};
             }
             String dir = BcxinFileUtil.appendFolderPath(folderPath);
             //打包活动信息 文件名： _spconfiglimit__t_20170101010101
             String fileName = BcxinFileUtil.packTimestamp( SPCONFIG ) + ".bcx";
             String detailUrl = dir + fileName;
             final File newFile = new File(detailUrl);

             Map<String, String> reMap = Maps.newHashMap();
             reMap.put(areaKey,areaLimit);
             String result = JSON.toJSONString(reMap);
             try {
                 byte[] buf = DESUtil.encrypt(result.getBytes("UTF-8"), GlobalConst.KEY);
                 Files.write(buf, newFile);
             } catch (Exception ex) {
                 ex.printStackTrace();
             }
         }
     }
}
