package com.bcxin.sp.work.controller.activity.car;

import com.bcxin.sp.config.annotation.AuditLogAn;
import com.bcxin.sp.work.controller.sys.BaseController;
import com.bcxin.sp.work.entity.PageResult;
import com.bcxin.sp.work.entity.domain.activity.temp.TempActivityInfo;
import com.bcxin.sp.work.entity.domain.activity.traffic.ActivityTraffic;
import com.bcxin.sp.work.entity.domain.base.PoliceCar;
import com.bcxin.sp.work.entity.dto.ActivityCarTrackDTO;
import com.bcxin.sp.work.entity.dto.CarDTO;
import com.bcxin.sp.work.entity.dto.ParkDTO;
import com.bcxin.sp.work.entity.dto.SearchDto;
import com.bcxin.sp.work.service.activity.car.CarService;
import com.bcxin.sp.work.service.activity.person.ActivityPersonService;
import com.bcxin.sp.work.util.Const.DictConst;
import com.bcxin.sp.work.util.Const.MenuConst;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.servlet.ModelAndView;

import javax.annotation.Resource;
import java.util.List;

/**
 * 票证态势管理
 */
@Controller
@RequestMapping("/business/car")
@Slf4j
public class CarController extends BaseController {

    @Resource
    private CarService carService;

    @Resource
    private ActivityPersonService activityPersonService;
    /**
     * <b> 重点车辆信息 </b>
     * @author ZXF
     * @create 2020/05/11 0011 15:24
     * @version
     * @注意事项 </b>
     */
    @RequestMapping("zdclList/{activityNo}")
    public ModelAndView zdclList(@PathVariable("activityNo") String activityNo) {
        ModelAndView index = new ModelAndView("/activity/workbench/clts/zdclList");
        index.addObject("activityNo",activityNo);
        return index;
    }

    @AuditLogAn(operateType = DictConst.OP_SELECT,menuName = MenuConst.HDGL_GABA)
    @RequestMapping("findZdclListData")
    @ResponseBody
    public SearchDto<CarDTO> findZdclListData(SearchDto<CarDTO> dto) throws Exception {
        /* 查出所有的记录 */
        PageResult pageResult = carService.findZdclListData(dto);
        List<CarDTO> resultList = (List<CarDTO>)pageResult.getRows();
        SearchDto<CarDTO> result = new SearchDto<CarDTO>();
        result.setData(resultList);
        result.setIDisplayStart(dto.getIDisplayStart());
        result.setIDisplayLength(dto.getIDisplayLength());
        result.setITotalRecords(pageResult.getTotal());
        result.setITotalDisplayRecords(pageResult.getTotal());
        return result;
    }

    /**
     * <b> 重点车辆位置信息 </b>
     * @author ZXF
     * @create 2020/05/15 0015 16:14
     * @version
     * @注意事项 </b>
     */
    @RequestMapping("clwzList/{activityCarId}")
    public ModelAndView clwzList(@PathVariable("activityCarId") String activityCarId) {
        ModelAndView index = new ModelAndView("/activity/workbench/clts/zdclwzList");
        index.addObject("activityCarId",activityCarId);
        return index;
    }

    /**
     * <b> 重点车辆位置信息 </b>
     * @author ZXF
     * @create 2020/05/11 0011 15:24
     * @version
     * @注意事项 </b>
     */
    @RequestMapping("zdclwzList/{activityNo}")
    public ModelAndView zdclwzList(@PathVariable("activityNo") String activityNo) {
        ModelAndView index = new ModelAndView("/activity/workbench/clts/zdclwzList");
        index.addObject("activityNo",activityNo);
        return index;
    }

    @AuditLogAn(operateType = DictConst.OP_SELECT,menuName = MenuConst.HDGL_GABA)
    @RequestMapping("findZdclwzListData")
    @ResponseBody
    public SearchDto<ActivityCarTrackDTO> findZdclwzListData(SearchDto<ActivityCarTrackDTO> dto) throws Exception {
        /* 查出所有的记录 */
        PageResult pageResult = carService.findZdclwzListData(dto);
        List<ActivityCarTrackDTO> resultList = (List<ActivityCarTrackDTO>)pageResult.getRows();
        SearchDto<ActivityCarTrackDTO> result = new SearchDto<ActivityCarTrackDTO>();
        result.setData(resultList);
        result.setIDisplayStart(dto.getIDisplayStart());
        result.setIDisplayLength(dto.getIDisplayLength());
        result.setITotalRecords(pageResult.getTotal());
        result.setITotalDisplayRecords(pageResult.getTotal());
        return result;
    }

    /**
     * <b> 警车基本数据信息 </b>
     * @author ZXF
     * @create 2020/05/11 0011 15:24
     * @version
     * @注意事项 </b>
     */
    @RequestMapping("jcjbsjList/{activityNo}")
    public ModelAndView jcjbsjList(@PathVariable("activityNo") String activityNo) {
        ModelAndView index = new ModelAndView("/activity/workbench/clts/jcjbsjList");
        index.addObject("activityNo",activityNo);
        return index;
    }

    @AuditLogAn(operateType = DictConst.OP_SELECT,menuName = MenuConst.HDGL_GABA)
    @RequestMapping("findJcjbsjListData")
    @ResponseBody
    public SearchDto<PoliceCar> findJcjbsjListData(SearchDto<PoliceCar> pc) throws Exception {
        /* 查出所有的记录 */
        PageResult pageResult = carService.findJcjbsjListData(pc);
        List<PoliceCar> resultList = (List<PoliceCar>)pageResult.getRows();
        SearchDto<PoliceCar> result = new SearchDto<PoliceCar>();
        result.setData(resultList);
        result.setIDisplayStart(pc.getIDisplayStart());
        result.setIDisplayLength(pc.getIDisplayLength());
        result.setITotalRecords(pageResult.getTotal());
        result.setITotalDisplayRecords(pageResult.getTotal());
        return result;
    }

    /**
     * <b> 停车场信息 </b>
     * @author ZXF
     * @create 2020/05/11 0011 15:24
     * @version
     * @注意事项 </b>
     */
    @RequestMapping("tccList/{activityNo}")
    public ModelAndView tccList(@PathVariable("activityNo") String activityNo) {
        ModelAndView index = new ModelAndView("/activity/workbench/clts/tccList");
        index.addObject("activityNo",activityNo);
        return index;
    }

    @AuditLogAn(operateType = DictConst.OP_SELECT,menuName = MenuConst.HDGL_GABA)
    @RequestMapping("findTccListData")
    @ResponseBody
    public SearchDto<ParkDTO> findTccListData(SearchDto<ParkDTO> dto) throws Exception {
        /* 查出所有的记录 */
        PageResult pageResult = carService.findTccListData(dto);
        List<ParkDTO> resultList = (List<ParkDTO>)pageResult.getRows();
        SearchDto<ParkDTO> result = new SearchDto<ParkDTO>();
        result.setData(resultList);
        result.setIDisplayStart(dto.getIDisplayStart());
        result.setIDisplayLength(dto.getIDisplayLength());
        result.setITotalRecords(pageResult.getTotal());
        result.setITotalDisplayRecords(pageResult.getTotal());
        return result;
    }

    /**
     * <b> 交通路况信息 </b>
     * @author ZXF
     * @create 2020/05/11 0011 15:24
     * @version
     * @注意事项 </b>
     */
    @RequestMapping("jtlkList/{activityNo}")
    public ModelAndView jtlkList(@PathVariable("activityNo") String activityNo) {
        ModelAndView index = new ModelAndView("/activity/workbench/clts/jtlkList");
        index.addObject("activityNo",activityNo);
        return index;
    }

    @AuditLogAn(operateType = DictConst.OP_SELECT,menuName = MenuConst.HDGL_GABA)
    @RequestMapping("findJtlkListData")
    @ResponseBody
    public SearchDto<ActivityTraffic> findJtlkListData(SearchDto<ActivityTraffic> at) throws Exception {
        /* 查出所有的记录 */
        PageResult pageResult = carService.findJtlkListData(at);
        List<ActivityTraffic> resultList = (List<ActivityTraffic>)pageResult.getRows();
        SearchDto<ActivityTraffic> result = new SearchDto<ActivityTraffic>();
        result.setData(resultList);
        result.setIDisplayStart(at.getIDisplayStart());
        result.setIDisplayLength(at.getIDisplayLength());
        result.setITotalRecords(pageResult.getTotal());
        result.setITotalDisplayRecords(pageResult.getTotal());
        return result;
    }

    //temp
    /**
     * <b> 重点车辆信息 </b>
     * @author ZXF
     * @create 2020/05/11 0011 15:24
     * @version
     * @注意事项 </b>
     */
    @RequestMapping("hdclList")
    public ModelAndView hdclList() {
        ModelAndView index = new ModelAndView("/activity/workbench/temp/hdclList");
//        index.addObject("activityNo",activityNo);
        return index;
    }

    @AuditLogAn(operateType = DictConst.OP_SELECT,menuName = MenuConst.HDGL_GABA)
    @RequestMapping("findHdclListData")
    @ResponseBody
    public SearchDto<TempActivityInfo> findHdclListData(SearchDto<TempActivityInfo> dto) throws Exception {
        /* 查出所有的记录 */
        PageResult pageResult = activityPersonService.findTempActivityInfo(dto);
        List<TempActivityInfo> resultList = (List<TempActivityInfo>)pageResult.getRows();
        SearchDto<TempActivityInfo> result = new SearchDto<TempActivityInfo>();
        result.setData(resultList);
        result.setIDisplayStart(dto.getIDisplayStart());
        result.setIDisplayLength(dto.getIDisplayLength());
        result.setITotalRecords(pageResult.getTotal());
        result.setITotalDisplayRecords(pageResult.getTotal());
        return result;
    }


}
