/**
 * date: 2020-04-26 15:40
 * copyright(c) 2015-2020 百川信
 */
package com.bcxin.sp.work.controller.activity.extend;

import com.alibaba.fastjson.JSON;
import com.bcxin.sp.config.annotation.AuditLogAn;
import com.bcxin.sp.work.controller.sys.BaseController;
import com.bcxin.sp.work.entity.PageResult;
import com.bcxin.sp.work.entity.domain.activity.expand.ActivityAssessment;
import com.bcxin.sp.work.entity.domain.activity.expand.ActivityContractor;
import com.bcxin.sp.work.entity.domain.user.User;
import com.bcxin.sp.work.entity.dto.AjaxResult;
import com.bcxin.sp.work.entity.dto.SearchDto;
import com.bcxin.sp.work.entity.dto.accident.ActivityAssessmentSearchDTO;
import com.bcxin.sp.work.service.third.activityIsr.ActivityAssessmentService;
import com.bcxin.sp.work.util.Const.DictConst;
import com.bcxin.sp.work.util.Const.MenuConst;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.servlet.ModelAndView;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;
import java.util.List;

/**
 * @author: wangjianjun
 * @description: 风险评估信息
 * @data: 2020-04-26 15:40
 **/
@Controller
@RequestMapping("/business/activityAssessment")
@Slf4j
public class ActivityAssessmentController extends BaseController {

    @Resource
    private ActivityAssessmentService activityAssessmentService;

    /**
     * 风险评估信息－页面
     *
     * @param
     * @return
     */
    @RequestMapping("/activityAssessmentListView/{activityNo}")
    public ModelAndView jqsjListView(@PathVariable("activityNo") String activityNo) {
        ModelAndView index = new ModelAndView("/activity/extend/activityAssessmentList");
        index.addObject("activityNo", activityNo);
        return index;
    }

    /**
     * 风险评估信息-列表
     *
     * @param dto
     * @return
     */
    @AuditLogAn(operateType = DictConst.OP_SELECT, menuName = MenuConst.HDGL_GABA)
    @RequestMapping("/findActivityAssessmentListData")
    @ResponseBody
    public SearchDto<ActivityAssessment> findActivityAssessmentListData(ActivityAssessmentSearchDTO dto) {
        PageResult pageResult = activityAssessmentService.findActivityAssessmentList(dto);
        List<ActivityAssessment> resultList = (List<ActivityAssessment>) pageResult.getRows();
        SearchDto<ActivityAssessment> result = new SearchDto<>();
        result.setData(resultList);
        result.setIDisplayStart(dto.getIDisplayStart());
        result.setIDisplayLength(dto.getIDisplayLength());
        result.setITotalRecords(pageResult.getTotal());
        result.setITotalDisplayRecords(pageResult.getTotal());
        return result;
    }

    /**
     * 风险评估信息-详情
     *
     * @param id
     * @return
     */
    @AuditLogAn(operateType = DictConst.OP_SELECT, menuName = MenuConst.HDGL_GABA)
    @RequestMapping("/findActivityAssessmentDetailData")
    @ResponseBody
    public ActivityAssessment findActivityPoliceIsrDetailData(String id) {
        return activityAssessmentService.findActivityAssessmentDetail(Long.valueOf(id));
    }

    /**
     * <b> 服务商列表 </b>
     * @author ZXF
     * @create 2020/11/05 0005 9:29
     * @version
     * @注意事项 </b>
     */
    @RequestMapping("list")
    public ModelAndView list() {
        ModelAndView index = new ModelAndView("/activity/assessment/list");
        return index;
    }

    @AuditLogAn(operateType = DictConst.OP_SELECT,menuName = MenuConst.HDGL_GABA)
    @RequestMapping("findListData")
    @ResponseBody
    public SearchDto<ActivityAssessment> findListData(SearchDto<ActivityAssessment> dto) throws Exception {
        /* 查出所有的记录 */
        PageResult pageResult = activityAssessmentService.findListData(dto);
        List<ActivityAssessment> resultList = (List<ActivityAssessment>)pageResult.getRows();
        SearchDto<ActivityAssessment> result = new SearchDto<ActivityAssessment>();
        result.setData(resultList);
        result.setIDisplayStart(dto.getIDisplayStart());
        result.setIDisplayLength(dto.getIDisplayLength());
        result.setITotalRecords(pageResult.getTotal());
        result.setITotalDisplayRecords(pageResult.getTotal());
        return result;
    }

    @RequestMapping("assessmentInfo/{id}")
    @ResponseBody
    public ActivityAssessment assessmentInfo(@PathVariable("id") Long id){
        return activityAssessmentService.findById(id);
    }

    @AuditLogAn(operateType = DictConst.OP_SAVE,menuName = MenuConst.HDGL_BAHD_TJHD)
    @RequestMapping("createOrUpdate")
    public @ResponseBody
    AjaxResult createOrUpdate(ActivityAssessment ac, HttpServletRequest request) {
        User user = super.getCurrentUser(request);
        ac.setUpdater(user.getUsername());
        activityAssessmentService.createOrUpdate(ac);
        AjaxResult result = new AjaxResult();
        result.setSuccessful(true);
        result.setObj(ac);
        return result;
    }

    @AuditLogAn(operateType = DictConst.OP_UPDATE,menuName = MenuConst.HDGL_BAHD_SCHD)
    @RequestMapping("freeze/{id}")
    public @ResponseBody AjaxResult freeze(@PathVariable("id") long id) {
        AjaxResult result = new AjaxResult();
        ActivityAssessment ac = activityAssessmentService.findById(id);
        if (ac!=null) {
            activityAssessmentService.freeze(ac);
            result.setSuccessful(true);
        } else {
            result.setSuccessful(false);
            result.setMsg("未找到服务商记录.");
        }
        return result;
    }

    @AuditLogAn(operateType = DictConst.OP_UPDATE,menuName = MenuConst.HDGL_BAHD_SCHD)
    @RequestMapping("approve/{id}/{status}")
    public @ResponseBody AjaxResult approve(@PathVariable("id") long id,@PathVariable("status") int status) {
        AjaxResult result = new AjaxResult();
        ActivityAssessment ac = activityAssessmentService.findById(id);
        if (ac!=null) {
            ac.setApproveStatus(status);
            ac.setIsSync(3);
            activityAssessmentService.createOrUpdate(ac);
            result.setSuccessful(true);
        } else {
            result.setSuccessful(false);
            result.setMsg("未找到服务商记录.");
        }
        return result;
    }

}