/**
 * date: 2020-04-26 15:40
 * copyright(c) 2015-2020 百川信
 */
package com.bcxin.sp.work.controller.activity.extend;

import com.bcxin.sp.config.annotation.AuditLogAn;
import com.bcxin.sp.work.controller.sys.BaseController;
import com.bcxin.sp.work.entity.PageResult;
import com.bcxin.sp.work.entity.domain.activity.expand.ActivityBuild;
import com.bcxin.sp.work.entity.domain.activity.expand.ActivityBuildItem;
import com.bcxin.sp.work.entity.dto.SearchDto;
import com.bcxin.sp.work.entity.dto.accident.ActivityBuildSearchDTO;
import com.bcxin.sp.work.service.third.activityIsr.ActivityBuildService;
import com.bcxin.sp.work.util.Const.DictConst;
import com.bcxin.sp.work.util.Const.MenuConst;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.servlet.ModelAndView;

import javax.annotation.Resource;
import java.util.List;

/**
 * @author: wangjianjun
 * @description: 活动临建态势
 * @data: 2020-04-26 15:40
 **/
@Controller
@RequestMapping("/business/activityBuild")
@Slf4j
public class ActivityBuildController extends BaseController {

    @Resource
    private ActivityBuildService activityBuildService;

    /**
     * 活动临建公司信息－页面
     *
     * @param
     * @return
     */
    @RequestMapping("/activityBuildListView/{activityNo}")
    public ModelAndView jqsjListView(@PathVariable("activityNo") String activityNo) {
        ModelAndView index = new ModelAndView("/activity/extend/activityBuildList");
        index.addObject("activityNo", activityNo);
        return index;
    }

    /**
     * 活动临建公司信息-列表
     *
     * @param dto
     * @return
     */
    @AuditLogAn(operateType = DictConst.OP_SELECT, menuName = MenuConst.HDGL_GABA)
    @RequestMapping("findActivityBuildListData")
    @ResponseBody
    public SearchDto<ActivityBuild> findactivityBuildListData(ActivityBuildSearchDTO dto) {
        PageResult pageResult = activityBuildService.findActivityBuildList(dto);
        List<ActivityBuild> resultList = (List<ActivityBuild>) pageResult.getRows();
        SearchDto<ActivityBuild> result = new SearchDto<>();
        result.setData(resultList);
        result.setIDisplayStart(dto.getIDisplayStart());
        result.setIDisplayLength(dto.getIDisplayLength());
        result.setITotalRecords(pageResult.getTotal());
        result.setITotalDisplayRecords(pageResult.getTotal());
        return result;
    }

    /**
     * 活动临建公司信息-详情
     *
     * @param id
     * @return
     */
    @AuditLogAn(operateType = DictConst.OP_SELECT, menuName = MenuConst.HDGL_GABA)
    @RequestMapping("findActivityBuildDetailData")
    @ResponseBody
    public ActivityBuild findActivityBuildDetailData(String id) {
        return activityBuildService.selectByPrimaryKey(Long.valueOf(id));
    }

    /**
     * 活动临建信息－页面
     *
     * @param
     * @return
     */
    @RequestMapping("/activityBuildItemListView/{activityBuildId}")
    public ModelAndView jqsjList2View(@PathVariable("activityBuildId") String activityBuildId) {
        ModelAndView index = new ModelAndView("/activity/extend/activityBuildItemList");
        index.addObject("activityBuildId", activityBuildId);
        return index;
    }

    /**
     * 活动临建信息-列表
     *
     * @param dto
     * @return
     */
    @AuditLogAn(operateType = DictConst.OP_SELECT, menuName = MenuConst.HDGL_GABA)
    @RequestMapping("findActivityBuildItemListData")
    @ResponseBody
    public SearchDto<ActivityBuildItem> findActivityBuildItemListData(ActivityBuildSearchDTO dto) {
//        dto.setActivityBuildId(request.getParameter("activityBuildId"));
        PageResult pageResult = activityBuildService.findActivityBuildItemList(dto);
        List<ActivityBuildItem> resultList = (List<ActivityBuildItem>) pageResult.getRows();
        SearchDto<ActivityBuildItem> result = new SearchDto<>();
        result.setData(resultList);
        result.setIDisplayStart(dto.getIDisplayStart());
        result.setIDisplayLength(dto.getIDisplayLength());
        result.setITotalRecords(pageResult.getTotal());
        result.setITotalDisplayRecords(pageResult.getTotal());
        return result;
    }

    /**
     * 活动临建信息-详情
     *
     * @param id
     * @return
     */
    @AuditLogAn(operateType = DictConst.OP_SELECT, menuName = MenuConst.HDGL_GABA)
    @RequestMapping("findActivityBuildItemDetailData")
    @ResponseBody
    public ActivityBuildItem findActivityBuildItemDetailData(String id) {
        return activityBuildService.selectItemByPrimaryKey(Long.valueOf(id));
    }
}