package com.bcxin.sp.work.controller.activity.extend;

import com.bcxin.sp.config.annotation.AuditLogAn;
import com.bcxin.sp.work.controller.sys.BaseController;
import com.bcxin.sp.work.entity.PageResult;
import com.bcxin.sp.work.entity.domain.activity.expand.ActivityContractor;
import com.bcxin.sp.work.entity.domain.user.User;
import com.bcxin.sp.work.entity.dto.AjaxResult;
import com.bcxin.sp.work.entity.dto.SearchDto;
import com.bcxin.sp.work.service.activity.extend.ActivityContractorService;
import com.bcxin.sp.work.util.Const.DictConst;
import com.bcxin.sp.work.util.Const.MenuConst;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.servlet.ModelAndView;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;
import java.util.List;

/**
 * <b> 承办者管理 </b>
 * @author ZXF
 * @create 2020/11/04 0004 18:08
 * @version
 * @注意事项 </b>
 */
@Controller
@RequestMapping("/business/contractor")
@Slf4j
public class ActivityContractorController extends BaseController {

    @Resource
    private ActivityContractorService activityContractorService;

    /**
     * <b> 承办者列表 </b>
     * @author ZXF
     * @create 2020/11/05 0005 9:29
     * @version
     * @注意事项 </b>
     */
    @RequestMapping("list")
    public ModelAndView list() {
        ModelAndView index = new ModelAndView("/activity/contractor/list");
        return index;
    }

    @AuditLogAn(operateType = DictConst.OP_SELECT,menuName = MenuConst.HDGL_GABA)
    @RequestMapping("findListData")
    @ResponseBody
    public SearchDto<ActivityContractor> findListData(SearchDto<ActivityContractor> dto) throws Exception {
        /* 查出所有的记录 */
        PageResult pageResult = activityContractorService.findListData(dto);
        List<ActivityContractor> resultList = (List<ActivityContractor>)pageResult.getRows();
        SearchDto<ActivityContractor> result = new SearchDto<ActivityContractor>();
        result.setData(resultList);
        result.setIDisplayStart(dto.getIDisplayStart());
        result.setIDisplayLength(dto.getIDisplayLength());
        result.setITotalRecords(pageResult.getTotal());
        result.setITotalDisplayRecords(pageResult.getTotal());
        return result;
    }

    @RequestMapping("contractorInfo/{id}")
    @ResponseBody
    public ActivityContractor contractorInfo(@PathVariable("id") Long id){
        return activityContractorService.findById(id);
    }

    @AuditLogAn(operateType = DictConst.OP_SAVE,menuName = MenuConst.HDGL_BAHD_TJHD)
    @RequestMapping("createOrUpdate")
    public @ResponseBody
    AjaxResult createOrUpdate(ActivityContractor ac, HttpServletRequest request) {
        User user = super.getCurrentUser(request);
        ac.setUpdater(user.getUsername());
        activityContractorService.createOrUpdate(ac);
        AjaxResult result = new AjaxResult();
        result.setSuccessful(true);
        result.setObj(ac);
        return result;
    }

    @AuditLogAn(operateType = DictConst.OP_UPDATE,menuName = MenuConst.HDGL_BAHD_SCHD)
    @RequestMapping("freeze/{id}")
    public @ResponseBody AjaxResult freeze(@PathVariable("id") long id) {
        AjaxResult result = new AjaxResult();
        ActivityContractor ac = activityContractorService.findById(id);
        if (ac!=null) {
            activityContractorService.freeze(ac);
            result.setSuccessful(true);
        } else {
            result.setSuccessful(false);
            result.setMsg("未找到企业记录.");
        }
        return result;
    }
}
