package com.bcxin.sp.work.controller.activity.person;

import com.bcxin.sp.config.annotation.AuditLogAn;
import com.bcxin.sp.work.controller.sys.BaseController;
import com.bcxin.sp.work.entity.PageResult;
import com.bcxin.sp.work.entity.domain.activity.person.*;
import com.bcxin.sp.work.entity.domain.activity.temp.TempActivityInfo;
import com.bcxin.sp.work.entity.dto.ActivityPersonDTO;
import com.bcxin.sp.work.entity.dto.PersonMonitorFaceDTO;
import com.bcxin.sp.work.entity.dto.SearchDto;
import com.bcxin.sp.work.entity.dto.accident.ActivityPersonAirSearchDTO;
import com.bcxin.sp.work.service.activity.person.ActivityPersonService;
import com.bcxin.sp.work.util.Const.DictConst;
import com.bcxin.sp.work.util.Const.MenuConst;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.servlet.ModelAndView;

import javax.annotation.Resource;
import java.util.List;
import java.util.Map;

/**
 * 人员态势管理
 */
@Controller
@RequestMapping("/business/activityPerson")
@Slf4j
public class ActivityPersonController extends BaseController {

    @Resource
    private ActivityPersonService activityPersonService;


    /**
     * <b> 人员背审信息 </b>
     * @author ZXF
     * @create 2020/04/23 0023 16:09
     * @version
     * @注意事项 </b>
     */
    @RequestMapping("rybsList/{activityNo}")
    public ModelAndView rybsList(@PathVariable("activityNo") String activityNo) {
        ModelAndView index = new ModelAndView("/activity/workbench/ryts/rybsList");
        index.addObject("activityNo",activityNo);
        return index;
    }

    @AuditLogAn(operateType = DictConst.OP_SELECT,menuName = MenuConst.HDGL_GABA)
    @RequestMapping("findRybsListData")
    @ResponseBody
    public SearchDto<ActivityPersonDTO> findRybsListData(SearchDto<ActivityPersonDTO> dto) throws Exception {
        /* 查出所有的记录 */
        PageResult pageResult = activityPersonService.findChryListData(dto);
        List<ActivityPersonDTO> resultList = (List<ActivityPersonDTO>)pageResult.getRows();
        SearchDto<ActivityPersonDTO> result = new SearchDto<ActivityPersonDTO>();
        result.setData(resultList);
        result.setIDisplayStart(dto.getIDisplayStart());
        result.setIDisplayLength(dto.getIDisplayLength());
        result.setITotalRecords(pageResult.getTotal());
        result.setITotalDisplayRecords(pageResult.getTotal());
        return result;
    }


    /**
     * <b> 人员背审信息 </b>
     * @author ZXF
     * @create 2020/04/23 0023 16:09
     * @version
     * @注意事项 </b>
     */
    @RequestMapping("rlsbxxList/{activityNo}")
    public ModelAndView rlsbxxList(@PathVariable("activityNo") String activityNo) {
        ModelAndView index = new ModelAndView("/activity/workbench/ryts/rlsbxxList");
        index.addObject("activityNo",activityNo);
        return index;
    }

    @AuditLogAn(operateType = DictConst.OP_SELECT,menuName = MenuConst.HDGL_GABA)
    @RequestMapping("findRlsbxxListData")
    @ResponseBody
    public SearchDto<ActivityPersonDTO> findRlsbxxListData(SearchDto<ActivityPersonDTO> dto) throws Exception {
        /* 查出所有的记录 */
        PageResult pageResult = activityPersonService.findChryListData(dto);
        List<ActivityPersonDTO> resultList = (List<ActivityPersonDTO>)pageResult.getRows();
        SearchDto<ActivityPersonDTO> result = new SearchDto<ActivityPersonDTO>();
        result.setData(resultList);
        result.setIDisplayStart(dto.getIDisplayStart());
        result.setIDisplayLength(dto.getIDisplayLength());
        result.setITotalRecords(pageResult.getTotal());
        result.setITotalDisplayRecords(pageResult.getTotal());
        return result;
    }

    /**
     * <b> 参会人员信息 </b>
     * @author ZXF
     * @create 2020/04/23 0023 16:09
     * @version
     * @注意事项 </b>
     */
    @RequestMapping("chryList/{activityNo}")
    public ModelAndView chryList(@PathVariable("activityNo") String activityNo) {
        ModelAndView index = new ModelAndView("/activity/workbench/ryts/chryList");
        index.addObject("activityNo",activityNo);
        return index;
    }

    @AuditLogAn(operateType = DictConst.OP_SELECT,menuName = MenuConst.HDGL_GABA)
    @RequestMapping("findChryListData")
    @ResponseBody
    public SearchDto<ActivityPersonDTO> findChryListData(SearchDto<ActivityPersonDTO> dto) throws Exception {
        /* 查出所有的记录 */
        PageResult pageResult = activityPersonService.findChryListData(dto);
        List<ActivityPersonDTO> resultList = (List<ActivityPersonDTO>)pageResult.getRows();
        SearchDto<ActivityPersonDTO> result = new SearchDto<ActivityPersonDTO>();
        result.setData(resultList);
        result.setIDisplayStart(dto.getIDisplayStart());
        result.setIDisplayLength(dto.getIDisplayLength());
        result.setITotalRecords(pageResult.getTotal());
        result.setITotalDisplayRecords(pageResult.getTotal());
        return result;
    }

    /**
     * <b> 重点人员信息 </b>
     * @author ZXF
     * @create 2020/04/23 0023 16:09
     * @version
     * @注意事项 </b>
     */
    @RequestMapping("zdryList/{activityNo}")
    public ModelAndView zdryList(@PathVariable("activityNo") String activityNo) {
        ModelAndView index = new ModelAndView("/activity/workbench/ryts/zdryList");
        index.addObject("activityNo",activityNo);
        return index;
    }

    @AuditLogAn(operateType = DictConst.OP_SELECT,menuName = MenuConst.HDGL_GABA)
    @RequestMapping("findZdryListData")
    @ResponseBody
    public SearchDto<ActivityPersonDTO> findZdryListData(SearchDto<ActivityPersonDTO> dto) throws Exception {
        /* 查出所有的记录 */
        PageResult pageResult = activityPersonService.findZdryListData(dto);
        List<ActivityPersonDTO> resultList = (List<ActivityPersonDTO>)pageResult.getRows();
        SearchDto<ActivityPersonDTO> result = new SearchDto<ActivityPersonDTO>();
        result.setData(resultList);
        result.setIDisplayStart(dto.getIDisplayStart());
        result.setIDisplayLength(dto.getIDisplayLength());
        result.setITotalRecords(pageResult.getTotal());
        result.setITotalDisplayRecords(pageResult.getTotal());
        return result;
    }

    /**
     * 重点人员详情
     * @author wangjianjun
     * @date 2020/5/15
     */
    @AuditLogAn(operateType = DictConst.OP_SELECT,menuName = MenuConst.HDGL_GABA)
    @RequestMapping("findZdryDetailData/{id}")
    @ResponseBody
    public Map findZdryDetailData(@PathVariable("id") Long id) throws Exception {
        return activityPersonService.findZdryDetailData(id);
    }

    /**
     * <b> 参会人员动态信息 </b>
     * @author ZXF
     * @create 2020/05/14 0014 17:31
     * @version
     * @注意事项 </b>
     */
    @RequestMapping("dtxxList/{activityNo}/{activityPersonId}/{fullName}")
    public ModelAndView dtxxList(@PathVariable("activityNo") String activityNo
            , @PathVariable("activityPersonId") String activityPersonId
            , @PathVariable("fullName") String fullName) {
        ModelAndView index = new ModelAndView("/activity/workbench/ryts/dtxxList");
        index.addObject("activityNo",activityNo);
        index.addObject("activityPersonId",activityPersonId);
        index.addObject("fullName",fullName);
        return index;
    }

    @AuditLogAn(operateType = DictConst.OP_SELECT,menuName = MenuConst.HDGL_GABA)
    @RequestMapping("findDtxxListData")
    @ResponseBody
    public SearchDto<PersonMonitorFaceDTO> findDtxxListData(SearchDto<PersonMonitorFaceDTO> dto) throws Exception {
        /* 查出所有的记录 */
        PageResult pageResult = activityPersonService.findDtxxListData(dto);
        List<PersonMonitorFaceDTO> resultList = (List<PersonMonitorFaceDTO>)pageResult.getRows();
        SearchDto<PersonMonitorFaceDTO> result = new SearchDto<PersonMonitorFaceDTO>();
        result.setData(resultList);
        result.setIDisplayStart(dto.getIDisplayStart());
        result.setIDisplayLength(dto.getIDisplayLength());
        result.setITotalRecords(pageResult.getTotal());
        result.setITotalDisplayRecords(pageResult.getTotal());
        return result;
    }

    /**
     * 重点人员实名制动态信息-页面
     * @author wangjianjun
     * @date 2020/5/15
     */ 
    @RequestMapping("airList/{activityNo}/{activityPersonId}/{fullName}")
    public ModelAndView airList(@PathVariable("activityNo") String activityNo
            , @PathVariable("activityPersonId") String activityPersonId
            , @PathVariable("fullName") String fullName) {
        ModelAndView index = new ModelAndView("/activity/workbench/ryts/zdrysmz/airList");
        index.addObject("activityNo",activityNo);
        index.addObject("activityPersonId",activityPersonId);
        index.addObject("fullName",fullName);
        return index;
    }

    /**
     * 重点人员实名制动态信息-列表数据
     * @author wangjianjun
     * @date 2020/5/15
     */ 
    @AuditLogAn(operateType = DictConst.OP_SELECT,menuName = MenuConst.HDGL_GABA)
    @RequestMapping("findAirListData")
    @ResponseBody
    public SearchDto<ActivityPersonMonitorAirTrack> findAirListData(ActivityPersonAirSearchDTO dto) throws Exception {
        /* 查出所有的记录 */
        PageResult pageResult = activityPersonService.findActivityPersonMonitorAirTrackList(dto);
        List<ActivityPersonMonitorAirTrack> resultList = (List<ActivityPersonMonitorAirTrack>)pageResult.getRows();
        SearchDto<ActivityPersonMonitorAirTrack> result = new SearchDto<ActivityPersonMonitorAirTrack>();
        result.setData(resultList);
        result.setIDisplayStart(dto.getIDisplayStart());
        result.setIDisplayLength(dto.getIDisplayLength());
        result.setITotalRecords(pageResult.getTotal());
        result.setITotalDisplayRecords(pageResult.getTotal());
        return result;
    }

    /**
     * 重点人员实名制动态信息-页面-铁路
     * @author wangjianjun
     * @date 2020/5/15
     */
    @RequestMapping("trainList/{activityNo}/{activityPersonId}/{fullName}")
    public ModelAndView trainList(@PathVariable("activityNo") String activityNo
            , @PathVariable("activityPersonId") String activityPersonId
            , @PathVariable("fullName") String fullName) {
        ModelAndView index = new ModelAndView("/activity/workbench/ryts/zdrysmz/trainList");
        index.addObject("activityNo",activityNo);
        index.addObject("activityPersonId",activityPersonId);
        index.addObject("fullName",fullName);
        return index;
    }

    /**
     * 重点人员实名制动态信息-列表数据-铁路
     * @author wangjianjun
     * @date 2020/5/15
     */
    @AuditLogAn(operateType = DictConst.OP_SELECT,menuName = MenuConst.HDGL_GABA)
    @RequestMapping("findTrainListData")
    @ResponseBody
    public SearchDto<ActivityPersonMonitorTrainTrack> findTrainListData(ActivityPersonAirSearchDTO dto) throws Exception {
        /* 查出所有的记录 */
        PageResult pageResult = activityPersonService.findActivityPersonMonitorTrainTrackList(dto);
        List<ActivityPersonMonitorTrainTrack> resultList = (List<ActivityPersonMonitorTrainTrack>)pageResult.getRows();
        SearchDto<ActivityPersonMonitorTrainTrack> result = new SearchDto<ActivityPersonMonitorTrainTrack>();
        result.setData(resultList);
        result.setIDisplayStart(dto.getIDisplayStart());
        result.setIDisplayLength(dto.getIDisplayLength());
        result.setITotalRecords(pageResult.getTotal());
        result.setITotalDisplayRecords(pageResult.getTotal());
        return result;
    }

    /**
     * 重点人员实名制动态信息-页面-公路
     * @author wangjianjun
     * @date 2020/5/15
     */
    @RequestMapping("roadList/{activityNo}/{activityPersonId}/{fullName}")
    public ModelAndView roadList(@PathVariable("activityNo") String activityNo
            , @PathVariable("activityPersonId") String activityPersonId
            , @PathVariable("fullName") String fullName) {
        ModelAndView index = new ModelAndView("/activity/workbench/ryts/zdrysmz/roadList");
        index.addObject("activityNo",activityNo);
        index.addObject("activityPersonId",activityPersonId);
        index.addObject("fullName",fullName);
        return index;
    }

    /**
     * 重点人员实名制动态信息-列表数据-公路
     * @author wangjianjun
     * @date 2020/5/15
     */
    @AuditLogAn(operateType = DictConst.OP_SELECT,menuName = MenuConst.HDGL_GABA)
    @RequestMapping("findRoadListData")
    @ResponseBody
    public SearchDto<ActivityPersonMonitorRoadTrack> findRoadListData(ActivityPersonAirSearchDTO dto) throws Exception {
        /* 查出所有的记录 */
        PageResult pageResult = activityPersonService.findActivityPersonMonitorRoadTrackList(dto);
        List<ActivityPersonMonitorRoadTrack> resultList = (List<ActivityPersonMonitorRoadTrack>)pageResult.getRows();
        SearchDto<ActivityPersonMonitorRoadTrack> result = new SearchDto<ActivityPersonMonitorRoadTrack>();
        result.setData(resultList);
        result.setIDisplayStart(dto.getIDisplayStart());
        result.setIDisplayLength(dto.getIDisplayLength());
        result.setITotalRecords(pageResult.getTotal());
        result.setITotalDisplayRecords(pageResult.getTotal());
        return result;
    }

    /**
     * 重点人员实名制动态信息-页面-轮渡
     * @author wangjianjun
     * @date 2020/5/15
     */
    @RequestMapping("shipList/{activityNo}/{activityPersonId}/{fullName}")
    public ModelAndView shipList(@PathVariable("activityNo") String activityNo
            , @PathVariable("activityPersonId") String activityPersonId
            , @PathVariable("fullName") String fullName) {
        ModelAndView index = new ModelAndView("/activity/workbench/ryts/zdrysmz/shipList");
        index.addObject("activityNo",activityNo);
        index.addObject("activityPersonId",activityPersonId);
        index.addObject("fullName",fullName);
        return index;
    }

    /**
     * 重点人员实名制动态信息-列表数据-轮渡
     * @author wangjianjun
     * @date 2020/5/15
     */
    @AuditLogAn(operateType = DictConst.OP_SELECT,menuName = MenuConst.HDGL_GABA)
    @RequestMapping("findShipListData")
    @ResponseBody
    public SearchDto<ActivityPersonMonitorShipTrack> findShipListData(ActivityPersonAirSearchDTO dto) throws Exception {
        /* 查出所有的记录 */
        PageResult pageResult = activityPersonService.findActivityPersonMonitorShipTrackList(dto);
        List<ActivityPersonMonitorShipTrack> resultList = (List<ActivityPersonMonitorShipTrack>)pageResult.getRows();
        SearchDto<ActivityPersonMonitorShipTrack> result = new SearchDto<ActivityPersonMonitorShipTrack>();
        result.setData(resultList);
        result.setIDisplayStart(dto.getIDisplayStart());
        result.setIDisplayLength(dto.getIDisplayLength());
        result.setITotalRecords(pageResult.getTotal());
        result.setITotalDisplayRecords(pageResult.getTotal());
        return result;
    }

    /**
     * 重点人员实名制动态信息-页面-公安检查站
     * @author wangjianjun
     * @date 2020/5/15
     */
    @RequestMapping("checkList/{activityNo}/{activityPersonId}/{fullName}")
    public ModelAndView checkList(@PathVariable("activityNo") String activityNo
            , @PathVariable("activityPersonId") String activityPersonId
            , @PathVariable("fullName") String fullName) {
        ModelAndView index = new ModelAndView("/activity/workbench/ryts/zdrysmz/checkList");
        index.addObject("activityNo",activityNo);
        index.addObject("activityPersonId",activityPersonId);
        index.addObject("fullName",fullName);
        return index;
    }

    /**
     * 重点人员实名制动态信息-列表数据-公安检查站
     * @author wangjianjun
     * @date 2020/5/15
     */
    @AuditLogAn(operateType = DictConst.OP_SELECT,menuName = MenuConst.HDGL_GABA)
    @RequestMapping("findCheckListData")
    @ResponseBody
    public SearchDto<ActivityPersonMonitorCheckTrack> findCheckListData(ActivityPersonAirSearchDTO dto) throws Exception {
        /* 查出所有的记录 */
        PageResult pageResult = activityPersonService.findActivityPersonMonitorCheckTrackList(dto);
        List<ActivityPersonMonitorCheckTrack> resultList = (List<ActivityPersonMonitorCheckTrack>)pageResult.getRows();
        SearchDto<ActivityPersonMonitorCheckTrack> result = new SearchDto<ActivityPersonMonitorCheckTrack>();
        result.setData(resultList);
        result.setIDisplayStart(dto.getIDisplayStart());
        result.setIDisplayLength(dto.getIDisplayLength());
        result.setITotalRecords(pageResult.getTotal());
        result.setITotalDisplayRecords(pageResult.getTotal());
        return result;
    }

    /**
     * 重点人员实名制动态信息-页面-旅馆住宿
     * @author wangjianjun
     * @date 2020/5/15
     */
    @RequestMapping("hotelList/{activityNo}/{activityPersonId}/{fullName}")
    public ModelAndView hotelList(@PathVariable("activityNo") String activityNo
            , @PathVariable("activityPersonId") String activityPersonId
            , @PathVariable("fullName") String fullName) {
        ModelAndView index = new ModelAndView("/activity/workbench/ryts/zdrysmz/hotelList");
        index.addObject("activityNo",activityNo);
        index.addObject("activityPersonId",activityPersonId);
        index.addObject("fullName",fullName);
        return index;
    }

    /**
     * 重点人员实名制动态信息-列表数据-旅馆住宿
     * @author wangjianjun
     * @date 2020/5/15
     */
    @AuditLogAn(operateType = DictConst.OP_SELECT,menuName = MenuConst.HDGL_GABA)
    @RequestMapping("findHotelListData")
    @ResponseBody
    public SearchDto<ActivityPersonMonitorHotelTrack> findHotelListData(ActivityPersonAirSearchDTO dto) throws Exception {
        /* 查出所有的记录 */
        PageResult pageResult = activityPersonService.findActivityPersonMonitorHotelTrackList(dto);
        List<ActivityPersonMonitorHotelTrack> resultList = (List<ActivityPersonMonitorHotelTrack>)pageResult.getRows();
        SearchDto<ActivityPersonMonitorHotelTrack> result = new SearchDto<ActivityPersonMonitorHotelTrack>();
        result.setData(resultList);
        result.setIDisplayStart(dto.getIDisplayStart());
        result.setIDisplayLength(dto.getIDisplayLength());
        result.setITotalRecords(pageResult.getTotal());
        result.setITotalDisplayRecords(pageResult.getTotal());
        return result;
    }

    /**
     * 重点人员实名制动态信息-页面-网吧上网
     * @author wangjianjun
     * @date 2020/5/15
     */
    @RequestMapping("barList/{activityNo}/{activityPersonId}/{fullName}")
    public ModelAndView barList(@PathVariable("activityNo") String activityNo
            , @PathVariable("activityPersonId") String activityPersonId
            , @PathVariable("fullName") String fullName) {
        ModelAndView index = new ModelAndView("/activity/workbench/ryts/zdrysmz/barList");
        index.addObject("activityNo",activityNo);
        index.addObject("activityPersonId",activityPersonId);
        index.addObject("fullName",fullName);
        return index;
    }

    /**
     * 重点人员实名制动态信息-列表数据-网吧上网
     * @author wangjianjun
     * @date 2020/5/15
     */
    @AuditLogAn(operateType = DictConst.OP_SELECT,menuName = MenuConst.HDGL_GABA)
    @RequestMapping("findBarListData")
    @ResponseBody
    public SearchDto<ActivityPersonMonitorBarTrack> findBarListData(ActivityPersonAirSearchDTO dto) throws Exception {
        /* 查出所有的记录 */
        PageResult pageResult = activityPersonService.findActivityPersonMonitorBarTrackList(dto);
        List<ActivityPersonMonitorBarTrack> resultList = (List<ActivityPersonMonitorBarTrack>)pageResult.getRows();
        SearchDto<ActivityPersonMonitorBarTrack> result = new SearchDto<ActivityPersonMonitorBarTrack>();
        result.setData(resultList);
        result.setIDisplayStart(dto.getIDisplayStart());
        result.setIDisplayLength(dto.getIDisplayLength());
        result.setITotalRecords(pageResult.getTotal());
        result.setITotalDisplayRecords(pageResult.getTotal());
        return result;
    }

    /**
     * 重点人员实名制动态信息-页面-人像识别
     * @author wangjianjun
     * @date 2020/5/15
     */
    @RequestMapping("faceList/{activityNo}/{activityPersonId}/{fullName}")
    public ModelAndView faceList(@PathVariable("activityNo") String activityNo
            , @PathVariable("activityPersonId") String activityPersonId
            , @PathVariable("fullName") String fullName) {
        ModelAndView index = new ModelAndView("/activity/workbench/ryts/zdrysmz/faceList");
        index.addObject("activityNo",activityNo);
        index.addObject("activityPersonId",activityPersonId);
        index.addObject("fullName",fullName);
        return index;
    }

    /**
     * 重点人员实名制动态信息-列表数据-人像识别
     * @author wangjianjun
     * @date 2020/5/15
     */
    @AuditLogAn(operateType = DictConst.OP_SELECT,menuName = MenuConst.HDGL_GABA)
    @RequestMapping("findFaceListData")
    @ResponseBody
    public SearchDto<ActivityPersonMonitorFaceTrack> findFaceListData(ActivityPersonAirSearchDTO dto) throws Exception {
        /* 查出所有的记录 */
        PageResult pageResult = activityPersonService.findActivityPersonMonitorFaceTrackList(dto);
        List<ActivityPersonMonitorFaceTrack> resultList = (List<ActivityPersonMonitorFaceTrack>)pageResult.getRows();
        SearchDto<ActivityPersonMonitorFaceTrack> result = new SearchDto<ActivityPersonMonitorFaceTrack>();
        result.setData(resultList);
        result.setIDisplayStart(dto.getIDisplayStart());
        result.setIDisplayLength(dto.getIDisplayLength());
        result.setITotalRecords(pageResult.getTotal());
        result.setITotalDisplayRecords(pageResult.getTotal());
        return result;
    }


    //temp，临时加的
    /**
     * <b> 人员背审信息 </b>
     * @author ZXF
     * @create 2020/04/23 0023 16:09
     * @version
     * @注意事项 </b>
     */
    @RequestMapping("hdryList")
    public ModelAndView hdryList() {
        ModelAndView index = new ModelAndView("/activity/workbench/temp/hdryList");
//        index.addObject("activityNo",activityNo);
        return index;
    }

    @AuditLogAn(operateType = DictConst.OP_SELECT,menuName = MenuConst.HDGL_GABA)
    @RequestMapping("findHdryListData")
    @ResponseBody
    public SearchDto<TempActivityInfo> findHdryListData(SearchDto<TempActivityInfo> dto) throws Exception {
        /* 查出所有的记录 */
        dto.setActivityNo("");
        PageResult pageResult = activityPersonService.findTempActivityInfo(dto);
        List<TempActivityInfo> resultList = (List<TempActivityInfo>)pageResult.getRows();
        SearchDto<TempActivityInfo> result = new SearchDto<TempActivityInfo>();
        result.setData(resultList);
        result.setIDisplayStart(dto.getIDisplayStart());
        result.setIDisplayLength(dto.getIDisplayLength());
        result.setITotalRecords(pageResult.getTotal());
        result.setITotalDisplayRecords(pageResult.getTotal());
        return result;
    }

}
