package com.bcxin.sp.work.controller.activity.security;

import com.bcxin.sp.config.annotation.AuditLogAn;
import com.bcxin.sp.work.controller.sys.BaseController;
import com.bcxin.sp.work.entity.PageResult;
import com.bcxin.sp.work.entity.dto.SearchDto;
import com.bcxin.sp.work.entity.dto.SecurityTaskDTO;
import com.bcxin.sp.work.entity.dto.SecurityTaskPersonDTO;
import com.bcxin.sp.work.entity.dto.SecurityTaskPersonTrackDTO;
import com.bcxin.sp.work.service.activity.security.SecurityTaskService;
import com.bcxin.sp.work.service.third.nx.NXDataService;
import com.bcxin.sp.work.util.Const.DictConst;
import com.bcxin.sp.work.util.Const.MenuConst;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.servlet.ModelAndView;

import javax.annotation.Resource;
import java.util.List;
import java.util.Map;

/**
 * 安保任务管理
 */
@Controller
@RequestMapping("/business/securityTask")
@Slf4j
public class SecurityTaskController extends BaseController {

    @Resource
    private SecurityTaskService securityTaskService;

    @Resource
    private NXDataService nxDataService;

    /**
     * <b> 根据活动查询场馆信息 </b>
     * @author ZXF
     * @create 2020/02/28 0028 15:09
     * @version
     * @注意事项 </b>
     */
    @RequestMapping("findSecurityTaskList/{activityId}")
    public @ResponseBody List<Map> findSecurityTaskList(@PathVariable("activityId") Long activityId) throws Exception {
        return securityTaskService.findSecurityTaskListByActivityId(activityId);
    }

    /** 安保态势 **/

    /**
     * <b> 应急处理预案信息 </b>
     * @author ZXF
     * @create 2020/04/23 0023 16:09
     * @version
     * @注意事项 </b>
     */
    @RequestMapping("abrwList/{activityNo}")
    public ModelAndView abrwList(@PathVariable("activityNo") String activityNo) {
        ModelAndView index = new ModelAndView("/activity/workbench/abts/abrwList");
        index.addObject("activityNo",activityNo);
        return index;
    }

    @AuditLogAn(operateType = DictConst.OP_SELECT,menuName = MenuConst.HDGL_GABA)
    @RequestMapping("findAbrwListData")
    @ResponseBody
    public SearchDto<SecurityTaskDTO> findAbrwListData(SearchDto<SecurityTaskDTO> dto) throws Exception {
        /* 查出所有的记录 */
        PageResult pageResult = securityTaskService.findAbrwListData(dto);
        List<SecurityTaskDTO> resultList = (List<SecurityTaskDTO>)pageResult.getRows();
        SearchDto<SecurityTaskDTO> result = new SearchDto<SecurityTaskDTO>();
        result.setData(resultList);
        result.setIDisplayStart(dto.getIDisplayStart());
        result.setIDisplayLength(dto.getIDisplayLength());
        result.setITotalRecords(pageResult.getTotal());
        result.setITotalDisplayRecords(pageResult.getTotal());
        return result;
    }



    /**
     * <b> 安保任务详情信息 </b>
     * @author ZXF
     * @create 2020/05/13 0013 10:34
     * @version
     * @注意事项 </b>
     */
    @RequestMapping("getAbrwListData/{taskId}")
    public @ResponseBody Map getAbrwListData(@PathVariable Long taskId) throws Exception {
        return securityTaskService.getAbrwListData(taskId);
    }

    @RequestMapping("lxgjList/{activityNo}/{taskId}")
    public ModelAndView lxgjList(@PathVariable("activityNo") String activityNo,@PathVariable("taskId") String taskId) {
        ModelAndView index = new ModelAndView("/activity/workbench/abts/lxgjList");
        index.addObject("activityNo",activityNo);
        index.addObject("taskId",taskId);
        return index;
    }

    @AuditLogAn(operateType = DictConst.OP_SELECT,menuName = MenuConst.HDGL_GABA)
    @RequestMapping("findLxgjListData")
    @ResponseBody
    public SearchDto<SecurityTaskPersonTrackDTO> findLxgjListData(SearchDto<SecurityTaskPersonTrackDTO> dto) throws Exception {
        /* 查出所有的记录 */
        PageResult pageResult = securityTaskService.findLxgjListData(dto);
        List<SecurityTaskPersonTrackDTO> resultList = (List<SecurityTaskPersonTrackDTO>)pageResult.getRows();
        SearchDto<SecurityTaskPersonTrackDTO> result = new SearchDto<SecurityTaskPersonTrackDTO>();
        result.setData(resultList);
        result.setIDisplayStart(dto.getIDisplayStart());
        result.setIDisplayLength(dto.getIDisplayLength());
        result.setITotalRecords(pageResult.getTotal());
        result.setITotalDisplayRecords(pageResult.getTotal());
        return result;
    }

    /**
     * <b> 任务保安人员列表 </b>
     * @author ZXF
     * @create 2020/05/13 0013 15:51
     * @version
     * @注意事项 </b>
     */
    @RequestMapping("rwbaryList/{activityNo}/{taskId}")
    public ModelAndView rwbaryList(@PathVariable("activityNo") String activityNo,@PathVariable("taskId") String taskId) {
        ModelAndView index = new ModelAndView("/activity/workbench/abts/rwbaryList");
        index.addObject("activityNo",activityNo);
        index.addObject("taskId",taskId);
        return index;
    }

    /**
     * 任务警力人员列表
     * @param activityNo
     * @param taskId
     * @return
     */
    @RequestMapping("rwbaryPoliceList/{activityNo}/{taskId}")
    public ModelAndView rwbaryPoliceList(@PathVariable("activityNo") String activityNo,@PathVariable("taskId") String taskId) {
        ModelAndView index = new ModelAndView("/activity/workbench/abts/rwbaryPoliceList");
        index.addObject("activityNo",activityNo);
        index.addObject("taskId",taskId);
        return index;
    }


    @AuditLogAn(operateType = DictConst.OP_SELECT,menuName = MenuConst.HDGL_GABA)
    @RequestMapping("findRwbaryListData")
    @ResponseBody
    public SearchDto<SecurityTaskPersonDTO> findRwbaryListData(SearchDto<SecurityTaskPersonDTO> dto) throws Exception {
        /* 查出所有的记录 */
        PageResult pageResult = securityTaskService.findRwbaryListData(dto);
        List<SecurityTaskPersonDTO> resultList = (List<SecurityTaskPersonDTO>)pageResult.getRows();
        SearchDto<SecurityTaskPersonDTO> result = new SearchDto<SecurityTaskPersonDTO>();
        result.setData(resultList);
        result.setIDisplayStart(dto.getIDisplayStart());
        result.setIDisplayLength(dto.getIDisplayLength());
        result.setITotalRecords(pageResult.getTotal());
        result.setITotalDisplayRecords(pageResult.getTotal());
        return result;
    }
}
