package com.bcxin.sp.work.controller.activity.workbench;

import com.bcxin.sp.config.annotation.AuditLogAn;
import com.bcxin.sp.config.annotation.OperLog;
import com.bcxin.sp.work.controller.sys.BaseController;
import com.bcxin.sp.work.entity.domain.user.User;
import com.bcxin.sp.work.service.activity.approve.ApproveService;
import com.bcxin.sp.work.service.activity.base.ActivityService;
import com.bcxin.sp.work.service.activity.extend.ActivityCameraTotalService;
import com.bcxin.sp.work.service.base.VenueService;
import com.bcxin.sp.work.service.sys.ServiceOrgService;
import com.bcxin.sp.work.util.Const.DictConst;
import com.bcxin.sp.work.util.Const.MenuConst;
import com.google.common.collect.Maps;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.servlet.ModelAndView;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;
import java.util.List;
import java.util.Map;

/**
 * <b> 安保工作台管理 </b>
 * @author ZXF
 * @create 2020/03/03 0003 11:03
 * @version
 * @注意事项 </b>
 */
@Controller
@RequestMapping("/business/workbench")
@Slf4j
public class WorkbenchController extends BaseController {

    @Resource
    private ActivityService activityService;

    @Resource
    private VenueService venueService;

    @Resource
    private ServiceOrgService serviceOrgService;

    @Resource
    private ApproveService approveService;

    @Resource
    private ActivityCameraTotalService activityCameraTotalService;

    /**
     * <b> 安保管理工作台-页面 </b>
     * @author ZXF
     * @create 2020/03/02 0002 16:45
     * @version
     * @注意事项 </b>
     */
    @RequestMapping("initial/{activityId}")
    @AuditLogAn(operateType = DictConst.OP_SELECT,menuName = MenuConst.HDGL_XKHD_GZT)
    @OperLog(menuName = "许可活动",operateType = "工作台",operateObj = "#activityId")
    public ModelAndView initial(@PathVariable("activityId") Long activityId) {
        ModelAndView index = new ModelAndView("/activity/workbench/detail");
        index.addObject("activityId",activityId);
        return index;
    }

    /**
     * <b> 查询活动信息列表 </b>
     * @author ZXF
     * @create 2020/03/03 0003 13:51
     * @version
     * @注意事项 </b>
     */
    @RequestMapping("findActivityList")
    @AuditLogAn(operateType = DictConst.OP_SELECT,menuName = MenuConst.HDGL_XKHD)
    public @ResponseBody List<Map> findActivityList(HttpServletRequest request) throws Exception {
        User user = getCurrentUser(request);
        return activityService.findActivityByUser(user.getId());
    }

    /**
     * <b> 查询部分活动信息 </b>
     * @author ZXF
     * @create 2020/03/03 0003 15:13
     * @version
     * @注意事项 </b>
     */
    @RequestMapping("getActivityById/{activityId}")
    public @ResponseBody Map getActivityById(@PathVariable("activityId") Long activityId) throws Exception {
        return activityService.getActivityById(activityId);
    }

    /**
     * <b> 根据活动id查询首条场馆信息 </b>
     * @author ZXF
     * @create 2020/03/03 0003 15:13
     * @version
     * @注意事项 </b>
     */
    @RequestMapping("getVenueByIdForOne/{activityId}")
    public @ResponseBody Map getVenueByIdForOne(@PathVariable("activityId") Long activityId) throws Exception {
        Map map = venueService.getVenueByIdForOne(activityId);
        if(map == null){
            map = Maps.newHashMap();
        }
        return map;
    }

    /**
     * <b> 根据活动id查询安保公司信息 </b>
     * @author ZXF
     * @create 2020/03/03 0003 15:13
     * @version
     * @注意事项 </b>
     */
    @RequestMapping("getServiceOrgByIdForOne/{activityId}")
    public @ResponseBody Map getServiceOrgByIdForOne(@PathVariable("activityId") Long activityId) throws Exception {
        Map map = serviceOrgService.getServiceOrgByIdForOne(activityId);
        if(map == null){
            map = Maps.newHashMap();
        }
        return map;
    }

    /**
     * <b> 根据活动id查询最后一次审批信息 </b>
     * @author ZXF
     * @create 2020/03/03 0003 15:13
     * @version
     * @注意事项 </b>
     */
    @RequestMapping("getApproveByIdLastOne/{activityId}")
    public @ResponseBody Map getApproveByIdLastOne(@PathVariable("activityId") Long activityId) throws Exception {
        Map map = approveService.getApproveByIdLastOne(activityId);
        if(map == null){
            map = Maps.newHashMap();
        }
        return map;
    }

    /**
     * <b> 根据活动id查询活动视频数据 </b>
     * @author ZXF
     * @create 2020/03/03 0003 15:13
     * @version
     * @注意事项 </b>
     */
    @RequestMapping("getActivityCameraTotalByActivityId/{activityId}")
    public @ResponseBody Map getActivityCameraTotalByActivityId(@PathVariable("activityId") Long activityId) throws Exception {
        Map map = activityCameraTotalService.getActivityCameraTotalByActivityId(activityId);
        if(map == null){
            map = Maps.newHashMap();
        }
        return map;
    }

}
