package com.bcxin.sp.work.controller.base;

import com.bcxin.sp.config.annotation.AuditLogAn;
import com.bcxin.sp.work.controller.sys.BaseController;
import com.bcxin.sp.work.entity.PageResult;
import com.bcxin.sp.work.entity.domain.base.Venue;
import com.bcxin.sp.work.entity.domain.user.User;
import com.bcxin.sp.work.entity.dto.AjaxResult;
import com.bcxin.sp.work.entity.dto.SearchDto;
import com.bcxin.sp.work.entity.dto.VenueDTO;
import com.bcxin.sp.work.service.base.VenueService;
import com.bcxin.sp.work.util.Const.DictConst;
import com.bcxin.sp.work.util.Const.MenuConst;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.servlet.ModelAndView;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;
import java.util.List;
import java.util.Map;

/**
 * 场馆管理
 */
@Controller
@RequestMapping("/business/venue")
@Slf4j
public class VenueController extends BaseController {

    @Resource
    private VenueService venueService;

    /**
     * <b> 根据活动查询场馆信息 </b>
     * @author ZXF
     * @create 2020/02/28 0028 15:09
     * @version
     * @注意事项 </b>
     */
    @RequestMapping("findVenueList/{activityId}")
    public @ResponseBody List<Map> findVenueList(@PathVariable("activityId") Long activityId) throws Exception {
        return venueService.findVenueListByActivityId(activityId);
    }

    /** 安保态势 **/

    /**
     * <b> 场馆归档 </b>
     * @author ZXF
     * @create 2020/04/23 0023 16:09
     * @version
     * @注意事项 </b>
     */
    @RequestMapping("cggdList/{activityNo}")
    public ModelAndView cggdList(@PathVariable("activityNo") String activityNo) {
        ModelAndView index = new ModelAndView("/activity/workbench/abts/cggdList");
        index.addObject("activityNo",activityNo);
        return index;
    }

    @AuditLogAn(operateType = DictConst.OP_SELECT,menuName = MenuConst.HDGL_GABA)
    @RequestMapping("findCggdListData")
    @ResponseBody
    public SearchDto<VenueDTO> findCggdListData(SearchDto<VenueDTO> dto) throws Exception {
        /* 查出所有的记录 */
        PageResult pageResult = venueService.findCggdListData(dto);
        List<VenueDTO> resultList = (List<VenueDTO>)pageResult.getRows();
        SearchDto<VenueDTO> result = new SearchDto<VenueDTO>();
        result.setData(resultList);
        result.setIDisplayStart(dto.getIDisplayStart());
        result.setIDisplayLength(dto.getIDisplayLength());
        result.setITotalRecords(pageResult.getTotal());
        result.setITotalDisplayRecords(pageResult.getTotal());
        return result;
    }

    /**
     * 查出所有场馆-分页
     * @param dto
     * @return
     * @throws Exception
     */
    @AuditLogAn(operateType = DictConst.OP_SELECT,menuName = MenuConst.HDGL_GABA)
    @RequestMapping("findAll")
    @ResponseBody
    public SearchDto<VenueDTO> findAll(SearchDto<VenueDTO> dto) throws Exception {
        /* 查出所有的记录 */
        PageResult pageResult = venueService.findAll(dto);
        List<VenueDTO> resultList = (List<VenueDTO>)pageResult.getRows();
        SearchDto<VenueDTO> result = new SearchDto<VenueDTO>();
        result.setData(resultList);
        result.setIDisplayStart(dto.getIDisplayStart());
        result.setIDisplayLength(dto.getIDisplayLength());
        result.setITotalRecords(pageResult.getTotal());
        result.setITotalDisplayRecords(pageResult.getTotal());
        return result;
    }

    /**
     * 场馆配置-列表
     * @author wangjianjun
     * @date 2020/6/3
     */
    @RequestMapping("/list")
    public ModelAndView list(HttpServletRequest request) {
        return new ModelAndView("/activity/bim/venue");
    }

    /**
     * 场馆配置-创建与修改
     * @author wangjianjun
     * @date 2020/6/3
     */
    @RequestMapping("createOrUpdate")
    public @ResponseBody
    AjaxResult createOrUpdate(Venue approveRole, HttpServletRequest request) {
        User cuser = super.getCurrentUser(request);
        if (approveRole.getId() == null) {
            venueService.insert(approveRole);
        } else {
            venueService.updateByPrimaryKey(approveRole);
        }
        AjaxResult result = new AjaxResult();
        result.setSuccessful(true);
        result.setObj(approveRole);
        return result;
    }

    /**
     * 场馆配置-删除
     * @author wangjianjun
     * @date 2020/6/3
     */
    @RequestMapping("delete")
    public @ResponseBody
    AjaxResult delete(Venue approveRole) {
        venueService.deleteByPrimaryKey(approveRole.getId());
        AjaxResult result = new AjaxResult();
        result.setSuccessful(true);
        result.setObj(approveRole);
        return result;
    }

    /**
     * 场馆配置-列表-不分页
     * @author wangjianjun
     * @date 2020/6/3
     */
    @RequestMapping("findData")
    public @ResponseBody
    List<Venue> findData(HttpServletRequest request) throws Exception {
//        User user = super.getCurrentUser(request);
        return venueService.findAll();
    }

}
