package com.bcxin.sp.work.controller.bi;

import com.bcxin.sp.work.controller.sys.BaseController;
import com.bcxin.sp.work.entity.domain.activity.base.Activity;
import com.bcxin.sp.work.entity.domain.user.User;
import com.bcxin.sp.work.service.activity.base.ActivityService;
import com.bcxin.sp.work.util.StringUtil;
import com.bcxin.sp.work.util.sys.ConfigUtil;
import com.bcxin.sp.work.util.zj.JwtUtil;
import com.google.common.collect.Maps;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.servlet.ModelAndView;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;
import java.util.List;
import java.util.Map;
import java.util.Optional;

/**
 * BI大屏处理
 *
 * @author 罗鹏
 */
@Controller
@RequestMapping("/business/bi")
@Slf4j
public class BiController extends BaseController {

    @Resource
    private ActivityService activityService;

    /**
     * 协同系统列表
     *
     * @return
     */
    @RequestMapping("cooper/list")
    public ModelAndView list() {
        return new ModelAndView("/bi/bizCooperList");
    }

    /**
     * 安保管理工作台
     *
     * @param request
     * @return
     */
    @RequestMapping("abgzt")
    public ModelAndView abgzt(HttpServletRequest request) {
        ModelAndView index = new ModelAndView("/activity/workbench/detail");
        if (StringUtil.isNotEmpty(request.getParameter("activityId"))) {
            index.addObject("activityId", request.getParameter("activityId"));
        } else {
            User user = super.getCurrentUser(request);
            /* 查找最新的一场活动 */
            Activity activity = activityService.findLastActivity(user);
            index.addObject("activityId", activity.getId());
        }
        return index;
    }

    /**
     * 视频智能分析
     *
     * @param request
     * @return
     */
    //@RequestMapping("spznfx")
    public ModelAndView spznfx(HttpServletRequest request) {
        ModelAndView index = new ModelAndView("/redirect");
        User user = super.getCurrentUser(request);
        if (StringUtil.isNotEmpty(request.getParameter("activityNo"))) {
            index.addObject("activityNo", request.getParameter("activityNo"));
        } else if (StringUtil.isNotEmpty(request.getParameter("activityId"))) {
            Activity activity = activityService.findById(Long.parseLong(request.getParameter("activityId")));
            index.addObject("activityNo", Optional.ofNullable(activity).map(a->a.getActivityNo()).orElse(""));
        } else {
            /* 查找最新的一场活动 */
            Activity activity = activityService.findLastActivity(user);
            index.addObject("activityNo", Optional.ofNullable(activity).map(a->a.getActivityNo()).orElse(""));
        }
        index.addObject("url", ConfigUtil.getValue("bi_spznfx_url"));
        //index.addObject("menuName", "活动态势");
        return index;
    }

    /**
     * 视频智能分析 NEW
     *
     * @param request
     * @return
     */
    @RequestMapping("spznfx")
    public ModelAndView spznfxNew(HttpServletRequest request) {
        ModelAndView index = new ModelAndView("/activity/workbench/cboardViewWithoutSelect");
        String activityNo = request.getParameter("activityNo");
        User user = super.getCurrentUser(request);
        if (StringUtil.isNotEmpty(request.getParameter("activityNo"))) {
            index.addObject("activityNo", request.getParameter("activityNo"));
        } else if (StringUtil.isNotEmpty(request.getParameter("activityId"))) {
            Activity activity = activityService.findById(Long.parseLong(request.getParameter("activityId")));
            index.addObject("activityNo", Optional.ofNullable(activity).map(a->a.getActivityNo()).orElse(""));
        } else {
            /* 查找最新的一场活动 */
//            Activity activity = activityService.findLastActivity(user);
//            index.addObject("activityNo", activity.getActivityNo());
        }
        Map<String,String> param = Maps.newHashMap();
        param.put("viewCode", "PSSAB_SPZNFX");
        param.put("activityNo", "'"+activityNo+"'");
        String token = JwtUtil.createJWT(param);
        index.addObject("url", ConfigUtil.getValue("bi_url") + "/view?token="+token);
//        List<Map> activityList = activityService.findActivityByUser(user.getId());
//        index.addObject("activityList", activityList);
        index.addObject("menuName", "视频智能分析");
//        index.addObject("menuType", "fxpgts");

        request.getSession().setAttribute("currentBiViewCode", "PSSAB_SPZNFX");
        return index;
    }




    /**
     * GIS防控指挥
     *
     * @param request
     * @return
     */
    @RequestMapping("fkzh")
    public ModelAndView fkzh(HttpServletRequest request) {
        ModelAndView index = new ModelAndView("/redirect");
        index.addObject("url", ConfigUtil.getValue("bi_fkzh_url"));
        //index.addObject("menuName", "活动态势");
        return index;
    }


    /**
     * 风险评估态势
     *
     * @param request
     * @return
     */
    @RequestMapping("fxpgts")
    public ModelAndView fxpgts(HttpServletRequest request) {
        ModelAndView index = new ModelAndView("/activity/workbench/cboardView");
        String activityNo = request.getParameter("activityNo");
        User user = super.getCurrentUser(request);
        if (StringUtil.isNotEmpty(request.getParameter("activityNo"))) {
            index.addObject("activityNo", request.getParameter("activityNo"));
        } else if (StringUtil.isNotEmpty(request.getParameter("activityId"))) {
            Activity activity = activityService.findById(Long.parseLong(request.getParameter("activityId")));
            index.addObject("activityNo", Optional.ofNullable(activity).map(a->a.getActivityNo()).orElse(""));
        } else {
            /* 查找最新的一场活动 */
            Activity activity = activityService.findLastActivity(user);
            index.addObject("activityNo", Optional.ofNullable(activity).map(a->a.getActivityNo()).orElse(""));
        }
        Map<String,String> param = Maps.newHashMap();
        param.put("viewCode", "PSSAB_FXPGTS");
        param.put("activityNo", "'"+activityNo+"'");
        String token = JwtUtil.createJWT(param);
        index.addObject("url", ConfigUtil.getValue("bi_url") + "/view?token="+token);
        List<Map> activityList = activityService.findActivityByUser(user.getId());
        index.addObject("activityList", activityList);
        index.addObject("menuName", "风险评估态势");
        index.addObject("menuType", "fxpgts");

        request.getSession().setAttribute("currentBiViewCode", "PSSAB_FXPGTS");
        return index;
    }

    /**
     * 现场勘查态势
     *
     * @param request
     * @return
     */
    @RequestMapping("xckcts")
    public ModelAndView xckcts(HttpServletRequest request) {
        ModelAndView index = new ModelAndView("/activity/workbench/cboardView");
        User user = super.getCurrentUser(request);
        if (StringUtil.isNotEmpty(request.getParameter("activityNo"))) {
            index.addObject("activityNo", request.getParameter("activityNo"));
        } else if (StringUtil.isNotEmpty(request.getParameter("activityId"))) {
            Activity activity = activityService.findById(Long.parseLong(request.getParameter("activityId")));
            index.addObject("activityNo", Optional.ofNullable(activity).map(a->a.getActivityNo()).orElse(""));
        } else {
            /* 查找最新的一场活动 */
            Activity activity = activityService.findLastActivity(user);
            index.addObject("activityNo", Optional.ofNullable(activity).map(a->a.getActivityNo()).orElse(""));
        }
//        index.addObject("url", ConfigUtil.getValue("bi_xckcts_url"));//todo
        List<Map> activityList = activityService.findActivityByUser(user.getId());
        index.addObject("activityList", activityList);
        index.addObject("menuName", "现场勘查态势");
        index.addObject("menuType", "xckcts");

        return index;
    }

    /**
     * 活动临建态势
     *
     * @param request
     * @return
     */
    @RequestMapping("hdljts")
    public ModelAndView hdljts(HttpServletRequest request) {
        ModelAndView index = new ModelAndView("/activity/workbench/cboardView");
        String activityNo = request.getParameter("activityNo");
        User user = super.getCurrentUser(request);
        if (StringUtil.isNotEmpty(request.getParameter("activityNo"))) {
            index.addObject("activityNo", request.getParameter("activityNo"));
        } else if (StringUtil.isNotEmpty(request.getParameter("activityId"))) {
            Activity activity = activityService.findById(Long.parseLong(request.getParameter("activityId")));
            index.addObject("activityNo", Optional.ofNullable(activity).map(a->a.getActivityNo()).orElse(""));
        } else {
            /* 查找最新的一场活动 */
            Activity activity = activityService.findLastActivity(user);
            index.addObject("activityNo", Optional.ofNullable(activity).map(a->a.getActivityNo()).orElse(""));
        }
        Map<String,String> param = Maps.newHashMap();
        param.put("viewCode", "PSSAB_LJTS");
        param.put("activityNo", "'"+activityNo+"'");
        String token = JwtUtil.createJWT(param);
        index.addObject("url", ConfigUtil.getValue("bi_url") + "/view?token="+token);
        List<Map> activityList = activityService.findActivityByUser(user.getId());
        index.addObject("activityList", activityList);
        index.addObject("menuName", "活动临建态势");
        index.addObject("menuType", "hdljts");
        request.getSession().setAttribute("currentBiViewCode", "PSSAB_LJTS");
        return index;
    }

    /**
     * 活动态势
     *
     * @param request
     * @return
     */
    @RequestMapping("hdts")
    public ModelAndView hdts(HttpServletRequest request) {
        ModelAndView index = new ModelAndView("/activity/workbench/cboardView");
        User user = super.getCurrentUser(request);
        String activityNo = request.getParameter("activityNo");
        if (StringUtil.isNotEmpty(request.getParameter("activityNo"))) {
            index.addObject("activityNo", request.getParameter("activityNo"));
        } else if (StringUtil.isNotEmpty(request.getParameter("activityId"))) {
            Activity activity = activityService.findById(Long.parseLong(request.getParameter("activityId")));
            index.addObject("activityNo", Optional.ofNullable(activity).map(a->a.getActivityNo()).orElse(""));
            activityNo = activity.getActivityNo();
        } else {
            /* 查找最新的一场活动 */
            Activity activity = activityService.findLastActivity(user);
            index.addObject("activityNo", activity.getActivityNo());
            activityNo = Optional.ofNullable(activity).map(a->a.getActivityNo()).orElse("");
            index.addObject("activityNo", activityNo);
        }
        Map<String,String> param = Maps.newHashMap();
        param.put("viewCode", "PSSAB_ABTS");
        param.put("activityNo", "'"+activityNo+"'");
        String token = JwtUtil.createJWT(param);
        index.addObject("url", ConfigUtil.getValue("bi_url") + "/view?token="+token);
        List<Map> activityList = activityService.findActivityByUser(user.getId());
        index.addObject("activityList", activityList);
        index.addObject("menuName", "活动态势");
        request.getSession().setAttribute("currentBiViewCode", "PSSAB_ABTS");
        return index;
    }

    /**
     * 安保态势
     *
     * @param request
     * @return
     */
    @RequestMapping("abts")
    public ModelAndView abts(HttpServletRequest request) {
        ModelAndView index = new ModelAndView("/activity/workbench/cboardView");
        String activityNo = request.getParameter("activityNo");
        User user = super.getCurrentUser(request);
        if (StringUtil.isNotEmpty(request.getParameter("activityNo"))) {
            index.addObject("activityNo", request.getParameter("activityNo"));
        } else if (StringUtil.isNotEmpty(request.getParameter("activityId"))) {
            Activity activity = activityService.findById(Long.parseLong(request.getParameter("activityId")));
            index.addObject("activityNo", Optional.ofNullable(activity).map(a->a.getActivityNo()).orElse(""));
        } else {
            /* 查找最新的一场活动 */
            Activity activity = activityService.findLastActivity(user);
            index.addObject("activityNo", Optional.ofNullable(activity).map(a->a.getActivityNo()).orElse(""));

        }
        Map<String,String> param = Maps.newHashMap();
        param.put("viewCode", "PSSAB_ABTSB");
        param.put("activityNo", "'"+activityNo+"'");
        String token = JwtUtil.createJWT(param);
        index.addObject("url", ConfigUtil.getValue("bi_url") + "/view?token="+token);
        List<Map> activityList = activityService.findActivityByUser(user.getId());
        index.addObject("activityList", activityList);
        index.addObject("menuName", "安保态势");
        index.addObject("menuType", "abts");
        request.getSession().setAttribute("currentBiViewCode", "PSSAB_ABTSB");
        return index;
    }

    /**
     * 人员态势
     *
     * @param request
     * @return
     */
    @RequestMapping("ryts")
    public ModelAndView ryts(HttpServletRequest request) {
        ModelAndView index = new ModelAndView("/activity/workbench/cboardView");
        String activityNo = request.getParameter("activityNo");
        User user = super.getCurrentUser(request);
        if (StringUtil.isNotEmpty(request.getParameter("activityNo"))) {
            index.addObject("activityNo", request.getParameter("activityNo"));
        } else if (StringUtil.isNotEmpty(request.getParameter("activityId"))) {
            Activity activity = activityService.findById(Long.parseLong(request.getParameter("activityId")));
            index.addObject("activityNo", Optional.ofNullable(activity).map(a->a.getActivityNo()).orElse(""));
        } else {
            /* 查找最新的一场活动 */
            Activity activity = activityService.findLastActivity(user);
            index.addObject("activityNo", Optional.ofNullable(activity).map(a->a.getActivityNo()).orElse(""));
        }
        Map<String,String> param = Maps.newHashMap();
        param.put("viewCode", "PSSAB_RYTS");
        param.put("activityNo", "'"+activityNo+"'");
        String token = JwtUtil.createJWT(param);
        index.addObject("url", ConfigUtil.getValue("bi_url") + "/view?token="+token);

        List<Map> activityList = activityService.findActivityByUser(user.getId());
        index.addObject("activityList", activityList);
        index.addObject("menuName", "人员态势");
        index.addObject("menuType", "ryts");
        request.getSession().setAttribute("currentBiViewCode", "PSSAB_RYTS");
        return index;
    }

    /**
     * 票证态势
     *
     * @param request
     * @return
     */
    @RequestMapping("pzts")
    public ModelAndView pzts(HttpServletRequest request) {
        ModelAndView index = new ModelAndView("/activity/workbench/cboardView");
        String activityNo = request.getParameter("activityNo");
        User user = super.getCurrentUser(request);
        if (StringUtil.isNotEmpty(request.getParameter("activityNo"))) {
            index.addObject("activityNo", request.getParameter("activityNo"));
        } else if (StringUtil.isNotEmpty(request.getParameter("activityId"))) {
            Activity activity = activityService.findById(Long.parseLong(request.getParameter("activityId")));
            index.addObject("activityNo", Optional.ofNullable(activity).map(a->a.getActivityNo()).orElse(""));
        } else {
            /* 查找最新的一场活动 */
            Activity activity = activityService.findLastActivity(user);
            index.addObject("activityNo", Optional.ofNullable(activity).map(a->a.getActivityNo()).orElse(""));
        }
        Map<String,String> param = Maps.newHashMap();
        param.put("viewCode", "PSSAB_PZTS");
        param.put("activityNo", "'"+activityNo+"'");
        String token = JwtUtil.createJWT(param);
        index.addObject("url", ConfigUtil.getValue("bi_url") + "/view?token="+token);
        List<Map> activityList = activityService.findActivityByUser(user.getId());
        index.addObject("activityList", activityList);
        index.addObject("menuName", "票证态势");
        index.addObject("menuType", "pzts");
        request.getSession().setAttribute("currentBiViewCode", "PSSAB_PZTS");
        return index;
    }

    /**
     * 车辆态势
     *
     * @param request
     * @return
     */
    @RequestMapping("clts")
    public ModelAndView clts(HttpServletRequest request) {
        ModelAndView index = new ModelAndView("/activity/workbench/cboardView");
        String activityNo = request.getParameter("activityNo");
        User user = super.getCurrentUser(request);
        if (StringUtil.isNotEmpty(request.getParameter("activityNo"))) {
            index.addObject("activityNo", request.getParameter("activityNo"));
        } else if (StringUtil.isNotEmpty(request.getParameter("activityId"))) {
            Activity activity = activityService.findById(Long.parseLong(request.getParameter("activityId")));
            index.addObject("activityNo", Optional.ofNullable(activity).map(a->a.getActivityNo()).orElse(""));
        } else {
            /* 查找最新的一场活动 */
            Activity activity = activityService.findLastActivity(user);
            index.addObject("activityNo", Optional.ofNullable(activity).map(a->a.getActivityNo()).orElse(""));
        }
        Map<String,String> param = Maps.newHashMap();
        param.put("viewCode", "PSSAB_CLTS");
        param.put("activityNo", "'"+activityNo+"'");
        String token = JwtUtil.createJWT(param);
        index.addObject("url", ConfigUtil.getValue("bi_url") + "/view?token="+token);
        List<Map> activityList = activityService.findActivityByUser(user.getId());
        index.addObject("activityList", activityList);
        index.addObject("menuName", "车辆态势");
        index.addObject("menuType", "clts");
        request.getSession().setAttribute("currentBiViewCode", "PSSAB_CLTS");
        return index;
    }

    /**
     * 情报研判
     *
     * @param request
     * @return
     */
    @RequestMapping("qbyp")
    public ModelAndView qbyp(HttpServletRequest request) {
        ModelAndView index = new ModelAndView("/activity/workbench/cboardView");
        User user = super.getCurrentUser(request);
        if (StringUtil.isNotEmpty(request.getParameter("activityNo"))) {
            index.addObject("activityNo", request.getParameter("activityNo"));
        } else if (StringUtil.isNotEmpty(request.getParameter("activityId"))) {
            Activity activity = activityService.findById(Long.parseLong(request.getParameter("activityId")));
            index.addObject("activityNo", Optional.ofNullable(activity).map(a->a.getActivityNo()).orElse(""));
        } else {
            /* 查找最新的一场活动 */
            Activity activity = activityService.findLastActivity(user);
            index.addObject("activityNo", Optional.ofNullable(activity).map(a->a.getActivityNo()).orElse(""));
        }
        index.addObject("url", ConfigUtil.getValue("bi_qbyp_url"));
        List<Map> activityList = activityService.findActivityByUser(user.getId());
        index.addObject("activityList", activityList);
        index.addObject("menuName", "情报研判");
        index.addObject("menuType", "qbyp");

        return index;
    }

    /**
     * 圈层态势
     *
     * @param request
     * @return
     */
    @RequestMapping("qcts")
    public ModelAndView qcts(HttpServletRequest request) {
        ModelAndView index = new ModelAndView("/activity/workbench/cboardView");
        User user = super.getCurrentUser(request);
        if (StringUtil.isNotEmpty(request.getParameter("activityNo"))) {
            index.addObject("activityNo", request.getParameter("activityNo"));
        } else if (StringUtil.isNotEmpty(request.getParameter("activityId"))) {
            Activity activity = activityService.findById(Long.parseLong(request.getParameter("activityId")));
            index.addObject("activityNo", Optional.ofNullable(activity).map(a->a.getActivityNo()).orElse(""));
        } else {
            /* 查找最新的一场活动 */
            Activity activity = activityService.findLastActivity(user);
            index.addObject("activityNo", Optional.ofNullable(activity).map(a->a.getActivityNo()).orElse(""));
        }
        index.addObject("url", ConfigUtil.getValue("bi_qcts_url"));
        List<Map> activityList = activityService.findActivityByUser(user.getId());
        index.addObject("activityList", activityList);
        index.addObject("menuName", "圈层态势");
        return index;
    }

    /**
     * 现场态势
     *
     * @param request
     * @return
     */
    @RequestMapping("xcts")
    public ModelAndView xcts(HttpServletRequest request) {
        ModelAndView index = new ModelAndView("/activity/workbench/cboardView");
        String activityNo = request.getParameter("activityNo");
        User user = super.getCurrentUser(request);
        if (StringUtil.isNotEmpty(request.getParameter("activityNo"))) {
            index.addObject("activityNo", request.getParameter("activityNo"));
        } else if (StringUtil.isNotEmpty(request.getParameter("activityId"))) {
            Activity activity = activityService.findById(Long.parseLong(request.getParameter("activityId")));
            index.addObject("activityNo", Optional.ofNullable(activity).map(a->a.getActivityNo()).orElse(""));
        } else {
            Activity activity = activityService.findLastActivity(user);
            /* 查找最新的一场活动 */
            index.addObject("activityNo", Optional.ofNullable(activity).map(a->a.getActivityNo()).orElse(""));
        }
        Map<String,String> param = Maps.newHashMap();
        param.put("viewCode", "PSSAB_XCTS");
        param.put("activityNo", "'"+activityNo+"'");
        String token = JwtUtil.createJWT(param);
        index.addObject("url", ConfigUtil.getValue("bi_url") + "/view?token="+token);
        List<Map> activityList = activityService.findActivityByUser(user.getId());
        index.addObject("activityList", activityList);
        index.addObject("menuName", "现场态势");
        index.addObject("menuType", "xcts");
        request.getSession().setAttribute("currentBiViewCode", "PSSAB_XCTS");
        return index;
    }

    /**
     * 低慢小态势
     *
     * @param request
     * @return
     */
    @RequestMapping("dmxts")
    public ModelAndView dmxts(HttpServletRequest request) {
        ModelAndView index = new ModelAndView("/activity/workbench/cboardView");
        String activityNo = request.getParameter("activityNo");
        User user = super.getCurrentUser(request);
        if (StringUtil.isNotEmpty(request.getParameter("activityNo"))) {
            index.addObject("activityNo", request.getParameter("activityNo"));
        } else if (StringUtil.isNotEmpty(request.getParameter("activityId"))) {
            Activity activity = activityService.findById(Long.parseLong(request.getParameter("activityId")));
            index.addObject("activityNo", Optional.ofNullable(activity).map(a->a.getActivityNo()).orElse(""));
        } else {
            /* 查找最新的一场活动 */
            Activity activity = activityService.findLastActivity(user);
            index.addObject("activityNo", Optional.ofNullable(activity).map(a->a.getActivityNo()).orElse(""));
        }
        Map<String,String> param = Maps.newHashMap();
        param.put("viewCode", "PSSAB_DMXTS");
        param.put("activityNo", "'"+activityNo+"'");
        String token = JwtUtil.createJWT(param);
        index.addObject("url", ConfigUtil.getValue("bi_url") + "/view?token="+token);
        List<Map> activityList = activityService.findActivityByUser(user.getId());
        index.addObject("activityList", activityList);
        index.addObject("menuName", "低慢小态势");
        index.addObject("menuType", "dmxts");
        request.getSession().setAttribute("currentBiViewCode", "PSSAB_DMXTS");
        return index;
    }

    /**
     * 战果统计
     *
     * @param request
     * @return
     */
    @RequestMapping("zgtj")
    public ModelAndView zgtj(HttpServletRequest request) {
        ModelAndView index = new ModelAndView("/activity/workbench/cboardView");
        String activityNo = request.getParameter("activityNo");
        User user = super.getCurrentUser(request);
        if (StringUtil.isNotEmpty(request.getParameter("activityNo"))) {
            index.addObject("activityNo", request.getParameter("activityNo"));
        } else if (StringUtil.isNotEmpty(request.getParameter("activityId"))) {
            Activity activity = activityService.findById(Long.parseLong(request.getParameter("activityId")));
            index.addObject("activityNo", Optional.ofNullable(activity).map(a->a.getActivityNo()).orElse(""));
        } else {
            /* 查找最新的一场活动 */
            Activity activity = activityService.findLastActivity(user);
            index.addObject("activityNo", Optional.ofNullable(activity).map(a->a.getActivityNo()).orElse(""));
        }
        Map<String,String> param = Maps.newHashMap();
        param.put("viewCode", "PSSAB_ZGTS");
        param.put("activityNo", "'"+activityNo+"'");
        String token = JwtUtil.createJWT(param);
        index.addObject("url", ConfigUtil.getValue("bi_url") + "/view?token="+token);
        List<Map> activityList = activityService.findActivityByUser(user.getId());
        index.addObject("activityList", activityList);
        index.addObject("menuName", "战果统计");
        index.addObject("menuType", "zgtj");
        request.getSession().setAttribute("currentBiViewCode", "PSSAB_ZGTS");
        return index;
    }

    /**
     * 圈层态势
     *
     * @param request
     * @return
     */
    @RequestMapping("qcgl")
    public ModelAndView qcgl(HttpServletRequest request) {
        ModelAndView index = new ModelAndView("/activity/workbench/cboardView");
        String activityNo = request.getParameter("activityNo");
        User user = super.getCurrentUser(request);
        if (StringUtil.isNotEmpty(request.getParameter("activityNo"))) {
            index.addObject("activityNo", request.getParameter("activityNo"));
        } else if (StringUtil.isNotEmpty(request.getParameter("activityId"))) {
            Activity activity = activityService.findById(Long.parseLong(request.getParameter("activityId")));
            index.addObject("activityNo", Optional.ofNullable(activity).map(a->a.getActivityNo()).orElse(""));
        } else {
            /* 查找最新的一场活动 */
            Activity activity = activityService.findLastActivity(user);
            index.addObject("activityNo", Optional.ofNullable(activity).map(a->a.getActivityNo()).orElse(""));
        }
        Map<String,String> param = Maps.newHashMap();
        param.put("viewCode", "PSSAB_QCTS");
        param.put("activityNo", "'"+activityNo+"'");
        String token = JwtUtil.createJWT(param);
        index.addObject("url", ConfigUtil.getValue("bi_url") + "/view?token="+token);

        List<Map> activityList = activityService.findActivityByUser(user.getId());
        index.addObject("activityList", activityList);
        index.addObject("menuName", "圈层态势");
        index.addObject("menuType", "qcts");
        request.getSession().setAttribute("currentBiViewCode", "PSSAB_QCTS");
        return index;
    }


    /**
     * 重大活动
     *
     * @param request
     * @return
     */
    @RequestMapping("zdabsy")
    public ModelAndView zdabsy(HttpServletRequest request) {
        ModelAndView index = new ModelAndView("/activity/workbench/cboardViewWithoutSelect");
        String activityNo = request.getParameter("activityNo");
        User user = super.getCurrentUser(request);
        if (StringUtil.isNotEmpty(request.getParameter("activityNo"))) {
            index.addObject("activityNo", request.getParameter("activityNo"));
        } else if (StringUtil.isNotEmpty(request.getParameter("activityId"))) {
            Activity activity = activityService.findById(Long.parseLong(request.getParameter("activityId")));
            index.addObject("activityNo", Optional.ofNullable(activity).map(a->a.getActivityNo()).orElse(""));
        } else {
            /* 查找最新的一场活动 */
            Activity activity = activityService.findLastActivity(user);
            index.addObject("activityNo", Optional.ofNullable(activity).map(a->a.getActivityNo()).orElse(""));
        }
        Map<String,String> param = Maps.newHashMap();
        param.put("viewCode", "PSSAB_ZDABSY");
        param.put("activityNo", "'"+activityNo+"'");
        String token = JwtUtil.createJWT(param);
        index.addObject("url", ConfigUtil.getValue("bi_url") + "/view?token="+token);

//        List<Map> activityList = activityService.findActivityByUser(user.getId());
//        index.addObject("activityList", activityList);
        index.addObject("menuName", "重大活动态势");
        index.addObject("menuType", "zdabsy ");
        request.getSession().setAttribute("currentBiViewCode", "PSSAB_ZDABSY");
        return index;
    }


    /**
     * 安保首页
     *
     * @param request
     * @return
     */
    @RequestMapping("dxhdsy")
    public ModelAndView dxhdsy(HttpServletRequest request) {
        ModelAndView index = new ModelAndView("/activity/workbench/cboardViewWithoutSelect");
        String activityNo = request.getParameter("activityNo");
        User user = super.getCurrentUser(request);
        if (StringUtil.isNotEmpty(request.getParameter("activityNo"))) {
            index.addObject("activityNo", request.getParameter("activityNo"));
        } else if (StringUtil.isNotEmpty(request.getParameter("activityId"))) {
            Activity activity = activityService.findById(Long.parseLong(request.getParameter("activityId")));
            index.addObject("activityNo", Optional.ofNullable(activity).map(a->a.getActivityNo()).orElse(""));
        } else {
            /* 查找最新的一场活动 */
//            Activity activity = activityService.findLastActivity(user);
//            index.addObject("activityNo", activity.getActivityNo());
        }
        Map<String,String> param = Maps.newHashMap();
        param.put("viewCode", "PSSAB_DXHDSY");
        param.put("activityNo", "'"+activityNo+"'");
        String token = JwtUtil.createJWT(param);
        index.addObject("url", ConfigUtil.getValue("bi_url") + "/view?token="+token);

//        List<Map> activityList = activityService.findActivityByUser(user.getId());
//        index.addObject("activityList", activityList);
        index.addObject("menuName", "大型活动安保态势");
        index.addObject("menuType", "dxhdsy");
        request.getSession().setAttribute("currentBiViewCode", "PSSAB_DXHDSY");
        return index;
    }


	/**
     * 获得token
     *
     * @param request
     * @return
     */
    @RequestMapping("token")
    @ResponseBody
    public Map<String,String> token(HttpServletRequest request) {
        String viewCode = request.getParameter("viewCode");
        String activityNo = request.getParameter("activityNo");
        Map<String,String> param = Maps.newHashMap();
        param.put("viewCode", viewCode);
        param.put("activityNo", "'"+activityNo+"'");
        String token = JwtUtil.createJWT(param);
        param.put("biUrl",ConfigUtil.getValue("bi_url") + "/view?token="+token);
        return param;
    }

}
