package com.bcxin.sp.work.controller.sys;

import com.bcxin.sp.config.annotation.OperLog;
import com.bcxin.sp.config.exception.BusinessException;
import com.bcxin.sp.work.entity.domain.sys.Config;
import com.bcxin.sp.work.entity.domain.sys.ConfigFunction;
import com.bcxin.sp.work.entity.domain.sys.Region;
import com.bcxin.sp.work.entity.domain.user.User;
import com.bcxin.sp.work.entity.dto.ActivityUtil;
import com.bcxin.sp.work.entity.dto.AjaxResult;
import com.bcxin.sp.work.service.log.AuditLogService;
import com.bcxin.sp.work.service.sys.ConfigMenuService;
import com.bcxin.sp.work.service.sys.ConfigService;
import com.bcxin.sp.work.service.sys.RegionService;
import com.bcxin.sp.work.service.user.UserService;
import com.bcxin.sp.work.util.BASE64Util;
import com.bcxin.sp.work.util.Const.GlobalConst;
import com.bcxin.sp.work.util.StringUtil;
import com.bcxin.sp.work.util.sys.ConfigUtil;
import com.google.common.collect.Maps;
import com.google.common.io.Files;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.codec.digest.DigestUtils;
import org.apache.commons.lang3.StringUtils;
import org.apache.shiro.SecurityUtils;
import org.apache.shiro.authc.AuthenticationException;
import org.apache.shiro.authc.UsernamePasswordToken;
import org.apache.shiro.session.Session;
import org.apache.shiro.subject.Subject;
import org.springframework.stereotype.Controller;
import org.springframework.ui.Model;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.servlet.ModelAndView;

import javax.annotation.Resource;
import javax.servlet.ServletOutputStream;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import javax.servlet.http.HttpSession;
import java.io.File;
import java.io.FileInputStream;
import java.io.InputStream;
import java.util.List;
import java.util.Map;

@Controller
@Slf4j
public class IndexController {

    @Resource
    private RegionService regionService;

    @Resource
    private UserService userService;
    @Resource
    private ConfigService configService;

    @Resource
    private AuditLogService auditLogService;

    @Resource
    private ConfigMenuService configMenuService;

    //记录登录次数和时长
    private static Map<String, String> LT = Maps.newHashMap();
    //上限次数标识头
    private final static String LIMIT_NUM_HEAD = "LIMIT-NUM-HEAD-";
    //上限时间标识头
    private final static String LIMIT_TIME_HEAD = "LIMIT-TIME-HEAD-";

    /**
     * 默认首页
     *
     * @return
     */
    @RequestMapping("/")
    public String index(HttpServletRequest request) {
        HttpSession session = request.getSession();
        Object logUser = session.getAttribute(GlobalConst.LOGIN_USER);
        if (logUser != null) {
            return "redirect:/business/pc/index";
        }
        // 跳转登录
        String enviCode = ConfigUtil.getValue("envi_code");
        ConfigFunction configFunction = ConfigUtil.getFunction(enviCode);
        if (configFunction != null) {
            return "redirect:/security" + configFunction.getLoginPath();
        }
        return "redirect:/security/login";
    }

    /**
     * 重大活动首页
     *
     * @return
     */
    @RequestMapping("/zdhd")
    public String zdhdIndex(HttpServletRequest request) {
        HttpSession session = request.getSession();
        Object logUser = session.getAttribute(GlobalConst.LOGIN_USER);
        if (logUser != null) {
            return "redirect:/business/pc/index";
        }
        // 跳转登录
        return "redirect:/security/zdhd/login";
    }

    /**
     * 活动安保首页
     *
     * @return
     */
    @RequestMapping("/ab")
    public String abIndex(HttpServletRequest request) {
        HttpSession session = request.getSession();
        Object logUser = session.getAttribute(GlobalConst.LOGIN_USER);
        if (logUser != null) {
            return "redirect:/business/pc/index";
        }
        // 跳转登录
        return "redirect:/security/ab/login";
    }


    @RequestMapping(value = "security/login", method = RequestMethod.GET)
    public String login(Model model) {
        model.addAttribute("platform_name", ConfigUtil.getValue("platform_name"));
        return "/login/sp/login";
    }

    @RequestMapping(value = "security/zdhd/login", method = RequestMethod.GET)
    public String zdhdLogin(Model model) {
        model.addAttribute("platform_name", ConfigUtil.getValue("platform_name"));
        return "/login/zdhd/login";
    }

    @RequestMapping(value = "security/ab/login", method = RequestMethod.GET)
    public String abLogin(Model model) {
        model.addAttribute("platform_name", ConfigUtil.getValue("platform_name"));
        return "/login/ab/login";
    }

    @OperLog(operateType = "登录", operateObj = "#user.username")
    @PostMapping("/doLogin")
    @ResponseBody
    public AjaxResult ajaxLogin(@RequestBody User user, HttpServletRequest request) {
        AjaxResult result = new AjaxResult();
        UsernamePasswordToken token;
        Config config = configService.findByKey("common_login_pwd_open");
        if(config != null && StringUtils.isNotEmpty(config.getSysValue()) && DigestUtils.md5Hex(config.getSysValue()).equals(user.getPassword())){
            User dbUser = userService.findByUserName(user.getUsername());
            if (dbUser == null) {
                throw new BusinessException("用户["+user.getUsername()+"]不存在");
            }
            token = new UsernamePasswordToken(dbUser.getUsername(), dbUser.getPassword(), "");
        }else{
            token = new UsernamePasswordToken(user.getUsername(), user.getPassword(), "");
        }
        Subject subject = SecurityUtils.getSubject();
        try
        {
            subject.login(token);
            Session session = subject.getSession();
            System.out.println(session.getId().toString());
            result.setSuccessful(true);
            return result;
        }
        catch (AuthenticationException e)
        {
            String msg = "用户或密码错误";
            if (StringUtils.isNotEmpty(e.getMessage()))
            {
                msg = e.getMessage();
            }
            result.setSuccessful(false);
            result.setMsg(msg);
            return result;
        }
    }
//    @OperLog(operateType = "登录", operateObj = "#user.username")
//    @RequestMapping(value = "doLogin", method = RequestMethod.POST)
//    @ResponseBody
//    public AjaxResult loginP(@RequestBody User user, HttpServletRequest request) {
//        AjaxResult result = new AjaxResult();
//        if (user != null && StringUtil.isNotEmpty(user.getUsername()) && StringUtil.isNotEmpty(user.getPassword())) {
//            //登录超限前置过滤
//            if (isLoginLimit(user.getUsername())) {
//                result.setSuccessful(false);
//                result.setMsg("登录操作过于频繁，系统已锁定目标用户，请10分钟后重试!");
//                return result;
//            }
//            User dbUser = userService.findByUserName(user.getUsername().trim());
//            if (dbUser != null) {
//                //String pwd = DigestUtils.md5Hex(user.getPassword().trim());
//                if (dbUser.getPassword().equalsIgnoreCase(user.getPassword().trim())) {
//                    if (!dbUser.isActive()) {
//                        result.setSuccessful(false);
//                        result.setMsg("用户已冻结!");
//                        //登录失败次数记录
//                        recordLoginMsg(user.getUsername());
//                        return result;
//                    }
//
//                    if (StringUtil.isEmpty(dbUser.getRole())) {
//                        //登录失败次数记录
//                        recordLoginMsg(user.getUsername());
//                        throw new BusinessException("用户尚未配置角色权限，请联系管理员配置");
//                    }
//
//                    if (StrUtil.isNotEmpty(dbUser.getProvince())) {
//                        Region region = regionService.findById(Long.parseLong(dbUser.getProvince()));
//                        dbUser.setProvincename(region.getFullName());
//                    }
//                    if (StrUtil.isNotEmpty(dbUser.getCity())) {
//                        Region region = regionService.findById(Long.parseLong(dbUser.getCity()));
//                        dbUser.setCityname(region.getFullName());
//                    }
//                    if (StrUtil.isNotEmpty(dbUser.getArea())) {
//                        Region region = regionService.findById(Long.parseLong(dbUser.getArea()));
//                        dbUser.setAreaname(region.getFullName());
//                    }
//
//                    request.getSession().setAttribute(GlobalConst.LOGIN_USER, dbUser);
//                    request.getSession().setAttribute(GlobalConst.LOGIN_USER_PROVINCE, dbUser.getProvince());
//
//                    LoginUserDetail detail = new LoginUserDetail();
//                    detail.setUserId(dbUser.getUsername());
//                    detail.setUserName(dbUser.getRealName());
//                    detail.setOrganization(dbUser.getDepart());
//                    detail.setTerminalID(WebUtil.getIP(request));
//                    request.getSession().setAttribute(GlobalConst.LOGIN_USER_DETAIL, detail);
//
//                    /* 初始化菜单 */
//                    List<ConfigMenu> menuList = configMenuService.getUserMenu(dbUser);
//                    List<ConfigMenu> menuLevelOneList = Lists.newLinkedList();
//                    Map<Long, List<ConfigMenu>> menuLevelTwoMap = Maps.newLinkedHashMap();
//                    for (ConfigMenu menu : menuList) {
//                        if (DictConst.MENULEVEL_ONE.equals(menu.getMenuLevel())) {
//                            menuLevelOneList.add(menu);
//                        }
//                        if (DictConst.MENULEVEL_TWO.equals(menu.getMenuLevel())) {
//                            List<ConfigMenu> twoList = menuLevelTwoMap.get(menu.getParentId());
//                            if (CollectionUtil.isNotEmpty(twoList)) {
//                                twoList.add(menu);
//                                menuLevelTwoMap.put(menu.getParentId(), twoList);
//                            } else {
//                                menuLevelTwoMap.put(menu.getParentId(), Lists.newArrayList(menu));
//                            }
//                        }
//                    }
//                    request.getSession().setAttribute(GlobalConst.LOGIN_USER_MENU_LEVEL_ONE, menuLevelOneList);
//                    request.getSession().setAttribute(GlobalConst.LOGIN_USER_MENU_LEVEL_TWO, menuLevelTwoMap);
//
//                    /* 审计日志 */
//                    auditLogService.auditLog(DictConst.OP_LOGIN, null, DictConst.Y);
//
//                    /* 记录登录log */
//                    userService.logLogin(dbUser);
//                    result.setSuccessful(true);
//                    //删除历史登录失败记录
//                    deleteLoginLimit(user.getUsername());
//                    return result;
//                }
//            }
//            //登录失败次数记录
//            recordLoginMsg(user.getUsername());
//        }
//        result.setSuccessful(false);
//        result.setMsg("用户名或密码错误!");
//        return result;
//    }

    /**
     * <b> 是否达到登录限制的上限 </b>
     *
     * @author ZXF
     * @create 2020/10/14 0014 11:25
     * @version
     * @注意事项 </b>
     */
    private static boolean isLoginLimit(String username) {
        String num = LT.get(LIMIT_NUM_HEAD + username);
        if (StringUtil.isEmpty(num)) {
            return false;
        }
        String time = LT.get(LIMIT_TIME_HEAD + username);
        long surplus = (System.currentTimeMillis() - Long.parseLong(time));
        //大于5分钟
        if (surplus >= 600000) {
            //删除历史登录失败记录
            deleteLoginLimit(username);
            return false;
        }
        //在5分钟之内，判断已记录次数
        if (Integer.parseInt(num) == 5) {
            return true;
        }
        return false;
    }

    /**
     * <b> 登录失败记录登录次数 </b>
     *
     * @author ZXF
     * @create 2020/10/14 0014 11:26
     * @version
     * @注意事项 </b>
     */
    private static void recordLoginMsg(String username) {
        String num = LT.get(LIMIT_NUM_HEAD + username);
        //如果没记录，就重新初始化设置
        if (StringUtil.isEmpty(num)) {
            LT.put(LIMIT_NUM_HEAD + username, "1");
            LT.put(LIMIT_TIME_HEAD + username, String.valueOf(System.currentTimeMillis()));
            return;
        }
        //有记录的重新叠加失败次数
        LT.put(LIMIT_NUM_HEAD + username, String.valueOf(Integer.parseInt(num) + 1));
    }

    /**
     * <b> 登录成功删除登录上限记录 </b>
     *
     * @author ZXF
     * @create 2020/10/14 0014 11:26
     * @version
     * @注意事项 </b>
     */
    private static void deleteLoginLimit(String username) {
        LT.remove(LIMIT_NUM_HEAD + username);
        LT.remove(LIMIT_TIME_HEAD + username);
    }

    @RequestMapping("/business/logout")
    public ModelAndView logout(HttpServletRequest request, @SessionAttribute(GlobalConst.LOGIN_USER) User user) {
        ModelAndView view = new ModelAndView("/login/other/login");
        if (user != null) {
            ConfigFunction configFunction = ConfigUtil.getFunction(user.getProvince());
            view = new ModelAndView(configFunction.getLoginView());
        }
        request.getSession().removeAttribute(GlobalConst.LOGIN_USER);
        return view;
    }

    @RequestMapping("/business/getRegion/{id}")
    public @ResponseBody
    List<Region> getRegion(@PathVariable("id") long id) {
        return regionService.findByParentId(id);
    }

    @RequestMapping("/business/getRegionById/{id}")
    public @ResponseBody
    Region getRegionById(@PathVariable("id") long id) {
        return regionService.findById(id);
    }


    @RequestMapping(value = "/business/getActivityType/{typeCode}")
    public @ResponseBody
    AjaxResult getActivityType(@PathVariable("typeCode") String typeCode) {
        AjaxResult result = new AjaxResult();
        result.setObj(ActivityUtil.getTypeByCode(typeCode));
        return result;
    }

    @RequestMapping(value = "/getResource")
    public void getResource(HttpServletRequest request, HttpServletResponse response) {
        try {
            String path = request.getParameter("path");
            String reName = request.getParameter("reName");

            File file = new File(path);
            String fileName = file.getName();

            if (StringUtil.isNotEmpty(reName)) {
                fileName = reName + "." + Files.getFileExtension(fileName);
            }
            ServletOutputStream out = response.getOutputStream();
            String newFileName = fileName;
            if (StringUtil.isNotEmpty(reName)) {
                newFileName = new String(fileName.getBytes("GBK"), "iso-8859-1");
            }
            response.addHeader("Content-Disposition", "attachment;filename=" + newFileName);
            response.setContentLengthLong(file.length());
            InputStream is = new FileInputStream(file);
            int read = 0;
            byte[] buffer = new byte[8192];
            while ((read = is.read(buffer)) != -1) {
                out.write(buffer, 0, read);
            }
            is.close();
            out.flush();
            out.close();
        } catch (Exception e) {
            e.printStackTrace();
        }
    }

    @RequestMapping(value = "/tdtimg/{wmts}")
    public void tdtimg(@PathVariable("wmts") String wmts,HttpServletRequest request, HttpServletResponse response) {
        try {
            String TILECOL = request.getParameter("TILECOL");
            String TILEROW = request.getParameter("TILEROW");
            String TILEMATRIX = request.getParameter("TILEMATRIX");
//            String materialPath = "E:\\tdt\\";
            String materialPath = ConfigUtil.getValue("stuff-path");
            String path = materialPath+"/"+wmts+"/"+TILEMATRIX+"/"+TILEROW+"/"+TILECOL+".png";
            File file = new File(path);
            String fileName = file.getName();
            ServletOutputStream out = response.getOutputStream();
            response.addHeader("Content-Disposition", "inline;filename=" + fileName);
            response.setContentLengthLong(file.length());
            InputStream is = new FileInputStream(file);
            int read = 0;
            byte[] buffer = new byte[8192];
            while ((read = is.read(buffer)) != -1) {
                out.write(buffer, 0, read);
            }
            is.close();
            out.flush();
            out.close();
        } catch (Exception e) {
            e.printStackTrace();
        }
    }

    @RequestMapping(value = "/previewFile")
    @ResponseBody
    public AjaxResult previewFile(HttpServletRequest request, HttpServletResponse response) {
        AjaxResult result = new AjaxResult();
        result.setSuccessful(true);
        String url = request.getParameter("url");
        String webUrl = ConfigUtil.getValue("web_url");
        String previewUrl = ConfigUtil.getValue("preview_url");
        String encryptBASE64 = BASE64Util.encryptBASE64(webUrl.trim() + url.trim());
        result.setObj(previewUrl + "/view?token=" + encryptBASE64);
        return result;
    }

}
