package com.bcxin.sp.work.controller.sys;

import com.bcxin.sp.config.annotation.AuditLogAn;
import com.bcxin.sp.config.annotation.SysManageAuth;
import com.bcxin.sp.work.entity.domain.sys.SlMsgTemplate;
import com.bcxin.sp.work.entity.domain.user.User;
import com.bcxin.sp.work.entity.dto.AjaxResult;
import com.bcxin.sp.work.service.sys.SlMsgTemplateService;
import com.bcxin.sp.work.util.Const.DictConst;
import com.bcxin.sp.work.util.Const.MenuConst;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.servlet.ModelAndView;

import javax.servlet.http.HttpServletRequest;
import java.text.ParseException;

/**
 * 受理短信模板，通知承办方去领取受理许可书
 */
@Controller
@RequestMapping("/business/sl")
public class SLMsgTemplateController extends BaseController {

    @Autowired
    private SlMsgTemplateService slMsgTemplateService;

    @RequestMapping("/initNew")
    @SysManageAuth(limitRole = DictConst.ROLE_APPROVE)
    public ModelAndView initNew(HttpServletRequest request) {
        ModelAndView view = new ModelAndView("/sys/slMsgTemplateNew");
        User user = super.getCurrentUser(request);
        SlMsgTemplate slMsgTemplate = slMsgTemplateService.findTemplateByArea(user);
        view.addObject("sl",slMsgTemplate);
        return view;
    }


    @RequestMapping("/init")
    @SysManageAuth(limitRole = DictConst.ROLE_APPROVE)
    public ModelAndView list(HttpServletRequest request) {
        ModelAndView view = new ModelAndView("/sys/slMsgTemplate");
        User user = super.getCurrentUser(request);
        SlMsgTemplate slMsgTemplate = slMsgTemplateService.findTemplateByArea(user);
        view.addObject("sl",slMsgTemplate);
        return view;
    }

    @AuditLogAn(operateType = DictConst.OP_SELECT,menuName = MenuConst.XTPZ_DXMB_SLDXMB_TJ)
    @RequestMapping("createOrUpdate")
    public @ResponseBody
    AjaxResult createOrUpdate(SlMsgTemplate slMsgTemplate, HttpServletRequest request) throws ParseException {
        User user = super.getCurrentUser(request);
        if ( slMsgTemplate.getId() == null) {
            slMsgTemplateService.save(slMsgTemplate,user);
        } else {
            slMsgTemplateService.update(slMsgTemplate);
        }
        AjaxResult result = new AjaxResult();
        result.setSuccessful(true);
        result.setObj(slMsgTemplate);
        return result;
    }

    @AuditLogAn(operateType = DictConst.OP_UPDATE,menuName = MenuConst.XTPZ_DXMB_SLDXMB_QY)
    @RequestMapping("enable")
    public @ResponseBody
    AjaxResult enable(HttpServletRequest request) throws ParseException {
        String id = request.getParameter("id");
        SlMsgTemplate slMsgTemplate = slMsgTemplateService.findById(Long.parseLong(id));
        slMsgTemplate.setActive(DictConst.Y);
        slMsgTemplateService.update(slMsgTemplate);
        AjaxResult result = new AjaxResult();
        result.setSuccessful(true);
        result.setObj(slMsgTemplate);
        return result;
    }

    @AuditLogAn(operateType = DictConst.OP_DELETE,menuName = MenuConst.XTPZ_DXMB_SLDXMB_TY)
    @RequestMapping("freeze")
    public @ResponseBody
    AjaxResult freeze(HttpServletRequest request) throws ParseException {
        String id = request.getParameter("id");
        SlMsgTemplate slMsgTemplate = slMsgTemplateService.findById(Long.parseLong(id));
        slMsgTemplate.setActive(DictConst.N);
        slMsgTemplateService.update(slMsgTemplate);
        AjaxResult result = new AjaxResult();
        result.setSuccessful(true);
        result.setObj(slMsgTemplate);
        return result;
    }

}
