/**
 * date: 2020-05-28 16:31
 * copyright(c) 2015-2020 百川信
 */
package com.bcxin.sp.work.controller.third.bim;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONArray;
import com.bcxin.sp.config.task.bim.BimConfig;
import com.bcxin.sp.work.controller.sys.BaseController;
import com.bcxin.sp.work.entity.PageResult;
import com.bcxin.sp.work.entity.domain.base.Venue;
import com.bcxin.sp.work.entity.domain.third.bim.Drawing;
import com.bcxin.sp.work.entity.domain.third.bim.DrawingLabel;
import com.bcxin.sp.work.entity.domain.user.User;
import com.bcxin.sp.work.entity.dto.AjaxResult;
import com.bcxin.sp.work.entity.dto.SearchDto;
import com.bcxin.sp.work.entity.dto.accident.ActivityIsrSearchDTO;
import com.bcxin.sp.work.service.base.VenueService;
import com.bcxin.sp.work.service.third.bim.DrawingLabelService;
import com.bcxin.sp.work.service.third.bim.DrawingService;
import com.bcxin.sp.work.util.sys.ConfigUtil;
import com.bimface.api.bean.request.translate.FileTranslateRequest;
import com.bimface.api.bean.request.translate.TranslateSource;
import com.bimface.api.bean.response.FileTranslateBean;
import com.bimface.exception.BimfaceException;
import com.bimface.file.bean.FileBean;
import com.bimface.sdk.BimfaceClient;
import com.bimface.sdk.bean.request.FileUploadRequest;
import com.google.gson.Gson;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;
import org.springframework.web.servlet.ModelAndView;

import javax.annotation.Resource;
import javax.servlet.ServletException;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.io.IOException;
import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;

/**
 * @author: jianjun.wang
 * @description: bim图纸
 * @data: 2020-05-28 16:31
 **/
@Controller
@RequestMapping("/bim")
@Slf4j
public class BimController extends BaseController {

    public static BimfaceClient bimfaceClient = null;

    @Resource
    private DrawingService drawingService;

    @Resource
    private VenueService venueService;

    @Resource
    private DrawingLabelService drawingLabelService;

    private BimfaceClient bimfaceClient(){
        if(bimfaceClient==null){
            bimfaceClient = new BimfaceClient(ConfigUtil.getValue("BIM_KEY"), ConfigUtil.getValue("BIM_SECRET"));
        }
        return bimfaceClient;
    }
    /**
     * 图纸列表-页面
     * @author wangjianjun
     * @date 2020/6/3
     */
    @RequestMapping("/list")
    public ModelAndView list(HttpServletRequest request) throws Exception {
        ModelAndView view = new ModelAndView("/activity/bim/drawing");
        List<Venue> venues = venueService.findAll();
        view.addObject("venues", venues);
        return view;
    }

    /**
     * 图纸列表-页面
     * @author wangjianjun
     * @date 2020/6/3
     */
    @RequestMapping("/listPreview")
    public ModelAndView listPreview(HttpServletRequest request) throws Exception {
        ModelAndView view = new ModelAndView("/activity/bim/drawing_preview");
        List<Venue> venues = venueService.findAll();
        view.addObject("venues", venues);
        return view;
    }

    /**
     * 创建或者修改图纸
     * @author wangjianjun
     * @date 2020/6/3
     */
    @RequestMapping("createOrUpdate")
    public @ResponseBody
    AjaxResult createOrUpdate(Drawing approveRole, HttpServletRequest request) {
        User cuser = super.getCurrentUser(request);
        if (approveRole.getId() == null) {
            approveRole.setAddTime(new Date());
            drawingService.insert(approveRole);
        } else {
            approveRole.setUpdateTime(new Date());
            drawingService.updateByPrimaryKey(approveRole);
        }
        AjaxResult result = new AjaxResult();
        result.setSuccessful(true);
        result.setObj(approveRole);
        return result;
    }

    /**
     * 删除图纸
     * @author wangjianjun
     * @date 2020/6/3
     */
    @RequestMapping("delete")
    public @ResponseBody
    AjaxResult delete(Drawing approveRole) {
        drawingService.deleteByPrimaryKey(approveRole.getId());
        AjaxResult result = new AjaxResult();
        result.setSuccessful(true);
        result.setObj(approveRole);
        return result;
    }

    /**
     * 图纸列表，不分页
     * @author wangjianjun
     * @date 2020/6/3
     */
//    @RequestMapping("findData")
//    public @ResponseBody
//    List<Drawing> findData(HttpServletRequest request) throws Exception {
////        User user = super.getCurrentUser(request);
//        return drawingService.findAll();
//    }

    /**
     * 图纸列表，分页
     * @author wangjianjun
     * @date 2020/6/3
     */
    @RequestMapping("findData")
    @ResponseBody
    public SearchDto<Drawing> findActivityIsrListData(ActivityIsrSearchDTO dto) {
        PageResult pageResult = drawingService.findAll(dto);
        List<Drawing> resultList = (List<Drawing>) pageResult.getRows();
        SearchDto<Drawing> result = new SearchDto<>();
        result.setData(resultList);
        result.setIDisplayStart(dto.getIDisplayStart());
        result.setIDisplayLength(dto.getIDisplayLength());
        result.setITotalRecords(pageResult.getTotal());
        result.setITotalDisplayRecords(pageResult.getTotal());
        return result;
    }

    /**
     * 预览
     *
     * @author wangjianjun
     * @date 2020/5/29
     */
    @GetMapping("/view")
    public ModelAndView view(HttpServletRequest request, HttpServletResponse response) throws ServletException, IOException {

        // 获取参数值
        String fileId = request.getParameter("fileId");
        String fullName = request.getParameter("fullName");
        String name = request.getParameter("name");
        String fileType = request.getParameter("fileType");

        // 获取view token
        String viewToken = null;
        try {
            viewToken = bimfaceClient().getViewTokenByFileId(Long.valueOf(fileId));
        } catch (NumberFormatException e) {
        } catch (BimfaceException e) {
        }

        ModelAndView view = new ModelAndView("/activity/bim/view");
        if("2".equalsIgnoreCase(fileType)){
            view = new ModelAndView("/activity/bim/view3d");
        }

        if("1896948461340768".equals(fileId)){
            view = new ModelAndView("/activity/bim/viewLabel");
        }
        if("1900821292935264".equals(fileId)){//馆内
            view = new ModelAndView("/activity/bim/viewGuannei");
        }
        if("2027177107704096,2025816118831392".indexOf(fileId)>-1){
            view = new ModelAndView("/activity/bim/viewHospital");
        }
        //设置背景透明、去掉viewHouse等，用于物可视
        if("1896936872290272".equals(fileId)){
            view = new ModelAndView("/activity/bim/wukeshi");
        }
        if("2011775863924736".equals(fileId)){
            view = new ModelAndView("/redirect");
            view.addObject("url", request.getContextPath()+"/bim/65f80e6f8117b0564e4abd8d724b3d95/index.html");
        }
        if("2011775915100352".equals(fileId)){
            view = new ModelAndView("/redirect");
            view.addObject("url", request.getContextPath()+"/bim/8b5ce03c1965550cd344f578ab27b371/index.html");
        }
        //sss
//        if("2162474550323648".equals(fileId)){
//            view = new ModelAndView("/redirect");
//            view.addObject("url", request.getContextPath()+"/bim/view/国际汽车展览会场馆.html");
//        }

        if("2162474550323648".equals(fileId)){
            view = new ModelAndView("/redirect");
            view.addObject("url", request.getContextPath()+"/bim/09678b61c87efcb54d6efe342fd6e2e5/index.html");
        }
        view.addObject("viewToken", viewToken);
        view.addObject("fullName", fullName);
        view.addObject("name", name);
        view.addObject("fileId",fileId);
        //根据fileId找出所有的坐标和文字
        List<DrawingLabel> labels=drawingLabelService.selectAllByFileId(fileId);
        List<String> positions = labels.stream().map(p -> p.getWorldPosition()).collect(Collectors.toList());
        List<String> texts = labels.stream().map(p -> p.getText()).collect(Collectors.toList());
        List<String> labelIds = labels.stream().map(p -> p.getViewToken()).collect(Collectors.toList());

        view.addObject("positions",positions);
        view.addObject("texts", JSONArray.parseArray(JSON.toJSONString(texts)));
        view.addObject("labelIds", JSONArray.parseArray(JSON.toJSONString(labelIds)));


        return view;
    }

    /**
     * 上传
     *
     * @author wangjianjun
     * @date 2020/5/29
     */
    @PostMapping("/upload")
    public void upload(HttpServletRequest request, HttpServletResponse response, @RequestParam("file") MultipartFile file) throws ServletException, IOException {
        //上传文件
        FileBean fileBean = null;
        try {
            FileUploadRequest fileUploadRequest = new FileUploadRequest();
            fileUploadRequest.setContentLength(file.getSize());
            fileUploadRequest.setName(file.getOriginalFilename());
            fileUploadRequest.setInputStream(file.getInputStream());
            fileBean = bimfaceClient().upload(fileUploadRequest);
        } catch (BimfaceException e) {
            System.out.println(e.getMessage());
        }

        // 获取fileId
        Long fileId = fileBean.getFileId();

        // 发起文件转换
        FileTranslateBean translateBean = null;
        try {
            FileTranslateRequest fileTranslateRequest=new FileTranslateRequest();
            TranslateSource source=new TranslateSource();
            source.setFileId(fileId);
            Map<String, String> config=new HashMap<>();
            if(file.getOriginalFilename().contains(".zip")) {
                source.setRootName("北京展览馆.fbx");
                source.setCompressed(true);
                config.put("texture","true");
            }
            if(file.getOriginalFilename().contains(".obj")) {

            }
            fileTranslateRequest.setSource(source);
            fileTranslateRequest.setConfig(config);
            translateBean = bimfaceClient().translate(fileTranslateRequest);
        } catch (BimfaceException e) {
        }

        Gson gson = new Gson();
        response.getWriter().write(gson.toJson(translateBean));
    }


    /**
     * 获取文件转换状态
     *
     * @author wangjianjun
     * @date 2020/5/28
     */
    @GetMapping("/pull")
    public void pull(HttpServletRequest request, HttpServletResponse response) throws IOException {
        String fileId = request.getParameter("fileId");

        //调用BIMFACE-SDK获取文件转换状态
        FileTranslateBean translateBean = null;
        try {
            translateBean = bimfaceClient().getTranslate(Long.valueOf(fileId));
        } catch (NumberFormatException e) {
        } catch (BimfaceException e) {
            e.printStackTrace();
        }

        //// JSON序列化
        Gson gson = new Gson();
        response.getWriter().write(gson.toJson(translateBean));
    }

    /**
     * 保存或者修改引线标签
     * @author wangjianjun
     * @date 2020/6/3
     */
    @RequestMapping("saveLabel")
    public @ResponseBody
    AjaxResult saveLabel(DrawingLabel drawingLabel,  HttpServletRequest request) {
        //先查询吧
        DrawingLabel labelDb=drawingLabelService.selectByViewToken(drawingLabel.getViewToken());

        if (labelDb == null) {
            drawingLabelService.insert(drawingLabel);
        } else {
            labelDb.setText(drawingLabel.getText());
            drawingLabelService.updateByViewToken(labelDb);
        }
        AjaxResult result = new AjaxResult();
        result.setSuccessful(true);
        result.setObj(drawingLabel);
        return result;
    }

    /**
     * 删除标签
     * @author wangjianjun
     * @date 2020/6/3
     */
    @RequestMapping("deleteLabel")
    public @ResponseBody
    AjaxResult deleteLabel(DrawingLabel drawingLabel) {
        drawingLabelService.deleteByFileIdAndViewToken(drawingLabel.getFileId(),drawingLabel.getViewToken());
        AjaxResult result = new AjaxResult();
        result.setSuccessful(true);
        result.setObj(drawingLabel);
        return result;
    }



}


