package com.bcxin.sp.work.controller.user;

import cn.hutool.core.date.DateUnit;
import cn.hutool.core.date.DateUtil;
import com.bcxin.sp.config.annotation.AuditLogAn;
import com.bcxin.sp.config.annotation.OperLog;
import com.bcxin.sp.config.annotation.SysManageAuth;
import com.bcxin.sp.work.controller.sys.BaseController;
import com.bcxin.sp.work.entity.domain.activity.approve.ApproveRole;
import com.bcxin.sp.work.entity.domain.user.User;
import com.bcxin.sp.work.entity.dto.AjaxResult;
import com.bcxin.sp.work.entity.dto.SearchDto;
import com.bcxin.sp.work.entity.dto.UserSummarySearchDto;
import com.bcxin.sp.work.service.activity.approve.ApproveRoleService;
import com.bcxin.sp.work.service.user.UserService;
import com.bcxin.sp.work.util.Const.DictConst;
import com.bcxin.sp.work.util.Const.MenuConst;
import com.bcxin.sp.work.util.StringUtil;
import com.bcxin.sp.work.util.sys.ConfigUtil;
import org.apache.commons.codec.digest.DigestUtils;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.servlet.ModelAndView;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;
import java.util.Date;
import java.util.List;
import java.util.Objects;
import java.util.regex.Pattern;

/**
 * 用户管理
 * @author 罗鹏
 */
@Controller
@RequestMapping("/business/user")
public class UserController extends BaseController {

    @Resource
    private UserService userService;

    @Resource
    private ApproveRoleService approveRoleService;

    @RequestMapping("/list")
    @SysManageAuth(limitRole = DictConst.ROLE_APPROVE)
    public ModelAndView list(HttpServletRequest request) {
        User cuser = super.getCurrentUser(request);
        ModelAndView view = new ModelAndView("/user/user");
        if (DictConst.ROLE_SUPERADMIN.equals(cuser.getRole()) ) {
            view.addObject("roles", DictConst.fullRoleList());
        } else {
            view.addObject("roles", DictConst.simpleRoleList());
        }
        List<ApproveRole> approveRoles = approveRoleService.findByRegion(cuser.getProvince(), cuser.getCity(), cuser.getArea());
        view.addObject("approveRoles", approveRoles);
        view.addObject("envi", ConfigUtil.getValue("envi"));
        view.addObject("areaCode", request.getParameter("areaCode"));
        view.addObject("role", request.getParameter("role"));
        view.addObject("active", request.getParameter("active"));
        //隐藏左边菜单树标记
        view.addObject("hiddenLeft",request.getParameter("hiddenLeft"));
        return view;
    }

    @AuditLogAn(operateType = DictConst.OP_SAVE,menuName = MenuConst.XTPZ_YHPZ_TJYH)
    @OperLog(menuName = "用户配置",operateType = "#id",operateTypeMethod="transferUser",operateObj = "#realName")
    @RequestMapping("createOrUpdate")
    @ResponseBody
    public AjaxResult createOrUpdate(User user, HttpServletRequest request) {
        AjaxResult result = new AjaxResult();
        User dbUser = userService.findByUserName(user.getUsername().trim());
        if (user.getId() == null && dbUser != null) {
            result.setSuccessful(false);
            result.setMsg("用户名已存在！");
            return result;
        }

        // 校验密码
        if ("on".equalsIgnoreCase(ConfigUtil.getValue("switch_passPolicy"))) {//是否开户密码规则策略
            String reg = "^(?![a-zA-Z]+$)(?![0-9]+$)(?![._~!@#$^&*]+$)(?![0-9a-zA-Z]+$)(?![0-9._~!@#$^&*]+$)(?![a-zA-Z._~!@#$^&*]+$)[A-Za-z0-9._~!@#$^&*]{8,20}$";
            boolean isMatch = Pattern.matches(reg, user.getPassword());
            if (!isMatch) {
                result.setMsg("密码长度最少8个字符，包含大小写字母、特殊符号和数字");
                result.setSuccessful(false);
                return result;
            }
        }

        User cuser = super.getCurrentUser(request);
        user.setUpdater(cuser.getUsername());

        if (Objects.equals(user.getProvince(), "0")) {
            user.setProvince(null);
            user.setCity(null);
            user.setArea(null);
            user.setRegionLevel(0);
        } else if (Objects.equals(user.getCity(), "0")) {
            user.setCity(null);
            user.setArea(null);
            user.setRegionLevel(1);
        } else if (Objects.equals(user.getArea(), "0")) {
            user.setProvince(user.getProvince());
            user.setArea(null);
            user.setRegionLevel(2);
        } else {
            user.setRegionLevel(3);
        }

        if (Objects.equals(user.getRole(), DictConst.ROLE_ADMIN)) {
            user.setRole(DictConst.ROLE_ADMIN);
            user.setWorkRole(null);
        } else if (Objects.equals(user.getRole(), DictConst.ROLE_READ)) {
            user.setRole(DictConst.ROLE_READ);
            user.setWorkRole(null);
        } else if (Objects.equals(user.getRole(), DictConst.ROLE_DOWNLOAD)) {
            user.setRole(DictConst.ROLE_DOWNLOAD);
            user.setWorkRole(null);
        } else if (Objects.equals(user.getRole(), DictConst.ROLE_APPROVE)){
            user.setRole(DictConst.ROLE_APPROVE);
        } else if (Objects.equals(user.getRole(), DictConst.ROLE_ADMIN_APPROVE)){
            user.setRole(DictConst.ROLE_ADMIN_APPROVE);
        }

        if (dbUser != null) {
            if (!Objects.equals(dbUser.getPassword(),user.getPassword())) {
                user.setPassword(DigestUtils.md5Hex(user.getPassword()));
            }
        }

        userService.createOrUpdate(user);
        result.setSuccessful(true);
        result.setObj(user);
        return result;
    }

    /**
     * 冻结用户
     * @return
     */
    @AuditLogAn(operateType = DictConst.OP_DELETE,menuName = MenuConst.XTPZ_YHPZ_SCYH)
    @OperLog(menuName = "用户配置",operateType = "冻结用户",operateObj = "#username")
    @RequestMapping("frozen")
    public @ResponseBody
    AjaxResult frozen(long id,String username) {
        AjaxResult result = new AjaxResult();
        User user = userService.findById(id);
        if (user.isActive()) {
            user.setActive(false);
            userService.createOrUpdate(user);
            result.setSuccessful(true);
        }
        return result;
    }

    /**
     * 解冻用户
     *
     * @param id
     * @return
     */
    @AuditLogAn(operateType = DictConst.OP_UPDATE,menuName = MenuConst.XTPZ_YHPZ_QYYH)
    @OperLog(menuName = "用户配置",operateType = "启用用户",operateObj = "#username")
    @RequestMapping("thaw")
    public @ResponseBody
    AjaxResult thaw(long id,String username) {
        AjaxResult result = new AjaxResult();
        User user = userService.findById(id);
        if (!user.isActive()) {
            user.setActive(true);
            userService.createOrUpdate(user);
            result.setSuccessful(true);
        }
        return result;
    }

    @AuditLogAn(operateType = DictConst.OP_SELECT,menuName = MenuConst.XTPZ_YHPZ)
    @RequestMapping("findData")
    @ResponseBody
    public SearchDto<User> findData(SearchDto<User> dto) throws Exception {
        List<User> userList = userService.findUser(dto);
        long count = userService.findCountOfUser(dto);
        dto.setData(userList);
        dto.setITotalRecords(count);
        dto.setITotalDisplayRecords(count);
        return dto;
    }

    @RequestMapping(value = "/initEditpwd", method = RequestMethod.GET)
    public ModelAndView editpwdView(HttpServletRequest request) {
        ModelAndView view = new ModelAndView("/user/editpwd");
        return view;
    }

    /**
     * 密码过期处理
     * @author wangjianjun
     * @date 2020/12/23
     */
    @RequestMapping(value = "/passwordExpire")
    public @ResponseBody
    AjaxResult passwordExpire(HttpServletRequest request) {
        AjaxResult result = new AjaxResult();
        result.setSuccessful(false);
        User user = super.getCurrentUser(request);
        if (user.getLastPasswordDate() != null) {
            if ("on".equalsIgnoreCase(ConfigUtil.getValue("switch_passExpire"))) {//是否开户密码过期策略
                String days = ConfigUtil.getValue("passExpireDays") == null ? "90" : ConfigUtil.getValue("passExpireDays");//默认90天
                if (DateUtil.between(user.getLastPasswordDate(), new Date(), DateUnit.DAY) >= Integer.parseInt(days)) {
                    result.setMsg("密码周期达90天，请修改密码。");
                    result.setSuccessful(true);
                }
            }
        }
        return result;
    }

    @AuditLogAn(operateType = DictConst.OP_UPDATE,menuName = MenuConst.XTPZ_YHPZ_XGMM)
    @RequestMapping(value = "/editpwd", method = RequestMethod.POST)
    public @ResponseBody
    AjaxResult editpwd(HttpServletRequest request, @RequestParam String oldpwd, @RequestParam String newpwd) {
        AjaxResult result = new AjaxResult();
        User cuser = super.getCurrentUser(request);
        // 校验密码
        if ("on".equalsIgnoreCase(ConfigUtil.getValue("switch_passPolicy"))) {//是否开户密码规则策略
            String reg = "^(?![a-zA-Z]+$)(?![0-9]+$)(?![._~!@#$^&*]+$)(?![0-9a-zA-Z]+$)(?![0-9._~!@#$^&*]+$)(?![a-zA-Z._~!@#$^&*]+$)[A-Za-z0-9._~!@#$^&*]{8,20}$";
            boolean isMatch = Pattern.matches(reg, newpwd);
            if (!isMatch) {
                result.setMsg("密码长度最少8个字符，包含大小写字母、特殊符号和数字");
                result.setSuccessful(false);
                return result;
            }
        }
        if (!cuser.getPassword().equals(DigestUtils.md5Hex(oldpwd))) {
            result.setMsg("原密码不正确");
            result.setSuccessful(false);
        } else {
            cuser.setPassword(DigestUtils.md5Hex(newpwd));
            cuser.setLastPasswordDate(new Date());//写入密码修改时间
            userService.createOrUpdate(cuser);
            result.setMsg("修改成功，请牢记新的登录密码。");
            result.setSuccessful(true);
        }
        return result;
    }

    /**
     * 根据用户id获取用户信息
     *
     * @param id
     * @return
     */
    @RequestMapping("findById/{id}")
    public @ResponseBody User findById(@PathVariable("id") long id) {
        return userService.findById(id);
    }


    @RequestMapping("summary")
    public ModelAndView summary() {
        return new ModelAndView("/statistic/userSummary");
    }

    @AuditLogAn(operateType = DictConst.OP_SELECT,menuName = MenuConst.TJZX_RYPZTJ)
    @RequestMapping("summarySearch")
    public @ResponseBody
    UserSummarySearchDto summarySearch(UserSummarySearchDto dto,HttpServletRequest request) throws Exception {
        User currentUser = getCurrentUser(request);
        if(StringUtil.isEmpty(dto.getProvince())){
            dto.setProvince(currentUser.getProvince());
        }
        if(StringUtil.isEmpty(dto.getCity())){
            dto.setCity(currentUser.getCity());
        }
        if(StringUtil.isEmpty(dto.getArea())){
            dto.setArea(currentUser.getArea());
        }
        return userService.summarySearch(dto);
    }


    @RequestMapping("/userModal")
    public ModelAndView userModal(HttpServletRequest request) {
        ModelAndView view = new ModelAndView("/statistic/userModal");
        view.addObject("areaCode", request.getParameter("areaCode"));
        view.addObject("role", request.getParameter("role"));
        view.addObject("active", request.getParameter("active"));
        return view;
    }
}
