package com.bcxin.sp.work.entity.domain.activity.base;

import cn.hutool.core.date.DatePattern;
import cn.hutool.core.date.DateUnit;
import cn.hutool.core.date.DateUtil;
import com.alibaba.fastjson.annotation.JSONField;
import com.baomidou.mybatisplus.activerecord.Model;
import com.baomidou.mybatisplus.annotations.TableField;
import com.baomidou.mybatisplus.annotations.TableId;
import com.baomidou.mybatisplus.annotations.TableName;
import com.baomidou.mybatisplus.enums.IdType;
import com.bcxin.sp.work.entity.domain.activity.approve.Approve;
import com.bcxin.sp.work.entity.domain.user.User;
import com.bcxin.sp.work.entity.dto.ActivityUtil;
import com.bcxin.sp.work.entity.dto.ApproveUtil;
import com.fasterxml.jackson.annotation.JsonFormat;
import com.fasterxml.jackson.annotation.JsonIgnoreProperties;
import lombok.Data;
import org.springframework.format.annotation.DateTimeFormat;

import java.io.Serializable;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;

@Data
@TableName("sp_activity")
@JsonIgnoreProperties
public class Activity extends Model<Activity> {

    private static final long serialVersionUID = 7064937058904767154L;

    @TableId(type = IdType.AUTO)
    private Long id;
    /**
     * 报批时间
     */
    @JsonFormat(timezone = "GMT+8", pattern = "yyyy-MM-dd HH:mm:ss")
    private Date addTime = new Date();
    @JsonFormat(timezone = "GMT+8", pattern = "yyyy-MM-dd HH:mm:ss")
    private Date updateTime = new Date();
    private String updater = "system";

    private Long pssId;
    private String activityNo;
    private String fullName;
    private String typeCode;
    private String province;
    private String city;
    private String area;
    private String unit;
    private String address;
    private Integer number = 0;
    @DateTimeFormat(pattern = "yyyy-MM-dd HH:mm")
    @JSONField(format="yyyy-MM-dd HH:mm")
    @JsonFormat(timezone = "GMT+8", pattern = "yyyy-MM-dd HH:mm:ss")
    private Date startDate;
    @DateTimeFormat(pattern = "yyyy-MM-dd HH:mm")
    @JSONField(format="yyyy-MM-dd HH:mm")
    @JsonFormat(timezone = "GMT+8", pattern = "yyyy-MM-dd HH:mm:ss")
    private Date endDate;
    private Integer amount = 0;
    /**
     * 承办方
     */
    private String sponsor;
    /**
     * 承办方注册地址
     */
    private String sponsorAddress;
    /**
     * 主办单位(备案活动用)
     */
    private String zsponsor;
    /**
     * 主办方
     */
    private String organizer;
    private String assessmentorg;
    private boolean isGov;
    private String approveStatus;
    private boolean isExported;
    private String workflowVersion;
    private String sync;
    private String rejectContent; //退回理由
    private String surveyInfo;//判断是否上传勘查详情
    private String history;
    // 转交原因
    private String transferContent;
    // 重新申请原因
    private String reContent;
    // 是否转交
    private String isTransfer;
    // 是否备案项目(政府有分许可和备案)
    private String isBackUp;
    // 是否需要风评报告
    private String isNeedReport;
    /**
     * 审批级别（判断是省级审批，市级审批，区级审批）
     */
    private String approveLevel;

    /**
     * 下一个审批角色或用户
     */
    private String nextApproveRole;
    private String nextApproveUser;
    /**
     * 申请初审时间
     */
    @DateTimeFormat(pattern = "yyyy-MM-dd HH:mm")
    @JSONField(format="yyyy-MM-dd HH:mm")
    @JsonFormat(timezone = "GMT+8", pattern = "yyyy-MM-dd HH:mm:ss")
    private Date primaryDate;
    /**
     * 申请审批时间
     */
    @DateTimeFormat(pattern = "yyyy-MM-dd HH:mm")
    @JSONField(format="yyyy-MM-dd HH:mm")
    @JsonFormat(timezone = "GMT+8", pattern = "yyyy-MM-dd HH:mm:ss")
    private Date approveDate;


    @TableField(exist = false)
    private String needApproval; //判断用户是否需要审核
    //当前审批人员列表
    @TableField(exist = false)
    private List<User> approveUserList = new ArrayList<User>();
    @TableField(exist = false)
    private List<Approve> approveList = new ArrayList<Approve>();
    @TableField(exist = false)
    private String provincename;
    @TableField(exist = false)
    private String cityname;
    @TableField(exist = false)
    private String areaname;
    @TableField(exist = false)
    private String startDateStr;
    @TableField(exist = false)
    private String endDateStr;
    @TableField(exist = false)
    private String typeName;
    @TableField(exist = false)
    private String approveOne;
    @TableField(exist = false)
    private int actionStatus;

    private String isAddFiles;//是否补齐补正完材料
    /**
     * 活动坐标
     */
    private String coordinate;
    /**
     * 活动简介
     */
    private String introduce;
    /**
     * 上报时间（浙江用）
     */
    private String reportTime;

    @Override
    protected Serializable pkVal() {
        return this.id;
    }

    public String getStartDateStr(){
        if (this.startDate == null) {
            return "";
        }
        return DateUtil.format(this.startDate, DatePattern.NORM_DATETIME_MINUTE_FORMAT);
    }

    public String getEndDateStr(){
        if (this.endDate == null) {
            return "";
        }
        return DateUtil.format(this.endDate, DatePattern.NORM_DATETIME_MINUTE_FORMAT);
    }

    public String getDays(){
        if (this.startDate == null || this.endDate == null) {
            return "";
        }
        return (DateUtil.between(this.startDate,this.endDate, DateUnit.DAY) + 1) + "";
    }

    public String getTypeStr(){
        if (this.typeCode == null) {
            return "";
        }
        return ActivityUtil.getTypeByCode(this.typeCode);
    }

    public String getApproveStatusStr(){
        if (this.approveStatus == null) {
            return "";
        }
        return ApproveUtil.getTypeName(this.approveStatus);
    }

}
