package com.bcxin.sp.work.service.activity.action;

import com.baomidou.mybatisplus.mapper.EntityWrapper;
import com.baomidou.mybatisplus.mapper.Wrapper;
import com.bcxin.sp.work.dao.activity.approve.ApproveHistoryMapper;
import com.bcxin.sp.work.dao.activity.base.ActivityMapper;
import com.bcxin.sp.work.dao.activity.extend.ActivityActionMapper;
import com.bcxin.sp.work.dao.activity.extend.ActivitySessionMapper;
import com.bcxin.sp.work.dao.activity.history.ActivityHistoryMapper;
import com.bcxin.sp.work.dao.user.UserMapper;
import com.bcxin.sp.work.entity.PageResult;
import com.bcxin.sp.work.entity.domain.activity.action.ActivityAction;
import com.bcxin.sp.work.entity.domain.activity.approve.ApproveHistory;
import com.bcxin.sp.work.entity.domain.activity.base.Activity;
import com.bcxin.sp.work.entity.domain.activity.history.ActivityHistory;
import com.bcxin.sp.work.entity.domain.activity.session.ActivitySession;
import com.bcxin.sp.work.entity.domain.user.User;
import com.bcxin.sp.work.entity.dto.*;
import com.bcxin.sp.work.service.third.zj.ZJDataService;
import com.bcxin.sp.work.util.StringUtil;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import javax.annotation.Resource;
import java.util.Date;
import java.util.List;

@Service
@Transactional
public class ActivityActionService {


    @Resource
    private ActivityActionMapper activityActionMapper;

    @Resource
    private ActivityMapper activityMapper;
    @Resource
    private ActivitySessionMapper activitySessionMapper;
    @Resource
    private ActivityHistoryMapper activityHistoryMapper;
    @Resource
    private UserMapper userMapper;
    @Resource
    private ZJDataService zJDataService;


    public PageResult findActivity(SearchDto<ActivityHistory> dto) throws Exception {
        dto.setHistorySearch(true);
        List<ActivityActionDTO> activityList = activityActionMapper.findActivity(dto);
        long total = findCountOfUser(dto);
        return new PageResult(activityList,total);
    }

    public long findCountOfUser(SearchDto<ActivityHistory> dto) throws Exception {
        dto.setHistorySearch(true);
        return activityActionMapper.findCountOfActivity(dto);
    }

    public Activity detail(Long actionId){
        ActivityAction activityAction = activityActionMapper.selectById(actionId);
        if(activityAction == null){
            return null;
        }
        Activity activity;
        User user = userMapper.selectById(activityAction.getUserId());
        if(StringUtil.isNotEmpty(activityAction.getActivitySign())){
            ActivityHistoryDTO activityHistory = activityHistoryMapper.getById(Long.parseLong(activityAction.getActivityId()));
            // activityHistory 转 activity
            activity = new Activity();
            activity.setId(activityHistory.getId());
            activity.setFullName(activityHistory.getFullName());
            activity.setAddress(activityHistory.getAddress());
            activity.setIntroduce(activityHistory.getIntroduce());
            activity.setCoordinate(activityHistory.getCoordinate());
            activity.setSponsor(activityHistory.getSponsor());
            activity.setSponsorAddress(activityHistory.getSponsorAddress());
            activity.setTypeName(activityHistory.getTypeName());
            activity.setStartDateStr(activityHistory.getStartDateStr());
            activity.setEndDateStr(activityHistory.getEndDateStr());
            activity.setStartDate(activityHistory.getStartDate());
            activity.setEndDate(activityHistory.getEndDate());
            activity.setProvincename(activityHistory.getProvinceName());
            activity.setCityname(activityHistory.getCityName());
            activity.setAreaname(activityHistory.getAreaName());
            activity.setNumber(Integer.parseInt(activityHistory.getPeakNumber()));
        }else{
            activity = activityMapper.findFullById(Long.parseLong(activityAction.getActivityId()));
            activity.setTypeName(ActivityUtil.getTypeByCode(activity.getTypeCode()));
        }
        activity.setApproveOne(user.getRealName()+" "+user.getPhone());
        return activity;
    }

    /**
     * <b> 上报部级 </b>
     * @author ZXF
     * @create 2025/02/18 0018 18:03
     * @version
     * @注意事项 </b>
     */
    public AjaxResult uploadaction(Long actionId){
        AjaxResult result = new AjaxResult();
        ActivityAction activityAction = activityActionMapper.selectById(actionId);
        Activity activity;
        List<ActivitySession> resultList;
        User user = userMapper.selectById(activityAction.getUserId());
        if(StringUtil.isNotEmpty(activityAction.getActivitySign())){
            ActivityHistory activityHistory = activityHistoryMapper.selectById(Long.parseLong(activityAction.getActivityId()));
            //TODO activityHistory 转 activity
            activity = new Activity();
            activity.setId(activityHistory.getId());
            activity.setFullName(activityHistory.getFullName());
            activity.setAddress(activityHistory.getAddress());
            activity.setIntroduce(activityHistory.getIntroduce());
            activity.setCoordinate(activityHistory.getCoordinate());
            activity.setSponsor(activityHistory.getSponsor());
            activity.setSponsorAddress(activityHistory.getSponsorAddress());
            activity.setTypeCode(activityHistory.getActivityType());
            activity.setStartDate(activityHistory.getStartDate());
            activity.setEndDate(activityHistory.getEndDate());
            activity.setProvince(activityHistory.getProvince());
            activity.setCity(activityHistory.getCity());
            activity.setArea(activityHistory.getArea());
            activity.setNumber(Integer.parseInt(activityHistory.getPeakNumber()));
            resultList = activitySessionMapper.selectByActivityId(Long.parseLong(activityAction.getActivityId()));
        }else{
            activity = activityMapper.findFullById(Long.parseLong(activityAction.getActivityId()));
            resultList = activitySessionMapper.selectByActivityId(activity.getId());
        }
        AjaxResult ret = zJDataService.uploadaction(user,activity,resultList);
        if(!ret.isSuccessful()){
            return ret;
        }
        createOrUpdate(activityAction.getUserId(),Long.parseLong(activityAction.getActivityId()), activityAction.getActivitySign(),1);
        result.setSuccessful(true);
        result.setMsg("上报成功");
        return result;
    }

    public void createOrUpdate(Long userId,Long activityId,String sign,int actionStatus) {
        ActivityAction activityAction = getByActivityId(activityId, sign);
        if(activityAction == null){
            activityAction = new ActivityAction();
            activityAction.setActivityId(activityId+"");
            activityAction.setActivitySign(sign);
            activityAction.setUserId(userId);
            activityActionMapper.insert(activityAction);
        }else{
            activityAction.setUpdateTime(new Date());
            activityAction.setActionStatus(actionStatus);
            activityActionMapper.updateById(activityAction);
        }
    }

    public ActivityAction getByActivityId(Long activityId, String sign) {
        Wrapper wrapper=new EntityWrapper<ApproveHistory>();
        wrapper.eq("activityId",activityId);
        if(StringUtil.isNotEmpty(sign)){
            wrapper.eq("activitySign",sign);
        }
        List<ActivityAction> list = activityActionMapper.selectList(wrapper);
        if(list.size() == 0){
            return null;
        }
        return list.get(0);
    }

}