package com.bcxin.sp.work.service.activity.approve;

import cn.hutool.core.collection.CollectionUtil;
import com.baomidou.mybatisplus.mapper.EntityWrapper;
import com.baomidou.mybatisplus.mapper.Wrapper;
import com.bcxin.sp.work.dao.activity.approve.ApproveDetailMapper;
import com.bcxin.sp.work.dao.activity.approve.ApproveHistoryMapper;
import com.bcxin.sp.work.dao.activity.approve.ApproveMapper;
import com.bcxin.sp.work.entity.domain.activity.approve.Approve;
import com.bcxin.sp.work.entity.domain.activity.approve.ApproveDetail;
import com.bcxin.sp.work.entity.domain.activity.approve.ApproveHistory;
import com.bcxin.sp.work.util.Const.DictConst;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import javax.annotation.Resource;
import java.util.List;
import java.util.Map;

@Service
@Transactional
public class ApproveService  {

    @Resource
    private ApproveMapper approveMapper;

    @Resource
    private ApproveDetailMapper approveDetailMapper;

    @Resource
    private ApproveHistoryMapper approveHistoryMapper;


    public void removeApprove(Long activityId){
        approveMapper.removeApprove(activityId,"30");
    }

    public void save(Approve approve) {
        approveMapper.insert(approve);
        for (ApproveDetail detail : approve.getDetails()) {
            detail.setApproveId(approve.getId());
            approveDetailMapper.insert(detail);
        }
    }

    public void update(Approve approve) {
        approveMapper.updateById(approve);
        approveDetailMapper.deleteById(approve.getId());
        for (ApproveDetail detail : approve.getDetails()) {
            detail.setApproveId(approve.getId());
            approveDetailMapper.insert(detail);
        }
    }

    public void deleteByActivityId(Long activityId) {
        List<Approve> approveList = approveMapper.selectList(new EntityWrapper<Approve>().eq("activityId",activityId));
        for (Approve approve : approveList) {
            approve.setLogicDel(DictConst.Y);
            approveMapper.updateById(approve);
        }

    }


    public List<Approve> findByActivityId(long activityId) {
       return approveMapper.selectList(new EntityWrapper<Approve>()
               .eq("activityId",activityId)
               .eq("logicDel",DictConst.N));
    }

    public Approve findLastByActivityId(long activityId) {
        List<Approve> approveList = approveMapper.selectList(
                new EntityWrapper<Approve>()
                        .eq("activityId", activityId)
                        .eq("logicDel",DictConst.N)
                        .orderBy("id", false));
        if (CollectionUtil.isNotEmpty(approveList)) {
            return approveList.get(0);
        }
        return new Approve();
    }

    public List<ApproveHistory> findHistoryByActivityId(long activityId) {
        Wrapper wrapper=new EntityWrapper<ApproveHistory>();
        wrapper.eq("activityId",activityId);
        wrapper.orderBy("addTime",true);
        return approveHistoryMapper.selectList(wrapper);
    }

    public List<ApproveDetail> findApproveDetail(Long approveId) {
        return approveDetailMapper.findByApproveId(approveId);
    }

    public Approve findApproveById(Long approveId) {
        return approveMapper.selectById(approveId);
    }

    /**
     * <b> 根据活动id查询最后一次审批信息 </b>
     * @author ZXF
     * @create 2020/03/03 0003 16:07
     * @version
     * @注意事项 </b>
     */
    public Map getApproveByIdLastOne(long activityId) {
        return approveMapper.getApproveByIdLastOne(activityId);
    }
}