package com.bcxin.sp.work.service.activity.history;

import cn.hutool.core.date.DateUtil;
import cn.hutool.core.util.RandomUtil;
import com.baomidou.mybatisplus.mapper.EntityWrapper;
import com.bcxin.sp.work.dao.activity.extend.ActivitySessionMapper;
import com.bcxin.sp.work.dao.activity.history.ActivityHistoryMapper;
import com.bcxin.sp.work.entity.PageResult;
import com.bcxin.sp.work.entity.domain.activity.action.ActivityAction;
import com.bcxin.sp.work.entity.domain.activity.approve.Approve;
import com.bcxin.sp.work.entity.domain.activity.base.Activity;
import com.bcxin.sp.work.entity.domain.activity.history.ActivityHistory;
import com.bcxin.sp.work.entity.domain.activity.session.ActivitySession;
import com.bcxin.sp.work.entity.domain.user.User;
import com.bcxin.sp.work.entity.dto.ActivityHistoryDTO;
import com.bcxin.sp.work.entity.dto.AjaxResult;
import com.bcxin.sp.work.entity.dto.SearchDto;
import com.bcxin.sp.work.service.activity.action.ActivityActionService;
import com.bcxin.sp.work.util.BcxinFileUtil;
import com.bcxin.sp.work.util.Const.DictConst;
import com.bcxin.sp.work.util.StringUtil;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.web.multipart.MultipartFile;

import javax.annotation.Resource;
import java.util.List;
import java.util.Map;

/**
 * 历史活动数据录入
 * @author 罗鹏
 */
@Service
@Transactional
public class ActivityHistoryService {

    @Resource
    private ActivityHistoryMapper activityHistoryMapper;

    @Resource
    private ActivitySessionMapper activitySessionMapper;

    @Resource
    private ActivityActionService activityActionService;

    public ActivityHistory findById(long id) {
        return activityHistoryMapper.selectById(id);
    }
    public ActivityHistoryDTO findFullById(long id) {
        ActivityHistoryDTO dto = activityHistoryMapper.getById(id);
        ActivityAction activityAction = activityActionService.getByActivityId(id, "20000");
        if(activityAction != null) {
            dto.setActionStatus(activityAction.getActionStatus());
        }
        return dto;
    }


    public PageResult findActivity(SearchDto<ActivityHistory> dto) throws Exception {
        dto.setHistorySearch(true);
        //StringBuffer condition = SearchUtil.getCondition(dto,true);
        //condition.append(" ORDER BY a.id DESC");
        //condition.append(" limit ");
        //condition.append(dto.getIDisplayStart());
        //condition.append(",");
        //condition.append(dto.getIDisplayLength());
        List<ActivityHistoryDTO> activityList = activityHistoryMapper.findActivity(dto);
        long total = findCountOfUser(dto);
        return new PageResult(activityList,total);
    }

    public long findCountOfUser(SearchDto<ActivityHistory> dto) throws Exception {
        dto.setHistorySearch(true);
        //StringBuffer condition = SearchUtil.getCondition(dto,true);
        return activityHistoryMapper.findCountOfActivity(dto);
    }

    /**
     * 保存活动信息
     * @param parameterMap
     * @param pgbg
     * @param bbcl
     * @throws Exception
     */
    public String save(User user,Map<String, String> parameterMap, MultipartFile pgbg, MultipartFile bbcl) throws Exception {
        /* 参数校验 */
        String msg = checkParam(parameterMap);
        if (StringUtil.isNotEmpty(msg)) {
            return msg;
        }
        ActivityHistory activityHistory = new ActivityHistory();
        String sponsorCount = parameterMap.get("sponsorCount");
        String addressCount = parameterMap.get("addressCount");

        String firstSponsor = parameterMap.get("sponsor");
        activityHistory.setSponsor(firstSponsor);
        StringBuffer manySponsor = new StringBuffer();
        if (StringUtil.isNotEmpty(sponsorCount)) {
            if ( Integer.parseInt(sponsorCount) > 1) {
                for (int i = 1; i < Integer.parseInt(sponsorCount); i++) {
                    String temp = parameterMap.get("sponsor"+i);
                    if (StringUtil.isNotEmpty(temp)) {
                        manySponsor.append(temp).append("，");
                    }
                }
                if (StringUtil.isNotEmpty(manySponsor.toString())) {
                    activityHistory.setSponsor(firstSponsor + "，"  + manySponsor.substring(0,manySponsor.length()-1));
                }
            }
        }


        String firstAddress = parameterMap.get("address");
        activityHistory.setAddress(firstAddress);
        StringBuffer manyAddress = new StringBuffer();
        if (StringUtil.isNotEmpty(addressCount)) {
            if ( Integer.parseInt(addressCount) > 1) {
                for (int i = 1; i < Integer.parseInt(addressCount); i++) {
                    String temp = parameterMap.get("address"+i);
                    if (StringUtil.isNotEmpty(temp)) {
                        manyAddress.append(temp).append("，");
                    }
                }
                if (StringUtil.isNotEmpty(manyAddress.toString())) {
                    activityHistory.setAddress(firstAddress + "，"  + manyAddress.substring(0,manyAddress.length()-1));
                }
            }
        }

        String organizer = parameterMap.get("organizer");
        String assessment = parameterMap.get("assessment");
        String name = parameterMap.get("fullName");
        String activityType = parameterMap.get("activityType");
        String province = parameterMap.get("province");
        String city = parameterMap.get("city");
        String area = parameterMap.get("area");
        String addressType = parameterMap.get("addressType");
        String peakNumber = parameterMap.get("peakNumber");
        String startDate = parameterMap.get("startDate");
        String endDate = parameterMap.get("endDate");
        String sponsorAddress = parameterMap.get("sponsorAddress");
        String coordinate = parameterMap.get("coordinate");
        String introduce = parameterMap.get("introduce");
        activityHistory.setSponsorAddress(sponsorAddress);
        activityHistory.setCoordinate(coordinate);
        activityHistory.setIntroduce(introduce);

        activityHistory.setOrganizer(organizer);
        activityHistory.setAssessment(assessment);
        activityHistory.setFullName(name);
        activityHistory.setActivityNo("LS"+ DateUtil.current(false) + RandomUtil.randomNumbers(5));
        activityHistory.setActivityType(activityType);
        activityHistory.setProvince(StringUtil.isEmpty(province)?user.getProvince():province);
        activityHistory.setCity(StringUtil.isEmpty(city)?user.getCity():city);
        activityHistory.setArea((StringUtil.isEmpty(area) || "0".equals(area))?user.getArea():area);
        activityHistory.setAddressType(addressType);
        activityHistory.setPeakNumber(peakNumber);
        activityHistory.setActivityChannel(parameterMap.get("activityChannel"));
        try {
            activityHistory.setStartDate(DateUtil.parse(startDate));
            activityHistory.setEndDate(DateUtil.parse(endDate));
        } catch (Exception e){
            return "日期格式错误";
        }

        activityHistory.setBbcl(BcxinFileUtil.saveFile(bbcl));
        activityHistory.setPgbg(BcxinFileUtil.saveFile(pgbg));
        activityHistory.setUserId(user.getId());

        activityHistoryMapper.insert(activityHistory);
        return "";
    }

    /**
     * 校验元素
     * @param parameterMap
     * @return
     */
    private String checkParam(Map<String, String> parameterMap){
        String name = parameterMap.get("name");
        ActivityHistory history = activityHistoryMapper.findByName(name);
        if (history != null) {
            return "存在重复的活动名称，请检查";
        }
        return "";
    }

    public boolean deleteByActivityHistoryId(Long activityHistoryId) {
        List<ActivityHistory> activityHistoryList = activityHistoryMapper.selectList(new EntityWrapper<ActivityHistory>().eq("id",activityHistoryId));
        int i = 0;
        for (ActivityHistory activityHistory : activityHistoryList) {
            activityHistory.setLogicDel(DictConst.Y);
            i = activityHistoryMapper.updateById(activityHistory);
        }
        if(i>0){
            return true;
        }
        return false;
    }
    public AjaxResult submitaction(User user,Long activityId){
        AjaxResult result = new AjaxResult();
        ActivityHistory activityHistory = findById(activityId);
        if(StringUtil.isEmpty(activityHistory.getSponsorAddress())||StringUtil.isEmpty(activityHistory.getIntroduce())||StringUtil.isEmpty(activityHistory.getCoordinate())){
            result.setSuccessful(false);
            result.setMsg("活动坐标、简介、承办单位地址为空（历史活动不支持上报，请前往部级上报平台手动录入）");
            return result;
        }
        List<ActivitySession> resultList = activitySessionMapper.selectByActivityId(activityId);
        if(resultList.size()==0){
            result.setSuccessful(false);
            result.setMsg("活动场次信息为空（历史活动不支持上报，请前往部级上报平台手动录入）");
            return result;
        }
        for (ActivitySession activitySession : resultList){
            if(activitySession.getIsImprove() == 0){
                result.setSuccessful(false);
                result.setMsg("存在场次信息未完善");
                return result;
            }
        }
        if(!"330000".equals(activityHistory.getProvince())){
            result.setSuccessful(false);
            result.setMsg("当前活动上报功能未开通");
            return result;
        }
        //记录上报时间
        activityHistory.setReportTime(com.bcxin.sp.work.util.sys.DateUtil.getCurrentDateTime());
        activityHistoryMapper.updateById(activityHistory);
        //TODO 增加上报表记录
        activityActionService.createOrUpdate(user.getId(),activityId, "20000",0);
        result.setSuccessful(true);
        result.setMsg("上报成功");
        return result;
    }
}
