package com.bcxin.sp.work.service.common;

import cn.hutool.core.date.DateUnit;
import cn.hutool.core.date.DateUtil;
import com.bcxin.sp.work.dao.activity.approve.ApproveMapper;
import com.bcxin.sp.work.dao.sys.RegionMapper;
import com.bcxin.sp.work.dao.user.UserMapper;
import com.bcxin.sp.work.entity.domain.activity.approve.Approve;
import com.bcxin.sp.work.entity.domain.activity.base.Activity;
import com.bcxin.sp.work.entity.domain.user.User;
import com.bcxin.sp.work.service.sys.MessageService;
import com.bcxin.sp.work.util.Const.DictConst;
import com.bcxin.sp.work.util.StringUtil;
import org.springframework.scheduling.annotation.Async;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import javax.annotation.Resource;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;
import java.util.Map;

/**
 * @author Administrator
 */
@Service
@Transactional
public class NotifyService {

    /**
     * 审批url
     */
    private final static String APPROVAL_URL = "/business/approve/list";

    /**
     * 备案url
     */
    private final static String BEIAN_URL = "/business/activity/list";

    @Resource
    private MessageService messageService;

    @Resource
    private UserMapper userMapper;

    @Resource
    private ApproveMapper approveMapper;

    @Resource
    private RegionMapper regionMapper;

    /**
     * 提交初审
     * @param activity
     */
    public void tjcs(Activity activity){
        /* 查找符合条件的初审人员 */
        List<User> primaryUserList = userMapper.findApproveUser(activity.getApproveLevel(),activity.getId());
        String title = "【"+activity.getFullName()+"】已提交初审";
        String content = "【"+activity.getSponsor()+"】申报的活动【"+activity.getFullName()+"】已提交初审，请及时审批。";
        if (activity.getStartDate() != null) {
            //计算今天与活动开始时间相差几天
            long dateDiff = DateUtil.between(new Date(), activity.getStartDate(), DateUnit.DAY);
            if (dateDiff < 30) {
                content = "【" + activity.getSponsor() + "】申报的活动【" + activity.getFullName() + "】已提交初审，<span style='color: red'>活动举办日期距今已不到30天，</span>请及时审批。";
            }
        }
        String keyword = "立即审批";
        notifyUserAndAdmin(primaryUserList, title, content, keyword,APPROVAL_URL);
    }

    /**
     * 提交材料
     * @param activity
     */
    public void cxtjcl(Activity activity){
        /* 查找符合条件的初审人员 */
        List<User> primaryUserList = userMapper.findApproveUser(activity.getApproveLevel(),activity.getId());
        String title = "【"+activity.getFullName()+"】已重新提交报批材料";
        String content = "【"+activity.getSponsor()+"】申报的活动【"+activity.getFullName()+"】已重新提交报批材料，请及时审批。";
        String keyword = "立即审批";
        notifyUserAndAdmin(primaryUserList, title, content, keyword,APPROVAL_URL);
    }

    /**
     * 提交评估材料
     * @param activity
     */
    public void cxtjpgcl(Activity activity){
        /* 查找符合条件的等级评定人员 */
        List<User> primaryUserList = userMapper.findApproveUser(activity.getApproveLevel(),activity.getId());
        String title = "【"+activity.getFullName()+"】已重新提交评估材料";
        String content = "【"+activity.getSponsor()+"】申报的活动【"+activity.getFullName()+"】已重新提交评估材料，请及时审批。";
        String keyword = "立即审批";
        notifyUserAndAdmin(primaryUserList, title, content, keyword,APPROVAL_URL);
    }

    /**
     * 提交等级评定
     * @param activity
     */
    public void tjdjpd(Activity activity){
        /* 查找符合条件的初审人员 */
        List<User> primaryUserList = userMapper.findApproveUser(activity.getApproveLevel(),activity.getId());
        String title = "【"+activity.getFullName()+"】已提交安全管理等级评定";
        String content = "【"+activity.getSponsor()+"】申报的活动【"+activity.getFullName()+"】已提交安全管理等级评定，请及时审批。";
        if (activity.getStartDate() != null) {
            //计算今天与活动开始时间相差几天
            long dateDiff = DateUtil.between(new Date(), activity.getStartDate(), DateUnit.DAY);
            if (dateDiff < 30) {
                content = "【" + activity.getSponsor() + "】申报的活动【" + activity.getFullName() + "】已提交安全管理等级评定，<span style='color: red'>活动举办日期距今已不到30天，</span>请及时审批。";
            }
        }
        String keyword = "立即审批";
        notifyUserAndAdmin(primaryUserList, title, content, keyword,APPROVAL_URL);
    }

    /**
     * 提交初审（转交）
     * @param activity
     */
    public void tjcsAndChangeArea(Activity activity, String sourceArea, String newArea) {
        /* 查找符合条件的1级审批人员 */
        List<User> primaryUserList = userMapper.findApproveUser(activity.getApproveLevel(),activity.getId());
        String title = "【" + activity.getFullName() + "】已提交初审（转交）";
        String content = "【" + activity.getSponsor() + "】申报的活动【" + activity.getFullName() + "】已提交初审，活动由【" + activity.getSponsor() + "】由" + sourceArea + "转交至" + newArea + "，请及时审批。";
        if (activity.getStartDate() != null) {
            //计算今天与活动开始时间相差几天
            long dateDiff = DateUtil.between(new Date(), activity.getStartDate(), DateUnit.DAY);
            if (dateDiff < 30) {
                content = "【" + activity.getSponsor() + "】申报的活动【" + activity.getFullName() + "】已提交初审，<span style='color: red'>活动举办日期距今已不到30天</span>，活动由【" + activity.getSponsor() + "】由" + sourceArea + "转交至" + newArea + "，请及时审批。";
            }
        }
        String keyword = "立即审批";
        notifyUserAndAdmin(primaryUserList, title, content, keyword,APPROVAL_URL);
    }

    /**
     * 通过初审
     * @param activity
     * @param user
     */
    public void tgcs(Activity activity,User user){
        String title = "【"+activity.getFullName()+"】已通过初审";
        String content = "【" + activity.getSponsor() + "】申报的活动【" + activity.getFullName() + "】已通过初审。";
        //审批管理员账号需要能接收初审、受理、审批、结果导出等消息
        List<User> adminUsers = userMapper.findAdminUserList(user);
        for (User adminUser : adminUsers) {
            messageService.instance(adminUser.getId(),title,content);
        }
    }

    /**
     * 完成等级评定
     * @param activity
     * @param user
     */
    public void tgdjpd(Activity activity,User user){
        String title = "【"+activity.getFullName()+"】已完成安全管理等级评定";
        String content = "【" + activity.getSponsor() + "】申报的活动【" + activity.getFullName() + "】已完成安全管理等级评定。";
        //审批管理员账号需要能接收初审、受理、审批、结果导出等消息
        List<User> adminUsers = userMapper.findAdminUserList(user);
        for (User adminUser : adminUsers) {
            messageService.instance(adminUser.getId(),title,content);
        }
    }

    /**
     * 初审退回
     * @param activity
     * @param user
     */
    public void csth(Activity activity,User user){
        String title = "【" + activity.getFullName() + "】初审被退回";
        String content = "【" + activity.getSponsor() + "】申报的活动【" + activity.getFullName() + "】初审被退回，退回意见：" + activity.getRejectContent();
        //审批管理员账号需要能接收初审、受理、审批、结果导出等消息
        List<User> adminUsers = userMapper.findAdminUserList(user);
        for (User adminUser : adminUsers) {
            messageService.instance(adminUser.getId(),title,content);
        }
    }


    @Async
    public void transferActNotify(Activity activity,List<String> userList,User user,String transferAddr){
        String title = "【"+activity.getFullName()+"】已被转交";
        String content = "【" + activity.getSponsor() + "】申报的活动【" + activity.getFullName() + "】已被" + user.getRealName() + "转交至" + transferAddr + "审批。";

        for(String userId : userList){
            messageService.instance(Long.parseLong(userId),title,content);
        }
        //审批管理员账号需要能接收初审、受理、审批、结果导出等消息
        List<User> adminUsers = userMapper.findAdminUserList(user);
        for (User adminUser : adminUsers) {
            // 防止重复发送
            if(!userList.contains(adminUser.getId().toString())){
                messageService.instance(adminUser.getId(),title,content);
            }
        }
    }

    /**
     * 承办方转交活动
     * @param userMapList
     * @param transferAddr
     */
    @Async
    public void contractorTransferActNotify(Activity activity,List<Map> userMapList, String transferAddr){
        if(userMapList==null || userMapList.size()==0){
            return;
        }
        String title = "【"+activity.getFullName()+"】已被转交";
        String content = "【" + activity.getSponsor() + "】申报的活动【" + activity.getFullName() + "】已被" + activity.getSponsor() + "转交至" + transferAddr + "审批。";

        List<String> userList=new ArrayList<>();
        for(Map map : userMapList){
            userList.add(map.get("userId").toString());
        }
        for(String userId : userList){
            messageService.instance(Long.parseLong(userId),title,content);
        }

        //审批管理员账号需要能接收初审、受理、审批、结果导出等消息
        User user = userMapper.findUserById(Long.parseLong(userList.get(0)));
        List<User> adminUsers = userMapper.findAdminUserList(user);
        for (User adminUser : adminUsers) {
            // 防止重复发送
            if(!userList.contains(adminUser.getId().toString())){
                messageService.instance(adminUser.getId(),title,content);
            }
        }
    }

    /**
     * 转交活动通知审批
     * @param activity
     * @param userList
     * @param user
     * @param transferAddr
     */
    public void transferActApproveNotify(Activity activity,List<String> userList,User user,String sourceTransferAddr,String transferAddr){
        if(userList==null || userList.isEmpty()){
            return;
        }
        String place = "";
        if (DictConst.APPROVELEVEL_PROVINCE.equals(activity.getApproveLevel())) {
            place = regionMapper.findNameById(Long.parseLong(activity.getProvince()));
        } else if (DictConst.APPROVELEVEL_CITY.equals(activity.getApproveLevel())) {
            place = regionMapper.findNameById(Long.parseLong(activity.getCity()));
        } else if (DictConst.APPROVELEVEL_AREA.equals(activity.getApproveLevel())) {
            place = regionMapper.findNameById(Long.parseLong(activity.getArea()));
        }

        String title = "【"+activity.getFullName()+"】已提交初审（转交）";
        String content = "【" + activity.getSponsor() + "】申报的活动【" + activity.getFullName() + "】已提交初审，活动由" + place + "审批人员由" + sourceTransferAddr + "转交至" + transferAddr + "，请及时审批。";

        // 获取管理员
        User userApprove=userMapper.findUserById(Long.parseLong(userList.get(0)));
        List<User> adminUsers = userMapper.findAdminUserList(userApprove);
        if(adminUsers!=null){
            for(User u : adminUsers){
                // 不包含
                if(!userList.contains(u.getId().toString())) {
                    messageService.instance(u.getId(), title, content);
                }
            }
        }

        // 发送消息
        for(String userId : userList){
            messageService.instance(Long.parseLong(userId), title, content, "立即审批", APPROVAL_URL);
        }
    }

    /**
     * 修改材料（重新提交审批，重新提交初审）
     * @param activity
     */
    public void xgcl(Activity activity,String approveType){
        /* 初审修改材料 */
        if (DictConst.APPROVETYPE_CS.equals(approveType)) {
            List<User> userList = userMapper.findApproveUser(activity.getApproveLevel(),activity.getId());
            String title = "【" + activity.getFullName() + "】已重新提交初审";
            String content = "【" + activity.getSponsor() + "】申报的活动【" + activity.getFullName() + "】已重新提交初审，请及时审批。";
            String keyword = "立即审批";
            notifyUserAndAdmin(userList, title, content, keyword,APPROVAL_URL);
        }
        /* 审批修改材料 */
        if (DictConst.APPROVETYPE_SP.equals(approveType)) {
            List<User> userList = userMapper.findApproveUser(activity.getApproveLevel(),activity.getId());
            String title = "【" + activity.getFullName() + "】已重新提交审批";
            String content = "【" + activity.getSponsor() + "】申报的活动【" + activity.getFullName() + "】已重新提交审批。";
            String keyword = "立即审批";
            notifyUserAndAdmin(userList, title, content, keyword,APPROVAL_URL);
        }

    }

    /**
     * 提交报备
     * @param activity
     */
    public void submitReport(Activity activity) {
        String title = "【" + activity.getFullName() + "】已提交报备";
        String content = "【" + activity.getSponsor() + "】申报的活动【" + activity.getFullName() + "】已提交报备。";
        String keyword = "立即查看";
        List<User> userList = adminAndApproveUsers(activity);
        for (User u : userList) {
            //管理员不显示关键字
            if ("ADMIN".equals(u.getRole())) {
                messageService.instance(u.getId(), title, content);
            } else {
                messageService.instance(u.getId(), title, content, keyword, BEIAN_URL);

            }
        }
    }

    /**
     * 重新提交报备通知
     * @param activity
     * @param comment 重新提交原因
     */
    public void resubmitTJBB(Activity activity, String comment) {
        String title = "【"+activity.getFullName()+"】已重新提交报备";
        String content = "【" + activity.getSponsor() + "】申报的活动【" + activity.getFullName() + "】已重新提交报备。";
        String keyword = "立即查看";
        List<User> userList = adminAndApproveUsers(activity);
        for (User u : userList) {
            //管理员不显示关键字
            if ("ADMIN".equals(u.getRole())) {
                messageService.instance(u.getId(), title, content);
            } else {
                messageService.instance(u.getId(), title, content, keyword, BEIAN_URL);

            }
        }
    }


    /**
     * 报备被退回
     *
     * @param activity
     * @param user
     */
    public void backUpActReject(Activity activity, User user) {
        String title = "【" + activity.getFullName() + "】报备被退回";
        String content = "【" + activity.getSponsor() + "】申报的活动【" + activity.getFullName() + "】报备被退回，退回意见：" + activity.getRejectContent();
        List<User> userList = adminAndApproveUsers(activity);
        for (User u : userList) {
            messageService.instance(u.getId(), title, content);
        }
    }


    /**
     * 可以查看备案活动的人员（当前地区）
     */
    private List<User> adminAndApproveUsers(Activity activity) {

        String approveLevel = "1";
        if (StringUtil.isNotEmpty(activity.getProvince()) && StringUtil.isNotEmpty(activity.getCity()) && StringUtil.isEmpty(activity.getArea())) {
            approveLevel = "2";
        } else if (StringUtil.isNotEmpty(activity.getProvince()) && StringUtil.isNotEmpty(activity.getCity()) && StringUtil.isNotEmpty(activity.getArea())) {
            approveLevel = "3";
        }
        activity.setApproveLevel(approveLevel);
        //可以查看备案活动的人员（当前地区）
        List<User> adminAndApproveUsers = userMapper.listAdminAndApproveOfBackUp(activity);

        return adminAndApproveUsers;
    }

    /**
     * 提交审批
     * @param activity
     */
    public void submitApprovalNotify(Activity activity) {
        /* 查找符合条件的人员 */
        List<User> userList = userMapper.findApproveUser(activity.getApproveLevel(),activity.getId());
        String title = "【"+activity.getFullName()+"】已提交审批";
        String content = "【" + activity.getSponsor() + "】申报的活动【" + activity.getFullName() + "】已提交审批。";
        String keyword = "立即审批";
        notifyUserAndAdmin(userList, title, content, keyword,APPROVAL_URL);
    }


    /**
     * 提交风评报告
     * @param activity
     */
    public void submitAssessmentNotify(Activity activity) {
        String title = "【"+activity.getFullName()+"】已提交风险评估报告";
        String content = "【"+activity.getSponsor()+"】申报的活动【"+activity.getFullName()+"】已提交风险评估报告。";
        String keyword = "立即查看";

        //查询当前审批人
        List<Approve> approveList = approveMapper.selectApproveUser(activity.getId());

        if (approveList != null && approveList.size() > 0) {
            messageService.instance(approveList.get(0).getUserId(), title, content, keyword, APPROVAL_URL);
        }
    }

    /**
     * 重新提交风评报告
     * @param activity
     */
    public void resubmitAssessmentNotify(Activity activity) {
        String title = "【"+activity.getFullName()+"】已重新提交风险评估报告";
        String content = "【"+activity.getSponsor()+"】申报的活动【"+activity.getFullName()+"】已重新提交风险评估报告。";
        String keyword = "立即查看";
        //查询当前审批人
        List<Approve> approveList = approveMapper.selectApproveUser(activity.getId());

        if (approveList != null && approveList.size()>0) {
            messageService.instance(approveList.get(0).getUserId(), title, content, keyword, APPROVAL_URL);
        }
    }

    /**
     * 已受理
     * @param activity
     * @param user
     */
    public void acceptedNotify(Activity activity, User user) {
        String title = "【"+activity.getFullName()+"】已受理";
        String content = "【" + activity.getSponsor() + "】申报的活动【" + activity.getFullName() + "】已受理。";
        //审批管理员账号需要能接收初审、受理、审批、结果导出等消息
        List<User> adminUsers = userMapper.findAdminUserList(user);
        for (User adminUser : adminUsers) {
            messageService.instance(adminUser.getId(),title,content);
        }
    }

    /**
     * 不受理
     * @param activity
     * @param user
     */
    public void notAcceptedNotify(Activity activity, User user) {
        String title = "【" + activity.getFullName() + "】不予受理";
        String content = "【" + activity.getSponsor() + "】申报的活动【" + activity.getFullName() + "】不予受理，不予受理意见：" + activity.getRejectContent();
        //审批管理员账号需要能接收初审、受理、审批、结果导出等消息
        List<User> adminUsers = userMapper.findAdminUserList(user);
        for (User adminUser : adminUsers) {
            messageService.instance(adminUser.getId(),title,content);
        }
    }

    /**
     * 审批流程中
     * @param activity
     * @param approve 下一级审批人员
     */
    public void splcz(Activity activity, User approve) {

        String title = "【"+activity.getFullName()+"】等待审批";
        String content = "【" + activity.getSponsor() + "】申报的活动【" + activity.getFullName() + "】等待审批，请及时审批。";
        String keyword = "立即审批";
        messageService.instance(approve.getId(), title, content, keyword, APPROVAL_URL);
    }

    /**
     * 通过审批
     * @param activity
     * @param user
     */
    public void tgsp(Activity activity, User user) {
        String title = "【"+activity.getFullName()+"】已通过审批";
        String content = "【" + activity.getSponsor() + "】申报的活动【" + activity.getFullName() + "】已通过审批。";
        //审批管理员账号需要能接收初审、受理、审批、结果导出等消息
        List<User> adminUsers = userMapper.findAdminUserList(user);
        for (User adminUser : adminUsers) {
            messageService.instance(adminUser.getId(),title,content);
        }
    }

    /**
     * 审批不通过
     * @param activity
     * @param user
     */
    public void spbtg(Activity activity,User user){
        String title = "【" + activity.getFullName() + "】未通过审批";
        String content = "【" + activity.getSponsor() + "】申报的活动【" + activity.getFullName() + "】未通过审批，不予许可意见：" + activity.getRejectContent();
        //审批管理员账号需要能接收初审、受理、审批、结果导出等消息
        List<User> adminUsers = userMapper.findAdminUserList(user);
        for (User adminUser : adminUsers) {
            messageService.instance(adminUser.getId(),title,content);
        }
    }

    /**
     * 审批退回
     * @param activity
     * @param user
     */
    public void spth(Activity activity,User user){
        String title = "【" + activity.getFullName() + "】审批被退回";
        String content = "【" + activity.getSponsor() + "】申报的活动【" + activity.getFullName() + "】审批被退回，退回意见：" + activity.getRejectContent();
        //审批管理员账号需要能接收初审、受理、审批、结果导出等消息
        List<User> adminUsers = userMapper.findAdminUserList(user);
        for (User adminUser : adminUsers) {
            messageService.instance(adminUser.getId(),title,content);
        }
    }


    private void notifyUserAndAdmin(List<User> userList, String title, String content, String keyword, String url) {
        List<Long> list=new ArrayList<>();
        for (User user : userList) {
            list.add(user.getId());
            messageService.instance(user.getId(),title,content,keyword,url);
        }

        if(list!=null && list.size()>0){
            //审批管理员账号需要能接收初审、受理、审批、结果导出等消息
            User user = userMapper.findUserById(userList.get(0).getId());
            List<User> adminUsers = userMapper.findAdminUserList(user);
            for (User adminUser : adminUsers) {
                // 防止重复发送
                if(!list.contains(adminUser.getId())){
                    messageService.instance(adminUser.getId(),title,content);
                }
            }
        }
    }
}
