package com.bcxin.sp.work.service.third.anbao;

import cn.hutool.core.collection.CollectionUtil;
import cn.hutool.core.date.DateUtil;
import cn.hutool.core.lang.Console;
import cn.hutool.core.lang.UUID;
import cn.hutool.core.util.IdUtil;
import cn.hutool.core.util.StrUtil;
import com.alibaba.fastjson.JSONObject;
import com.bcxin.sp.config.cache.CacheUtils;
import com.bcxin.sp.config.exception.BusinessException;
import com.bcxin.sp.config.redis.RedisUtils;
import com.bcxin.sp.work.dao.activity.base.ActivityMapper;
import com.bcxin.sp.work.dao.activity.extend.ActivityMaterialMapper;
import com.bcxin.sp.work.dao.obpm.SyncAnbaoMapper;
import com.bcxin.sp.work.dao.user.UserMapper;
import com.bcxin.sp.work.entity.domain.activity.base.Activity;
import com.bcxin.sp.work.entity.domain.activity.expand.ActivityMaterial;
import com.bcxin.sp.work.entity.domain.user.User;
import com.bcxin.sp.work.entity.dto.ActivityAnbaoDto;
import com.bcxin.sp.work.entity.dto.AjaxResult;
import com.bcxin.sp.work.entity.dto.FileInfoAnbaoDto;
import com.bcxin.sp.work.entity.dto.anbao.UserAnbaoDto;
import com.bcxin.sp.work.service.third.nxzw.UpProMaterial;
import com.bcxin.sp.work.util.Const.DictConst;
import com.bcxin.sp.work.util.Const.GlobalConst;
import com.bcxin.sp.work.util.MD5Util;
import com.bcxin.sp.work.util.sys.ConfigUtil;
import com.google.common.collect.Lists;
import org.apache.commons.lang3.StringUtils;
import org.apache.shiro.SecurityUtils;
import org.apache.shiro.authc.AuthenticationException;
import org.apache.shiro.authc.UsernamePasswordToken;
import org.apache.shiro.session.Session;
import org.apache.shiro.subject.Subject;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.List;

/**
 * 首页service
 */
@Service
public class AnbaoService {

    private final static List<String> IGNORE_LIST
            = Lists.newArrayList("森林","边防","拘留","交通","水","轨道","人口","刑侦","司令","出租车");

    @Resource
    private UserMapper userMapper;
    @Resource
    private ActivityMapper activityMapper;

    @Resource
    private SyncAnbaoMapper syncAnbaoMapper;
    @Resource
    private RedisUtils redisUtils;

    @Resource
    private ActivityMaterialMapper activityMaterialMapper;

    public static void main(String[] args) {
        System.out.println(MD5Util.string2MD5("BCXIN" + "bcx001" + DateUtil.today()));
    }

    /**
     * 安保系统单点登录
     *
     *
     * @return
     * @throws BusinessException
     */
    public AjaxResult anbaoTokenValidate(String token,String username,String randomKey) throws BusinessException {
        AjaxResult result = new AjaxResult();
        //token解析
        String idCardNo = syncAnbaoMapper.getIdCode(username);
        if(StringUtils.isEmpty(idCardNo)){
            //username可能是身份证，查询账号
            String name = syncAnbaoMapper.getUsername(username);
            if(StringUtils.isNotEmpty(name)){
                idCardNo = username;
                username = name;
            }else{
                throw new BusinessException("用户信息不存在，单点失败");
            }
        }
        Console.log("拿到idcardNo.." + idCardNo);
        String tokenStr="";
        if (StrUtil.isNotEmpty(randomKey)) {
            tokenStr = MD5Util.string2MD5("BCXIN" + username + DateUtil.today() + randomKey);
        } else {
            tokenStr = MD5Util.string2MD5("BCXIN" + username + DateUtil.today());
        }
        if (!tokenStr.equals(token)) {
            System.out.println("============>anbaoTokenValidate == username:"+username+"today:"+DateUtil.today()+"randomKey:"+randomKey);
            throw new BusinessException("秘钥错误");
        }
        /* */
        User dbUser = userMapper.findUserByUserName(idCardNo);
        if (dbUser == null) {
            throw new BusinessException("用户不存在，请联系管理员");
        }
        UsernamePasswordToken token1 = new UsernamePasswordToken(dbUser.getUsername(), dbUser.getPassword(), "");
        Subject subject = SecurityUtils.getSubject();
        try
        {
            subject.login(token1);
            Session session = subject.getSession();
            System.out.println(session.getId().toString());
            dbUser.setLoginDay(DateUtil.today());
            redisUtils.set(token, JSONObject.toJSONString(dbUser));
            //加入静态缓存
//            CacheUtils.put(token,dbUser);
//            CacheUtils.put(token+":SESSION",session.getId().toString());
            result.setSuccessful(true);
            return result;
        }
        catch (AuthenticationException e)
        {
            String msg = "用户或密码错误";
            if (StringUtils.isNotEmpty(e.getMessage()))
            {
                msg = e.getMessage();
            }
            result.setSuccessful(false);
            result.setMsg(msg);
            return result;
        }
    }

    private static String ROM_SIGN="ghj6u56u343h35345y3y";

    public String setSign(){
        ROM_SIGN = MD5Util.string2MD5(UUID.randomUUID().toString());
        return ROM_SIGN;
    }
    public boolean verSign(String sign){
        if(ROM_SIGN.equals(sign)){
            ROM_SIGN = MD5Util.string2MD5(UUID.randomUUID().toString());
            return true;
        }
        return false;
    }

    /**
     * <b> 用户信息同步到审批系统 </b>
     * @author ZXF
     * @create 2023/11/08 0008 17:45
     * @version
     * @注意事项 </b>
     */
    public void syncUserChange(){
        List<UserAnbaoDto> list = syncAnbaoMapper.findUserByDay(DateUtil.formatDate(DateUtil.yesterday()));
        if (CollectionUtil.isEmpty(list)) {
            return;
        }
        Console.log("开始解析：{}",list);
        for (UserAnbaoDto bean : list) {

            Console.log("符合要求的数据：{}",bean);
            User user = userMapper.findUserByUserName(bean.getIdentityCard());
            if (user == null) {
                user = new User();
                user.setUsername(bean.getIdentityCard());
                user.setPassword(GlobalConst.DEFAULT_PASSWORD);
            }
            user.setRealName(bean.getName());
            user.setPoliceNumber(bean.getAlarm());
            user.setDepart(bean.getIndustryTitle());
            String province = StrUtil.sub(bean.getOrganCode(),0,2)+"0000";
            user.setProvince(province);
            user.setOrganCode(bean.getOrganCode());
            user.setPhone(bean.getTrombone());
            user.setRole(bean.getRole());
            user.setActive(true);
            user.setAddTime(DateUtil.date());
            String organCode = StrUtil.sub(bean.getOrganCode(),0,6);
            /* 省 */
            if (organCode.endsWith("0000")) {
                user.setRegionLevel(1);
            } else {
                /* 市 */
                if (organCode.endsWith("00")) {
                    user.setCity(organCode);
                    user.setRegionLevel(2);
                }
                /* 区县 */
                else {
                    user.setCity(StrUtil.sub(bean.getOrganCode(), 0, 4) + "00");
                    user.setArea(organCode);
                    user.setRegionLevel(3);
                }
            }
            user.setUpdater(bean.getModifiedId());
            if (user.getId() == null) {
                Console.log("新增：{}",user.getUsername());
                userMapper.insert(user);
            } else {
                Console.log("修改：{}",user.getUsername());
                user.setUpdateTime(DateUtil.date());
                userMapper.updateById(user);
            }

        }
    }

    /**
     * <b> 活动信息同步到安保系统 </b>
     * @author ZXF
     * @create 2023/11/08 0008 17:45
     * @version
     * @注意事项 </b>
     */
    public void syncSaveActivityOut(){
        List<String> nos = syncAnbaoMapper.findActivityNoByDay(DateUtil.formatDate(DateUtil.yesterday()));
        List<ActivityAnbaoDto> list;
        if(nos.size()==0){
            list = activityMapper.findActivityByDay(DateUtil.formatDate(DateUtil.yesterday()));
        }else{
            list = activityMapper.findActivityByDayAndNotNo(DateUtil.formatDate(DateUtil.yesterday()),nos);
        }
        for (ActivityAnbaoDto dto:list) {
            String approvalStatus = dto.getApprovalStatus();
            String status = "";
            if(DictConst.STATUS_CSZ.equals(approvalStatus)){
                status = "8";//待审查
            }else if(DictConst.STATUS_CSXG.equals(approvalStatus)||DictConst.STATUS_SQCP.equals(approvalStatus)){
                status = "2";//审查不通过
            }else if(DictConst.STATUS_CSTG.equals(approvalStatus)){
                status = "3";//审查通过
            }else if(DictConst.STATUS_IN.equals(approvalStatus)||DictConst.STATUS_SLZ.equals(approvalStatus)){
                status = "9";//待审核
            }else if(DictConst.STATUS_NO.equals(approvalStatus)||DictConst.STATUS_REJECT.equals(approvalStatus)||DictConst.STATUS_BSL.equals(approvalStatus)){
                status = "4";//审核不通过
            }else if(DictConst.STATUS_YES.equals(approvalStatus)){
                status = "5";//审核通过
            }
            if("未归档".equals(dto.getArchiveStatus())){
                dto.setArchiveStatus("0");
            }else{
                dto.setArchiveStatus("1");
            }
            if("大活审批系统".equals(dto.getDataSource())){
                dto.setDataSource("9");
            }
            dto.setActId(Long.parseLong(dto.getFkId()));
            dto.setApprovalStatus(status);
            syncAnbaoMapper.saveAnbaoActivity(dto);
        }
    }

    /**
     * <b> 活动信息同步到安保系统 </b>
     * @author ZXF
     * @create 2023/11/08 0008 17:45
     * @version
     * @注意事项 </b>
     */
    public void syncUpdateActivityOut(){
        List<ActivityAnbaoDto> list = activityMapper.findActivityByDay(DateUtil.formatDate(DateUtil.yesterday()));
        for (ActivityAnbaoDto dto:list) {
            String approvalStatus = dto.getApprovalStatus();
            String status = "";
            if(DictConst.STATUS_CSZ.equals(approvalStatus)){
                status = "8";//待审查
            }else if(DictConst.STATUS_CSXG.equals(approvalStatus)||DictConst.STATUS_SQCP.equals(approvalStatus)){
                status = "2";//审查不通过
            }else if(DictConst.STATUS_CSTG.equals(approvalStatus)){
                status = "3";//审查通过
            }else if(DictConst.STATUS_IN.equals(approvalStatus)||DictConst.STATUS_SLZ.equals(approvalStatus)){
                status = "9";//待审核
            }else if(DictConst.STATUS_NO.equals(approvalStatus)||DictConst.STATUS_REJECT.equals(approvalStatus)||DictConst.STATUS_BSL.equals(approvalStatus)){
                status = "4";//审核不通过
            }else if(DictConst.STATUS_YES.equals(approvalStatus)){
                status = "5";//审核通过
            }
            if("未归档".equals(dto.getArchiveStatus())){
                dto.setArchiveStatus("0");
            }else{
                dto.setArchiveStatus("1");
            }
            if("大活审批系统".equals(dto.getDataSource())){
                dto.setDataSource("9");
            }
            dto.setActId(Long.parseLong(dto.getFkId()));
            dto.setApprovalStatus(status);
            syncAnbaoMapper.updateAnbaoActivity(dto);
        }
    }

    /**
     * <b> 活动审批状态同步到安保系统（一小时前到当前的变更数据） </b>
     * @author ZXF
     * @create 2023/11/08 0008 17:45
     * @version
     * @注意事项 </b>
     */
    public void syncActivityStatusOut(){
        List<ActivityAnbaoDto> list = activityMapper.findActivityByTime();
        for (ActivityAnbaoDto dto:list) {
            syncActivityStatusOut(dto.getApprovalStatus(),dto.getActNo());
        }
    }

    /**
     * <b> 活动审批状态同步到安保系统 </b>
     * @author ZXF
     * @create 2023/11/08 0008 17:45
     * @version
     * @注意事项 </b>
     */
    public void syncActivityStatusOut(String approvalStatus,String activityNo){
        String status = "";
        if(DictConst.STATUS_CSZ.equals(approvalStatus)){
            status = "8";//待审查
        }else if(DictConst.STATUS_CSXG.equals(approvalStatus)||DictConst.STATUS_SQCP.equals(approvalStatus)){
            status = "2";//审查不通过
        }else if(DictConst.STATUS_CSTG.equals(approvalStatus)){
            status = "3";//审查通过
        }else if(DictConst.STATUS_IN.equals(approvalStatus)||DictConst.STATUS_SLZ.equals(approvalStatus)){
            status = "9";//待审核
        }else if(DictConst.STATUS_NO.equals(approvalStatus)||DictConst.STATUS_REJECT.equals(approvalStatus)||DictConst.STATUS_BSL.equals(approvalStatus)){
            status = "4";//审核不通过
        }else if(DictConst.STATUS_YES.equals(approvalStatus)){
            status = "5";//审核通过
        }
        if(StringUtils.isNotEmpty(status)){
            syncAnbaoMapper.updateAnbaoActivityStatus(status,activityNo);
        }
    }

    /**
     * <b> 活动附件同步到安保系统 </b>
     * @author ZXF
     * @create 2023/11/08 0008 17:45
     * @version
     * @注意事项 </b>
     */
    public void syncActivityFileOut(){
        //当天存在变更的文件对应活动id
        List<String> list = activityMaterialMapper.findActivityIdByDay(DateUtil.formatDate(DateUtil.yesterday()));
        for (String activityId:list) {
            String actId = syncAnbaoMapper.getActId(activityId);
            List<FileInfoAnbaoDto> fiList = setFileInfoList(activityId,actId);
            if(fiList.size()>0){
                //批量删批量增
                syncAnbaoMapper.deleteFileInfoByActId(actId);
                syncAnbaoMapper.insertBatch(fiList);
            }
        }
    }

    private List<FileInfoAnbaoDto> setFileInfoList(String activityId,String actId){
        List<FileInfoAnbaoDto> list = Lists.newArrayList();
        ActivityMaterial materialList = activityMaterialMapper.findByActivityId(Long.parseLong(activityId));
        setFileInfoAnbaoDto(list,actId,"报批材料（许可审批材料）",materialList.getBpcl());
        setFileInfoAnbaoDto(list,actId,"评估材料",materialList.getPgcl());
        setFileInfoAnbaoDto(list,actId,"评估报告",materialList.getPgbg());
        setFileInfoAnbaoDto(list,actId,"评估报告出具方",materialList.getPgbgProvider());
        setFileInfoAnbaoDto(list,actId,"受理文书",materialList.getSlws());
        setFileInfoAnbaoDto(list,actId,"监理检查表",materialList.getJljcb());
        setFileInfoAnbaoDto(list,actId,"监理报告",materialList.getJlbg());
        setFileInfoAnbaoDto(list,actId,"许可决定书",materialList.getXkjds());
        setFileInfoAnbaoDto(list,actId,"安全工作方案",materialList.getAqgzfa());
        setFileInfoAnbaoDto(list,actId,"安全许可审批表",materialList.getAqxkspb());
        return list;
    }

    private void setFileInfoAnbaoDto(List<FileInfoAnbaoDto> list,String actId,String typeName,String url){
        if(StringUtils.isEmpty(url)){
            return;
        }
        url = url.startsWith("http")?url: ConfigUtil.getValue("web_url")+url;
        FileInfoAnbaoDto dto = new FileInfoAnbaoDto();
        dto.setFileId(IdUtil.simpleUUID());
        dto.setCreateTime(com.bcxin.sp.work.util.sys.DateUtil.getCurrentDateTime());
        dto.setFileName(url.substring(url.lastIndexOf("/")+1));
        dto.setFileType("."+dto.getFileName().split("\\.")[1]);
        dto.setFileTitle(typeName);
        dto.setRelId(actId);
        dto.setFileUrl(url);
        list.add(dto);
    }
}
