package com.bcxin.sp.work.service.third.zj;

import cn.hutool.http.HttpRequest;
import com.alibaba.fastjson.JSONObject;
import com.bcxin.sp.work.dao.activity.extend.ActivitySessionMapper;
import com.bcxin.sp.work.entity.domain.activity.base.Activity;
import com.bcxin.sp.work.entity.domain.activity.session.ActivitySession;
import com.bcxin.sp.work.entity.domain.sys.Region;
import com.bcxin.sp.work.entity.domain.user.User;
import com.bcxin.sp.work.entity.dto.AjaxResult;
import com.bcxin.sp.work.entity.dto.zj.EventDataDTO;
import com.bcxin.sp.work.service.activity.base.ActivityService;
import com.bcxin.sp.work.service.sys.RegionService;
import com.bcxin.sp.work.util.nx.SMEncryptUtil;
import com.bcxin.sp.work.util.sys.ConfigUtil;
import com.bcxin.sp.work.util.sys.DateUtil;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.core.env.Environment;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import javax.annotation.Resource;
import java.util.Base64;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 */
@Service("zjDataService")
@Transactional
@Slf4j
public class ZJDataService {


    @Resource
    private ActivityService activityService;
    @Resource
    private ActivitySessionMapper activitySessionMapper;
    @Resource
    private RegionService regionService;

    @Autowired
    private Environment environment;

    private static String TOKEN_URL = "/sj/login/api/dw/login";
    private static String UPLOAD_ACTION_URL = "/dw/base/dw/upload/action";

    private static String getToken(){
        JSONObject jsonObject = new JSONObject();
        /*账号：zj_admin001
        密码：dxhd666666*/
        jsonObject.put("username", ConfigUtil.getValue("ZJ_QUERY_USERNAME"));
        //密码需要传输进行2次base64加密
        jsonObject.put("password", ConfigUtil.getValue("ZJ_QUERY_PASSWORD"));
        String body = jsonObject.toJSONString();
        String url = ConfigUtil.getValue("ZJ_QUERY_URL")+TOKEN_URL;
        System.out.println("请求地址:"+url);
        System.out.println("请求报文:"+body);
        // token鉴权
        String ret = HttpRequest.post(url)
                .body(body)
                .execute().body();
        System.out.println("返回报文:"+ret);
        if(StringUtils.isNotEmpty(ret)){
            ResultZJ obj = JSONObject.parseObject(ret,ResultZJ.class);
            if(obj.getCode()==200){
                return obj.getMessage();
            }
            throw new RuntimeException(obj.getMessage());
        }
        return "";
    }

    public static void main(String[] args) {
//        String a = "zjza#1816";
//        Base64.Encoder encoder = Base64.getEncoder();
//        String a2 = encoder.encodeToString(encoder.encode(a.getBytes()));
//        System.out.println(a2);
        Map certAttributeNodeMap = new HashMap();
        String[] keyes = new String[2];
        keyes[0] = "_saml_pki_cert_subject";
        String value ="CN=何龙 620102197605143318,OU=00,OU=00,O=03,L=00,L=00,ST=62,C=CN";
        certAttributeNodeMap.put(keyes, value);
        System.out.println(certAttributeNodeMap.get(keyes));
        String val = certAttributeNodeMap.get(keyes)+"";
        val = val.split(",")[0].split(" ")[1];
        System.out.println(val);
    }

    /**
     * 上传-活动
     */
    public AjaxResult uploadaction(User user, Long activityId){
        AjaxResult result = new AjaxResult();
        Activity activity = activityService.findFullById(activityId);
        List<ActivitySession> resultList = activitySessionMapper.selectByActivityId(activityId);
        if(resultList.size()==0){
            result.setSuccessful(false);
            result.setMsg("活动场次信息为空（历史活动不支持上报，请前往部级上报平台手动录入）");
            return result;
        }
        for (ActivitySession activitySession : resultList){
            if(activitySession.getIsImprove() == 0){
                result.setSuccessful(false);
                result.setMsg("存在场次信息未完善");
                return result;
            }
        }
        if(!"330000".equals(activity.getProvince())){
            result.setSuccessful(false);
            result.setMsg("当前活动上报功能未开通");
            return result;
        }
        try {
            String code = user.getArea();
            if(StringUtils.isEmpty(user.getArea())){
                code = user.getCity();
            }
            if(StringUtils.isNotEmpty(code)){
                Region region = regionService.findById(Long.parseLong(code));
                user.setOrganCode(code+"000000");
                user.setDepart(region.getAlias());
            }
            EventDataDTO dto = EventDataDTO.create(user, activity, resultList);

            String token = getToken();
            if(StringUtils.isEmpty(token)){
                result.setSuccessful(false);
                result.setMsg("秘钥获取失败");
                return result;
            }
            System.out.println("Token:"+token);
            String url = ConfigUtil.getValue("ZJ_QUERY_URL")+UPLOAD_ACTION_URL;
            String resbody = JSONObject.toJSONString(dto);
            System.out.println("请求地址:"+url);
            System.out.println("请求报文:"+resbody);
//            JSONObject jsonObject = new JSONObject();
//            jsonObject.put("uploadAction", SMEncryptUtil.sm4Encrypt(resbody));
            // token鉴权
            String ret = HttpRequest.post(url)
                    .header("token", token)
                    .body(resbody)
//                    .body(jsonObject.toJSONString())
                    .execute().body();
            System.out.println("返回报文:"+ret);
            if(StringUtils.isNotEmpty(ret)){
                ResultZJ obj = JSONObject.parseObject(ret,ResultZJ.class);
                if(obj.getCode()==200){
                    //记录上报时间
                    activity = activityService.findById(activityId);
                    activity.setReportTime(DateUtil.getCurrentDateTime());
                    activityService.createOrUpdate(activity);
                    result.setSuccessful(true);
                    result.setMsg("上报成功");
                    return result;
                }
                result.setSuccessful(false);
                result.setMsg(obj.getMessage());
                return result;
            }
            result.setSuccessful(false);
            result.setMsg("上报接口返回异常");
            return result;
        }catch (Exception e){
            result.setSuccessful(false);
            result.setMsg("活动上报异常："+e.getMessage());
            return result;
        }
    }

    /**
     * 上传-活动
     */
    public AjaxResult uploadaction(User user, Activity activity,List<ActivitySession> resultList){
        AjaxResult result = new AjaxResult();
        try {
            String code = user.getArea();
            if(StringUtils.isEmpty(user.getArea())){
                code = user.getCity();
            }
            if(StringUtils.isNotEmpty(code)){
                Region region = regionService.findById(Long.parseLong(code));
                user.setOrganCode(code+"000000");
                user.setDepart(region.getAlias());
            }
            EventDataDTO dto = EventDataDTO.create(user, activity, resultList);
            // 测试模拟上报
            if("test".equals(environment.getProperty("spring.profiles.active"))){
                result.setSuccessful(true);
                result.setMsg("上报成功");
                return result;
            }
            String token = getToken();
            if(StringUtils.isEmpty(token)){
                result.setSuccessful(false);
                result.setMsg("秘钥获取失败，请联系管理员");
                return result;
            }
            System.out.println("Token:"+token);
            String url = ConfigUtil.getValue("ZJ_QUERY_URL")+UPLOAD_ACTION_URL;
            String resbody = JSONObject.toJSONString(dto);
            System.out.println("请求地址:"+url);
            System.out.println("请求报文:"+resbody);
//            JSONObject jsonObject = new JSONObject();
//            jsonObject.put("uploadAction", SMEncryptUtil.sm4Encrypt(resbody));
            // token鉴权
            String ret = HttpRequest.post(url)
                    .header("token", token)
                    .body(resbody)
//                    .body(jsonObject.toJSONString())
                    .execute().body();
            System.out.println("返回报文:"+ret);
            if(StringUtils.isNotEmpty(ret)){
                ResultZJ obj = JSONObject.parseObject(ret,ResultZJ.class);
                if(obj.getCode()==200){
                    result.setSuccessful(true);
                    result.setMsg("上报成功");
                    return result;
                }
                result.setSuccessful(false);
                result.setMsg(obj.getMessage()+",请与“上报信息-上报联系人”沟通或联系管理员");
                return result;
            }
            result.setSuccessful(false);
            result.setMsg("上报接口返回异常，请联系管理员");
            return result;
        }catch (Exception e){
            result.setSuccessful(false);
            result.setMsg("活动上报异常："+e.getMessage()+"，请联系管理员");
            return result;
        }
    }
}
