package com.bcxin.sp.work.service.user.zj;

import cn.hutool.core.collection.CollectionUtil;
import cn.hutool.core.date.DateTime;
import cn.hutool.core.date.DateUtil;
import cn.hutool.core.lang.Console;
import cn.hutool.core.map.MapUtil;
import cn.hutool.core.util.StrUtil;
import cn.hutool.http.HttpUtil;
import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.bcxin.sp.config.exception.BusinessException;
import com.bcxin.sp.work.dao.sys.ConfigMapper;
import com.bcxin.sp.work.dao.sys.RegionMapper;
import com.bcxin.sp.work.dao.user.UserMapper;
import com.bcxin.sp.work.entity.domain.sys.Config;
import com.bcxin.sp.work.entity.domain.sys.ConfigMenu;
import com.bcxin.sp.work.entity.domain.sys.Region;
import com.bcxin.sp.work.entity.domain.user.LoginUserDetail;
import com.bcxin.sp.work.entity.domain.user.User;
import com.bcxin.sp.work.entity.dto.AjaxResult;
import com.bcxin.sp.work.entity.dto.zj.Constant;
import com.bcxin.sp.work.entity.dto.zj.RespondsData;
import com.bcxin.sp.work.entity.dto.zj.UserDataDTO;
import com.bcxin.sp.work.service.log.AuditLogService;
import com.bcxin.sp.work.service.sys.ConfigMenuService;
import com.bcxin.sp.work.util.*;
import com.bcxin.sp.work.util.Const.DictConst;
import com.bcxin.sp.work.util.Const.GlobalConst;
import com.bcxin.sp.work.util.sys.ConfigUtil;
import com.google.common.collect.Lists;
import com.google.common.collect.Maps;
import com.zl.jwzh.yun.LogManage;
import com.zl.jwzh.yun.Qxrz;
import com.zl.jwzh.yun.comm.MyHelp;
import org.apache.commons.lang3.StringUtils;
import org.apache.http.NameValuePair;
import org.apache.shiro.SecurityUtils;
import org.apache.shiro.authc.AuthenticationException;
import org.apache.shiro.authc.UsernamePasswordToken;
import org.apache.shiro.session.Session;
import org.apache.shiro.subject.Subject;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;
import java.util.*;

/**
 * 对接浙江的警综平台
 */
@Service
@Transactional
public class PlatCommunicateService {

    private final static List<String> IGNORE_LIST
            = Lists.newArrayList("森林","边防","拘留","交通","水","轨道","人口","刑侦","司令","出租车");

    @Resource
    private AuditLogService auditLogService;

    @Resource
    private UserMapper userMapper;

    @Resource
    private RegionMapper regionMapper;

    @Resource
    private ConfigMapper configMapper;

    @Resource
    private ConfigMenuService configMenuService;

    /**
     * 治综系统单点登录
     * @param request
     * @param sessionId
     * @return
     * @throws BusinessException
     */
    public AjaxResult zzTokenValidate(HttpServletRequest request, String sessionId) throws BusinessException {
        AjaxResult result = new AjaxResult();
        Console.log("调用治综服务开始..");
        List<NameValuePair> nvps = Lists.newArrayList();
        //nvps.add(new BasicNameValuePair("key", "authentication"));
        //nvps.add(new BasicNameValuePair("sessionId", sessionId));
        Map<String,String> headerMap = Maps.newHashMap();
        headerMap.put("Authentication",sessionId);
        //String respMsg = BcxinHttpUtil.sendPostRequest(ConfigUtil.getValue("zz_token_validate_url"),nvps);
        String url = ConfigUtil.getValue("zz_token_validate_url") + "?key=identityCard,name,industryTitle,loginIp";
        String respMsg = BcxinHttpUtil.sendPostRequest(url,nvps,headerMap);

        Console.log("调用治综服务结束..");
        Console.log(respMsg);
        if (StringUtil.isEmpty(respMsg)) {
            /* 审计日志 */
            auditLogService.auditLog(DictConst.OP_LOGIN,null,DictConst.N);
            throw new BusinessException("获取浙江治综平台登录信息失败");
        }

        Map<String,Object> returnMap = JSON.parseObject(respMsg,Map.class);
        if (!(Boolean)returnMap.get("success")) {
            /* 审计日志 */
            auditLogService.auditLog(DictConst.OP_LOGIN,null,DictConst.N);
            throw new BusinessException("用户过期，登录失败，请重新从【治综平台】登录");
        }
        Map<String,Object> dataMap = JSON.parseObject(returnMap.get("data").toString(),Map.class);
        String idCardNo = dataMap.get("identityCard").toString();
        Console.log("得到治综身份证号码.." + idCardNo);

        User dbUser = userMapper.findUserByUserName(idCardNo);
        if (dbUser == null) {
            throw new BusinessException("用户["+idCardNo+"]不存在，请联系所属地市管理员");
        }
        if (!dbUser.isActive()) {
            throw new BusinessException("用户["+idCardNo+"]已冻结，请联系所属地市管理员");
        }
        if (StringUtil.isEmpty(dbUser.getRole())) {
            throw new BusinessException("用户["+idCardNo+"]尚未配置角色权限，请联系管理员配置");
        }
        if (StrUtil.isNotEmpty(dbUser.getProvince())) {
            Region region = regionMapper.selectById(Long.parseLong(dbUser.getProvince()));
            dbUser.setProvincename(region.getFullName());
        }
        if (StrUtil.isNotEmpty(dbUser.getCity())) {
            Region region = regionMapper.selectById(Long.parseLong(dbUser.getCity()));
            dbUser.setCityname(region.getFullName());
        }
        if (StrUtil.isNotEmpty(dbUser.getArea())) {
            Region region = regionMapper.selectById(Long.parseLong(dbUser.getArea()));
            dbUser.setAreaname(region.getFullName());
        }
        request.getSession().setAttribute(GlobalConst.LOGIN_USER, dbUser);
        request.getSession().setAttribute(GlobalConst.LOGIN_USER_DETAIL, cacheZZLoginUser(dataMap));

        /* 审计日志 */
        auditLogService.auditLog(DictConst.OP_LOGIN,null,DictConst.Y);

        result.setSuccessful(true);
        return result;
    }

    /**
     * 治综系统单点登录(改造后)
     * @param request
     * @param sessionId
     * @return
     * @throws BusinessException
     */
    public AjaxResult zzTokenValidateNew(HttpServletRequest request, String sessionId) throws BusinessException {
        AjaxResult result = new AjaxResult();
        Console.log("调用治综服务开始..");
        List<NameValuePair> nvps = Lists.newArrayList();
        //nvps.add(new BasicNameValuePair("key", "authentication"));
        //nvps.add(new BasicNameValuePair("sessionId", sessionId));
        Map<String,String> headerMap = Maps.newHashMap();
        headerMap.put("Authentication",sessionId);
        //String respMsg = BcxinHttpUtil.sendPostRequest(ConfigUtil.getValue("zz_token_validate_url"),nvps);
        String url = ConfigUtil.getValue("zz_token_validate_url") + "?key=identityCard,name,industryTitle,loginIp";
        String respMsg = BcxinHttpUtil.sendPostRequest(url,nvps,headerMap);

        Console.log("调用治综服务结束..");
        Console.log(respMsg);
        if (StringUtil.isEmpty(respMsg)) {
            /* 审计日志 */
            auditLogService.auditLog(DictConst.OP_LOGIN,null,DictConst.N);
            throw new BusinessException("获取浙江治综平台登录信息失败");
        }

        Map<String,Object> returnMap = JSON.parseObject(respMsg,Map.class);
        if (!(Boolean)returnMap.get("success")) {
            /* 审计日志 */
            auditLogService.auditLog(DictConst.OP_LOGIN,null,DictConst.N);
            throw new BusinessException("用户过期，登录失败，请重新从【治综平台】登录");
        }
        Map<String,Object> dataMap = JSON.parseObject(returnMap.get("data").toString(),Map.class);
        String idCardNo = dataMap.get("identityCard").toString();
        Console.log("得到治综身份证号码.." + idCardNo);

        User dbUser = userMapper.findUserByUserName(idCardNo);
        if (dbUser == null) {
            throw new BusinessException("用户["+idCardNo+"]不存在，请联系所属地市管理员");
        }
        UsernamePasswordToken token1 = new UsernamePasswordToken(dbUser.getUsername(), dbUser.getPassword(), "");
        Subject subject = SecurityUtils.getSubject();
        try
        {
            subject.login(token1);
            Session session = subject.getSession();
            System.out.println(session.getId().toString());
            result.setSuccessful(true);
            return result;
        }
        catch (AuthenticationException e)
        {
            String msg = "用户或密码错误";
            if (StringUtils.isNotEmpty(e.getMessage()))
            {
                msg = e.getMessage();
            }
            result.setSuccessful(false);
            result.setMsg(msg);
            return result;
        }
    }

    /**
     * 警综系统单点登录
     * @param request
     * @param token
     * @return
     * @throws BusinessException
     */
    public AjaxResult jzTokenValidate(HttpServletRequest request, String token) throws BusinessException {
        AjaxResult result = new AjaxResult();
        Console.log("调用警综服务开始..");
        Qxrz ser = new Qxrz();
        //调用服务
        Map<String, Object> map = ser.verificationToMap(token, "2");
        Console.log("调用警综服务结束..");
        Console.log(map);

        if (MapUtil.isEmpty(map)) {
            /* 审计日志 */
            auditLogService.auditLog(DictConst.OP_LOGIN,null,DictConst.N);
            throw new BusinessException("获取浙江警综平台登录信息失败，请重新登录");
        }
        String type = MyHelp.OtoS(map.get("TYPE"));//返回结果类型
        String description = MyHelp.OtoS(map.get("DESCRIPTION"));//返回结果描述
        Object returnMsg = map.get("RETURNMSG");
        Console.log("返回结果类型：" + type + "；返回结果描述：" + description + "；返回详细信息：" + returnMsg);
        Map<String, Object> returnMap = JSON.parseObject(returnMsg.toString(), Map.class);
        Console.log("转换returnMap结束..");
        if (!Objects.equals(type, "10000")) {
            /* 审计日志 */
            auditLogService.auditLog(DictConst.OP_LOGIN,null,DictConst.N);
            throw new BusinessException("浙江警综平台认证失败，请重新登录，异常信息：" + returnMap.toString());
        }

        String idCardNo = returnMap.get("SFZH")+"";

        Console.log("拿到idcardNo.." + idCardNo);
        /* */
        User dbUser = userMapper.findUserByUserName(idCardNo);
        if (dbUser == null) {
            throw new BusinessException("用户不存在，请联系管理员");
        }
        if (!dbUser.isActive()) {
            throw new BusinessException("用户已冻结，请联系所属地市管理员配置");
        }
        if (StringUtil.isEmpty(dbUser.getRole())) {
            throw new BusinessException("用户尚未配置角色权限，请联系所属地市管理员配置");
        }
        if (StrUtil.isNotEmpty(dbUser.getProvince())) {
            Region region = regionMapper.selectById(Long.parseLong(dbUser.getProvince()));
            dbUser.setProvincename(region.getFullName());
        }
        if (StrUtil.isNotEmpty(dbUser.getCity())) {
            Region region = regionMapper.selectById(Long.parseLong(dbUser.getCity()));
            dbUser.setCityname(region.getFullName());
        }
        if (StrUtil.isNotEmpty(dbUser.getArea())) {
            Region region = regionMapper.selectById(Long.parseLong(dbUser.getArea()));
            dbUser.setAreaname(region.getFullName());
        }
        request.getSession().setAttribute(GlobalConst.LOGIN_USER, dbUser);
        request.getSession().setAttribute(GlobalConst.LOGIN_USER_DETAIL, cacheZJLoginUser(returnMap));
        request.getSession().setAttribute(GlobalConst.LOGIN_USER_PROVINCE, dbUser.getProvince());
        /* 初始化菜单 */
        List<ConfigMenu> menuList = configMenuService.getUserMenu(dbUser);
        List<ConfigMenu> menuLevelOneList = Lists.newLinkedList();
        Map<Long, List<ConfigMenu>> menuLevelTwoMap = Maps.newLinkedHashMap();
        for (ConfigMenu menu : menuList) {
            if (DictConst.MENULEVEL_ONE.equals(menu.getMenuLevel())) {
                menuLevelOneList.add(menu);
            }
            if (DictConst.MENULEVEL_TWO.equals(menu.getMenuLevel())) {
                List<ConfigMenu> twoList = menuLevelTwoMap.get(menu.getParentId());
                if (CollectionUtil.isNotEmpty(twoList)) {
                    twoList.add(menu);
                    menuLevelTwoMap.put(menu.getParentId(), twoList);
                } else {
                    menuLevelTwoMap.put(menu.getParentId(), Lists.newArrayList(menu));
                }
            }
        }
        request.getSession().setAttribute(GlobalConst.LOGIN_USER_MENU_LEVEL_ONE, menuLevelOneList);
        request.getSession().setAttribute(GlobalConst.LOGIN_USER_MENU_LEVEL_TWO, menuLevelTwoMap);

        /* 审计日志 */
        auditLogService.auditLog(DictConst.OP_LOGIN,null,DictConst.Y);

        result.setSuccessful(true);
        return result;
    }

    /**
     * 警综系统单点登录(改造后)
     *
     *
     * @return
     * @throws BusinessException
     */
    public AjaxResult jzTokenValidateNew(String  appToken, String userToken) throws BusinessException {
        AjaxResult result = new AjaxResult();
        /*Console.log("调用警综服务开始..");
        Qxrz ser = new Qxrz();
        //调用服务
        Map<String, Object> map = ser.verificationToMap(token, "2");
        Console.log("调用警综服务结束..");
        Console.log(map);*/

      /*  if (MapUtil.isEmpty(map)) {
            *//* 审计日志 *//*
            auditLogService.auditLog(DictConst.OP_LOGIN,null,DictConst.N);
            throw new BusinessException("获取浙江警综平台登录信息失败，请重新登录");
        }*/
      /*  String type = MyHelp.OtoS(map.get("TYPE"));//返回结果类型
        String description = MyHelp.OtoS(map.get("DESCRIPTION"));//返回结果描述
        Object returnMsg = map.get("RETURNMSG");
        Console.log("返回结果类型：" + type + "；返回结果描述：" + description + "；返回详细信息：" + returnMsg);
        Map<String, Object> returnMap = JSON.parseObject(returnMsg.toString(), Map.class);
        Console.log("转换returnMap结束..");*/
        /*if (!Objects.equals(type, "10000")) {
            *//* 审计日志 *//*
            auditLogService.auditLog(DictConst.OP_LOGIN,null,DictConst.N);
            throw new BusinessException("浙江警综平台认证失败，请重新登录，异常信息：" + returnMap.toString());
        }*/
        Map  map=new HashMap();
        map.put("appTokenId",appToken);//应用令牌
        map.put("userTokenId",userToken);//用户令牌
        map.put("dqxtbs","20190816114900025");//当前系统标识
        String result1=  HttpUtil.post(Constant.UserURL+"/jyglb/apis/V2/getLoginUser",JSON.toJSONString(map));
        Console.log("用户基本信息获取服务:"+result1);
        JSONObject jsonObject=JSONObject.parseObject(result1);
        String data= jsonObject.get("result")+"";
        JSONObject jsonData=JSONObject.parseObject(data);
        if(jsonObject.get("status_code").equals("0001")){
            throw new BusinessException("获取浙江警综平台登录信息失败，请重新登录");
        }
        String idCardNo = jsonData.get("SFZH")+"";
        Console.log("拿到idcardNo.." + idCardNo);
        /* */
        User dbUser = userMapper.findUserByUserName(idCardNo);
        if (dbUser == null) {
            throw new BusinessException("用户不存在，请联系管理员");
        }
        UsernamePasswordToken token1 = new UsernamePasswordToken(dbUser.getUsername(), dbUser.getPassword(), "");
        Subject subject = SecurityUtils.getSubject();
        try
        {
            subject.login(token1);
            Session session = subject.getSession();
            System.out.println(session.getId().toString());
            result.setSuccessful(true);
            return result;
        }
        catch (AuthenticationException e)
        {
            String msg = "用户或密码错误";
            if (StringUtils.isNotEmpty(e.getMessage()))
            {
                msg = e.getMessage();
            }
            result.setSuccessful(false);
            result.setMsg(msg);
            return result;
        }
    }

    /**
     * 同步治综用户信息
     */
    public void syncUserData() {
        String url = ConfigUtil.getValue("zj_zz_data_sync_url");
        if (StringUtil.isEmpty(url)) {
            return;
        }
        /* 查询最后一次同步的时间 */
        Config config  = configMapper.selectBySysKey("zj_user_sync_last_date");
        String lastSyncDateStr = config.getSysValue();
        DateTime lastSyncDate = DateUtil.parseDate(lastSyncDateStr);
        /* 默认同步前一天，如果上次同步的日期距离很远，则循环同步到前一天 */
        long size = DateUtil.betweenDay(lastSyncDate,DateUtil.yesterday(),false);
        for (int i=1;i<=size;i++) {
            String syncDate = DateUtil.formatDateTime(DateUtil.offsetDay(lastSyncDate,i));
            syncUserDataSingleDate(url,syncDate);
        }

        /* 设置进入DB */
        ConfigUtil.putValue("zj_user_sync_last_date",DateUtil.formatDate(DateUtil.yesterday()));
        configMapper.updateBySysKey("zj_user_sync_last_date",DateUtil.formatDate(DateUtil.yesterday()));
    }


    /**
     * 同步治综用户信息
     */
    private void syncUserDataSingleDate(String url,String date) {
        String str = HttpUtil.get(url + "openApi/user/queryUser?modifiedDate=" + date.replace(" ","%20"));
        if (StringUtil.isEmpty(str)) {
            return;
        }
        UserDataDTO userDataDTO = JSON.parseObject(str, UserDataDTO.class);
        List<UserDataDTO.DataBean> list = userDataDTO.getData();
        if (CollectionUtil.isEmpty(list)) {
            return;
        }
        Console.log("开始解析：{}",list);
        for (UserDataDTO.DataBean bean : list) {
            /* 过滤不是治安大队的人 */
            if (!bean.getIndustryTitle().contains("治安")) {
                /* 如果是丽水市警务处，则允许通过 */
                if ( "浙江省丽水市公安局警务处".equals(bean.getIndustryTitle()) ) {
                    /* 不做任何处理 */
                } else if ( bean.getIndustryTitle().endsWith("公安局") ) {
                    /* 不做任何处理 */
                } else if ( bean.getIndustryTitle().endsWith("公安分局") ) {
                    /* 不做任何处理 */
                } else {
                    continue;
                }
            }
            boolean isIgnore = false;
            for (String ignore:IGNORE_LIST) {
                if (bean.getIndustryTitle().contains(ignore)) {
                    isIgnore = true;
                    break;
                }
            }
            if (isIgnore) {
                continue;
            }
            Console.log("符合要求的数据：{}",bean);
            User user = userMapper.findUserByUserName(bean.getIdentityCard());
            if (user == null) {
                user = new User();
                user.setUsername(bean.getIdentityCard());
                user.setPassword(GlobalConst.DEFAULT_PASSWORD);
            }
            user.setRealName(bean.getName());
            user.setPoliceNumber(bean.getAlarm());
            user.setDepart(bean.getIndustryTitle());
            user.setProvince("330000");
            user.setOrganCode(bean.getOrganCode());
            user.setPhone(bean.getTrombone());
            user.setActive(true);
            user.setAddTime(DateUtil.date());
            String organCode = StrUtil.sub(bean.getOrganCode(),0,6);
            /* 省 */
            if (organCode.endsWith("0000")) {
                user.setRegionLevel(1);
            } else {
                /* 市 */
                if (organCode.endsWith("00")) {
                    user.setCity(organCode);
                    user.setRegionLevel(2);
                }
                /* 区县 */
                else {
                    user.setCity(StrUtil.sub(bean.getOrganCode(), 0, 4) + "00");
                    user.setArea(organCode);
                    user.setRegionLevel(3);
                }
            }
            user.setUpdater("system");
            if (user.getId() == null) {
                Console.log("新增：{}",user.getUsername());
                userMapper.insert(user);
            } else {
                Console.log("修改：{}",user.getUsername());
                user.setUpdateTime(DateUtil.date());
                userMapper.updateById(user);
            }

        }
    }

    private LoginUserDetail cacheZJLoginUser(Map<String,Object> returnMap){
        LoginUserDetail detail = new LoginUserDetail();
        detail.setUserId(returnMap.get("SFZH")+"");
        detail.setUserName(returnMap.get("USERNAME").toString());
        detail.setOrganization(returnMap.get("DEPTNAME").toString());
        detail.setTerminalID(returnMap.get("IP").toString());
        return detail;
    }

    private LoginUserDetail cacheZZLoginUser(Map<String,Object> returnMap){
        LoginUserDetail detail = new LoginUserDetail();
        detail.setUserId(returnMap.get("identityCard").toString());
        detail.setUserName(returnMap.get("name").toString());
        detail.setOrganization(returnMap.get("industryTitle").toString());
        detail.setTerminalID(returnMap.get("loginIp").toString());
        return detail;
    }

    public void syncLog() {
        LogManage ser = new LogManage();
        String str = "<Log>" + "<Num_ID>350000100001</Num_ID>"
                + "<Reg_ID>1111111111</Reg_ID>"
                + "<User_ID>350000198609065541</User_ID>"
                + "<Organization>大同市公安局</Organization>"
                + "<Organization_ID>140200</Organization_ID>"
                + "<User_Name>李明</User_Name>"
                + "<Terminal_ID>10.10.10.10</Terminal_ID>"
                + "<Operate_Time>20130506121212</Operate_Time>"
                + "<Operate_Type>1</Operate_Type>"
                + "<Operate_Result>1</Operate_Result>"
                + "<Error_Code></Error_Code>"
                + "<Operate_Name>暂住人口查询</Operate_Name>" + "<Operate_Condition>"
                + "<![CDATA[name=‘张三’and sfzhm=‘350000198909073321’]]>"
                + "</Operate_Condition>" + "<BZ1>1</BZ1>" + "<BZ2>2</BZ2>"
                + "<BZ3>3</BZ3>" + "<BZ4>4</BZ4>" + "<BZ5>5</BZ5>"
                + "<BZ6>6</BZ6>" + "<BZ7>7</BZ7>" + "<BZ8>8</BZ8>"
                + "<BZ9>9</BZ9>" + "<BZ10>10</BZ10>" + "</Log>" + "<Log>"
                + "<Num_ID>Num_ID</Num_ID>" + "<Reg_ID>Reg_ID</Reg_ID>"
                + "<User_ID>User_ID</User_ID>"
                + "<Organization>Organization</Organization>"
                + "<Organization_ID>bmcode</Organization_ID>"
                + "<User_Name>User_Name</User_Name>"
                + "<Terminal_ID>Terminal_ID</Terminal_ID>"
                + "<Operate_Time>Operate_Time</Operate_Time>"
                + "<Operate_Type>1</Operate_Type>"
                + "<Operate_Result>1</Operate_Result>"
                + "<Error_Code>Code</Error_Code>"
                + "<Operate_Name>Operate_Name</Operate_Name>"
                + "<Operate_Condition>" + "Operate_Condition"
                + "</Operate_Condition>" + "<BZ1>BZ1</BZ1>" + "<BZ2>BZ2</BZ2>"
                + "<BZ3>BZ3</BZ3>" + "<BZ4>BZ4</BZ4>" + "<BZ5>BZ5</BZ5>"
                + "<BZ6>BZ6</BZ6>" + "<BZ7>BZ7</BZ7>" + "<BZ8>BZ8</BZ8>"
                + "<BZ9>BZ9</BZ9>" + "<BZ10>BZ10</BZ10>" + "</Log>";
        //调用服务
        Map<String, Object> map = ser.AcceptSystemLogsToMap(str);
        //解析返回数据
        if (map != null) {
            String type = MyHelp.OtoS(map.get("TYPE"));//返回结果类型
            String description = MyHelp.OtoS(map.get("DESCRIPTION"));//返回结果描述
            Object returnmsg = map.get("RETURNMSG");
            System.out.println("返回结果类型：" + type + "；返回结果描述：" + description + "；返回详细信息：" + returnmsg);
        } else {
            System.out.println("------【未正常返回数据】---------------");
        }
    }

    /**
     *@应用令牌生成服务
     * @return
     */
    public AjaxResult createAppToken(){
       Map  map=new HashMap();
        map.put("appKey","");//应用主键
        map.put("secureKey","");//秘钥主键
        map.put("yhsj",System.currentTimeMillis());//用户端时间
        String  result=  HttpUtil.post(Constant.UserURL+"/jwt/nologin/V2/202307/createAppToken",JSON.toJSONString(map));
        return JSON.parseObject(result,AjaxResult.class) ;
    }

    /**
     * @用户基本信息获取服务
     *
     * @return
     */
    public AjaxResult getLoginUser(String appTokenId,String userTokenId){
        Map  map=new HashMap();
        map.put("appTokenId",appTokenId);//应用令牌
        map.put("userTokenId",userTokenId);//用户令牌
        map.put("dqxtbs","20190816114900025");//当前系统标识
        String  result=  HttpUtil.post(Constant.UserURL+"/jyglb/apis/V2/getLoginUser",JSON.toJSONString(map));
        return JSON.parseObject(result,AjaxResult.class) ;
    }

    /**
     * @令牌续期注销服务
     * @return
     */

    public RespondsData renewOrOfflineToken(String tokenId, String type,String action,String callerId){
        Map  map=new HashMap();
        map.put("tokenId","");//令牌标识
        map.put("type","");//令牌类型 格式类型为枚举值，包括“user”表示用户令牌；“app”表示应用令牌
        map.put("action","");//令牌行为 格式类型为枚举值，包括以下两个类型：“renew”表示续期操作；“offline”表示注销操作
        map.put("callerId","");//应用唯一标识 接口调用方标识，用于检查接口调用的合法性
        map.put("callerTimestamp","");//调用时间 由年月日时分秒组成的中国时区时间字符串，格式 yyyy-MM-dd HH:mm:ss
        map.put("callerNounce","");//调用随机值 本次请求时的随机字符串
        //必须升序排序
        Map<String, Object> callerSign = new LinkedHashMap<>();
        map.put("tokenId", "");
        map.put("type", "");
        map.put("action", "");
        map.put("callerId", "");
        map.put("callerNounce", "");
        map.put("callerTimestamp", "");
        String json= com.alibaba.fastjson.JSON.toJSONString(callerSign);
        map.put("callerSign", CryptoUtils.encryptHexSm3(json));//签名 应采用国产密码算法对接口请求参数进行完整性保护；对入参去除‘callerSign’，‘dqxtbs’后进行递增排序后对json对象进行SM3加密
        map.put("dqxtbs","20190816114900025");//当前系统标识 输入系统唯一标识（例如系统AK信息、系统注册码requestid、系统域名host）（本字段不参与签名）
        String  result=  HttpUtil.post(Constant.UserURL+"/jwt/nologin/V2/renewOrOfflineToken",JSON.toJSONString(map));
        return JSON.parseObject(result,RespondsData.class) ;
    }

    /**
     * @用户令牌校验服务
     * @return
     */
    public RespondsData verifyUserToken(String userTokenId){
        Map  map=new HashMap();
        map.put("userTokenId","");//用户令牌
        String  result=  HttpUtil.post(Constant.UserURL+"/jwt/nologin/V2/verifyUserToken",JSON.toJSONString(map));
        return JSON.parseObject(result,RespondsData.class) ;
    }

    /**
     *@应用令牌校验服务
     * @return
     */
    public RespondsData verifyAppToken(String appTokenId){
        Map  map=new HashMap();
        map.put("appTokenId","");//用户令牌
        map.put("dqxtbs","20190816114900025");//当前系统标识
        String  result=  HttpUtil.post(Constant.UserURL+"/jwt/nologin/V2/verifyAppToken",JSON.toJSONString(map));
        return JSON.parseObject(result,RespondsData.class) ;
    }
    /**
     *@用户详细信息接口
     * @return
     */
    public RespondsData getDetailedUser(String appTokenId,String userTokenId){
        Map  map=new HashMap();
        map.put("appTokenId","");//应用令牌
        map.put("userTokenId","");//用户令牌
        map.put("dqxtbs","20190816114900025");//当前系统标识
        String  result=  HttpUtil.post(Constant.UserURL+"/jyglb/apis/V2/getDetailedUser",JSON.toJSONString(map));
        return JSON.parseObject(result,RespondsData.class) ;
    }
}
