package com.bcxin.sp.work.timer;

import cn.hutool.core.collection.CollUtil;
import cn.hutool.core.date.DatePattern;
import cn.hutool.core.date.DateUtil;
import cn.hutool.core.io.FileUtil;
import cn.hutool.http.HttpUtil;
import com.alibaba.fastjson.JSON;
import com.bcxin.sp.work.dao.activity.base.ActivityMapper;
import com.bcxin.sp.work.entity.domain.activity.base.Activity;
import com.bcxin.sp.work.entity.domain.activity.survey.Survey;
import com.bcxin.sp.work.entity.domain.log.FileSyncLog;
import com.bcxin.sp.work.service.activity.base.ActivityService;
import com.bcxin.sp.work.service.activity.survey.SurveyService;
import com.bcxin.sp.work.service.log.LogService;
import com.bcxin.sp.work.service.third.anbao.AnbaoService;
import com.bcxin.sp.work.util.BcxinFileUtil;
import com.bcxin.sp.work.util.Const.DictConst;
import com.bcxin.sp.work.util.Const.GlobalConst;
import com.bcxin.sp.work.util.DESUtil;
import com.bcxin.sp.work.util.SpringContextUtil;
import com.bcxin.sp.work.util.StringUtil;
import com.bcxin.sp.work.util.sys.ConfigUtil;
import com.google.common.collect.Maps;
import com.google.common.io.Files;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import javax.annotation.Resource;
import java.io.File;
import java.util.ArrayList;
import java.util.List;
import java.util.Map;
import java.util.Objects;

/**
 * <b>Function </b>
 *
 * @author LuoPeng
 * @date 2016年12月15日 上午10:23:30
 * @注意事项 </b>
 * <b>
 */
@Service("scheduleService")
@Transactional
public class ScheduleService {

    /**
     * 同步审批结果文件夹名称
     */
    private final static String SPJG_FOLDER = "spjg";

    /**
     * 文件读取结果，文件标识
     */
    private final static String SPFSLOG = "_spfslog_";

    @Resource
    private SyncActivityService syncActivityService;

    @Resource
    private SyncServiceOrgService syncServiceOrgService;

    @Resource
    private SyncContractorService syncContractorService;

    @Resource
    private SyncAssessmentService syncAssessmentService;

    @Resource
    private SyncFileLogService syncFileLogService;

    @Resource
    private SyncSurveyService syncSurveyService;

    @Resource
    private SyncSupervisorService syncSupervisorService;

    @Resource
    private SurveyService surveyService;

    @Resource
    private ActivityService activityService;

    @Resource
    private AnbaoService anbaoService;

    @Resource
    private SyncZJService syncZJService;

    @Resource
    private ActivityMapper activityMapper;

    @Resource
    private LogService logService;

    @Resource
    private ZJJZScheduleService zjjzScheduleService;



    public void syncActivityData() throws Exception {
        //if (checkProfile()) {
        //    return;
        //}
        syncActivityService.importData();
        syncActivityService.importApprovalData();
    }

    private boolean checkProfile() {
        String profile = SpringContextUtil.getActiveProfile();
        if ("dev".equals(profile)) {
            return true;
        }
        return false;
    }

    public void syncSupervisorData() throws Exception {
        if (checkProfile()) {
            return;
        }
        syncSupervisorService.importData();
    }

    public void syncSurveyData() throws Exception {
        if (checkProfile()) {
            return;
        }
        syncSurveyService.importData();
    }

    public void syncOrgData() throws Exception {
        if (checkProfile()) {
            return;
        }
        syncServiceOrgService.importData();
    }

    public void syncContractorData() throws Exception {
        if (checkProfile()) {
            return;
        }
        syncContractorService.importData();
    }

    public void syncAssessmentData() throws Exception {
        if (checkProfile()) {
            return;
        }
        syncAssessmentService.importData();
    }

    public void repairSurveyData() {
        if (checkProfile()) {
            return;
        }
        List<Survey> list = surveyService.findRepair();
        for (Survey survey : list) {
            if (survey == null) continue;
            if (survey.getPssId() == null) continue;
            Activity activity = activityService.findByPssId(survey.getPssId());
            if (activity != null) {
                survey.setActivityId(activity.getId());
                surveyService.update(survey);
                activity.setSurveyInfo(DictConst.Y);
                activityMapper.updateById(activity);
            }
        }
    }

    public void repairActivitySyncData() {
        if (checkProfile()) {
            return;
        }
        activityService.repairActivitySync();
    }

    public void repairFileSyncData() throws Exception {
        if (checkProfile()) {
            return;
        }
        syncFileLogService.importData();
    }

    public void repairApproval2SL() {
        if (checkProfile()) {
            return;
        }
        activityService.repairApproval2SL();
    }

    public void syncZJUserData() {
        if (checkProfile()) {
            return;
        }
        syncZJService.syncUserData();
    }

    public void generateSBFileReadData() throws Exception {
        if (checkProfile()) {
            return;
        }
        /*文件生成，同步*/
        if (!Objects.equals("file", ConfigUtil.getValue("pss-communicate-mode"))) {
            return;
        }
        /* 每次生成今天的记录文件 */
        List<FileSyncLog> list = logService.findTodayNeedSyncRecord();
        if (CollUtil.isEmpty(list)) {
            return;
        }
        List<Map<String, String>> reMapList = new ArrayList<>();
        for (FileSyncLog log : list) {
            Map<String, String> map = Maps.newHashMap();
            map.put("fileName", log.getFileName());
            map.put("readTime", DateUtil.format(log.getAddTime(), DatePattern.NORM_DATETIME_PATTERN));
            reMapList.add(map);
        }

        String result = JSON.toJSONString(reMapList);

        String spDir = ConfigUtil.getValue("spjg_folder");
        String upload_path = ConfigUtil.getValue("stuff-path");
        // 组装文件夹
        String[] folderPath = new String[]{upload_path, spDir, DateUtil.today(), SPJG_FOLDER};
        if (StringUtil.isNotEmpty(ConfigUtil.getValue("profile_envi"))
                && ConfigUtil.getValue("profile_envi").startsWith("pre")) {
            folderPath = new String[]{upload_path, spDir, ConfigUtil.getValue("envi"), DateUtil.today(), SPJG_FOLDER};
        }
        String dir = BcxinFileUtil.appendFolderPath(folderPath);
        //打包活动信息 文件名： _spfslog_100021_t_20170101010101
        String fileName = BcxinFileUtil.packTimestamp(SPFSLOG) + ".bcxlog";
        String detailurl = dir + fileName;
        FileUtil.mkdir(dir);
        File newFile = new File(detailurl);

        byte[] buf = DESUtil.encrypt(result.getBytes("UTF-8"), GlobalConst.KEY);
        Files.write(buf, newFile);
    }


    public void copyFileData() throws Exception {
        if (checkProfile()) {
            return;
        }
        if (!GlobalConst.SWITCH_ON.equals(ConfigUtil.getValue("switch_copyDir"))) {
            return;
        }
        String uploadPath = ConfigUtil.getValue("stuff-path");
        String[] sourcePath = new String[]{uploadPath, ConfigUtil.getValue("envi"), DateUtil.today()};
        String sourceDir = BcxinFileUtil.appendFolderPath(sourcePath);

        String[] targetPath = new String[]{ConfigUtil.getValue("copyDir_path"), DateUtil.today()};
        String targetDir = BcxinFileUtil.appendFolderPath(targetPath);

        /* 获取源目录的文件 */
        List<File> sourceList = FileUtil.loopFiles(sourceDir);

        /* 获得目标目录文件 */
        List<String> targetList = FileUtil.listFileNames(targetDir);

        /* 如果文件数量一致，则代表不需要同步 */
        if (sourceList.size() == targetList.size()) {
            return;
        }
        for (File file : sourceList) {
            if (targetList.contains(file.getName())) {
                continue;
            }
            String parentDir = file.getParent().replace(sourceDir, "");
            BcxinFileUtil.mkDir(targetDir + parentDir + File.separator);
            /* 复制文件 */
            File target = new File(targetDir + parentDir + File.separator + file.getName());
            Files.copy(file, target);
        }
    }

    /**
     * 浙江警综同步
     * @author wangjianjun
     * @date 2020/7/21
     */
    public void syncZJJZPersonAndDepart(){
        zjjzScheduleService.syncZJJZ();
    }
    /**
     * 浙江警综同步
     * @author wangjianjun
     * @date 2020/7/21
     */
    public void syncZJJZAuditLog(){
        zjjzScheduleService.syncZJJZLog();
    }

    /**
     * 浙江警综，初始化数据
     * @author wangjianjun
     * @date 2020/7/21
     */
    public void initSyncZJJZ1(){
        zjjzScheduleService.initZJJZ1();
    }
    /**
     * 浙江警综，初始化数据
     * @author wangjianjun
     * @date 2020/7/21
     */
    public void initSyncZJJZ2(){
        zjjzScheduleService.initZJJZ2();
    }

    /************************* 同步厦门安保系统 **************************/

    /**
     * <b> 用户同步 </b>
     * @author ZXF
     * @create 2024/01/10 0010 16:09
     * @version
     * @注意事项 </b>
     */
    public void syncUserChange(){
        HttpUtil.get(ConfigUtil.getValue("web_url")+"/thirdBusiness/anBaoUser/tb/1/"+anbaoService.setSign());
//        anbaoService.syncUserChange();
    }


    /**
     * <b> 活动信息同步到安保系统 </b>
     * @author ZXF
     * @create 2024/01/10 0010 16:09
     * @version
     * @注意事项 </b>
     */
    public void syncSaveActivityOut(){
        HttpUtil.get(ConfigUtil.getValue("web_url")+"/thirdBusiness/anBaoUser/tb/2/"+anbaoService.setSign());
//        anbaoService.syncSaveActivityOut();
    }


    /**
     * <b> 活动信息同步到安保系统 </b>
     * @author ZXF
     * @create 2024/01/10 0010 16:09
     * @version
     * @注意事项 </b>
     */
    public void syncUpdateActivityOut(){
        HttpUtil.get(ConfigUtil.getValue("web_url")+"/thirdBusiness/anBaoUser/tb/3/"+anbaoService.setSign());
//        anbaoService.syncUpdateActivityOut();
    }


    /**
     * <b> 活动文件同步到安全系统 </b>
     * @author ZXF
     * @create 2024/01/10 0010 16:09
     * @version
     * @注意事项 </b>
     */
    public void syncActivityFileOut(){
        HttpUtil.get(ConfigUtil.getValue("web_url")+"/thirdBusiness/anBaoUser/tb/5/"+anbaoService.setSign());
//        anbaoService.syncActivityFileOut();
    }


    /**
     * <b> 活动审批状态同步到安保系统 </b>
     * @author ZXF
     * @create 2024/01/10 0010 16:09
     * @version
     * @注意事项 </b>
     */
    public void syncActivityStatusOut(){
//        HttpUtil.get("http://localhost:8888/thirdBusiness/anBaoUser/tb/4/"+anbaoService.setSign());
        HttpUtil.get(ConfigUtil.getValue("web_url")+"/thirdBusiness/anBaoUser/tb/4/"+anbaoService.setSign());
//        anbaoService.syncActivityStatusOut();
    }

}
