package com.bcxin.sp.work.timer;

import org.springframework.scheduling.annotation.Scheduled;
import org.springframework.stereotype.Component;

import javax.annotation.Resource;

/**
 * 定时任务
 */
@Component
public class ScheduleTask {


	@Resource
	private ScheduleService scheduleService;


	//@Scheduled(fixedDelay=1000)  //第一种方式
	//fixedDelay延时多少毫秒，多少毫秒执行一次
	//@Scheduled(cron="0 * * * * *")     //第二种方式
	//1 Seconds (0-59)
	//2 Minutes (0-59)
	//3 Hours (0-23)
	//4 Day of month (1-31)
	//5 Month (1-12 or JAN-DEC)
	//6 Day of week (1-7 or SUN-SAT)
	//7 Year (1970-2099)
	//取值：可以是单个值，如6；
	//	也可以是个范围，如9-12；
	//	也可以是个列表，如9,11,13
	//	也可以是任意取值，使用*
	//0 * * * * * 代表每分钟执行一次
	//•"0 0 * * * *" = 每一小时执行一次.
	//•"*/10 * * * * *" = 没10秒执行一次.
	//•"0 0 8-10 * * *" = 每天8, 9 和 10 点整.
	//•"0 0/30 8-10 * * *" = 每天8:00, 8:30, 9:00, 9:30 和 10 点整.
	//•"0 0 9-17 * * MON-FRI" = 每周一到周五9-17点
	//•"0 0 0 25 12 ?" = 每一个圣诞节的午夜
	
	//"0 0 12 * * ?"    每天中午十二点触发 
	//"0 15 10 ? * *"    每天早上10：15触发 
	//"0 15 10 * * ?"    每天早上10：15触发 
	//"0 15 10 * * ? *"    每天早上10：15触发 
	//"0 15 10 * * ? 2005"    2005年的每天早上10：15触发 
	//"0 * 14 * * ?"    每天从下午2点开始到2点59分每分钟一次触发 
	//"0 0/5 14 * * ?"    每天从下午2点开始到2：55分结束每5分钟一次触发 
	//"0 0/5 14,18 * * ?"    每天的下午2点至2：55和6点至6点55分两个时间段内每5分钟一次触发 
	//"0 0-5 14 * * ?"    每天14:00至14:05每分钟一次触发 
	//"0 10,44 14 ? 3 WED"    三月的每周三的14：10和14：44触发 
	//"0 15 10 ? * MON-FRI"    每个周一、周二、周三、周四、周五的10：15触发
	
	
	/**
	 * <b>定时任务，每隔5分钟读取一遍目录结构，读取活动信息 </b>
	 * 同步审批结果
	 * @return
	 * @author LuoPeng
	 * @date 2016年12月14日 下午4:39:53
	 * @注意事项 </b>
	 * <b>
	 */
	@Scheduled(cron="0 0/1 * * * ?")//每隔5分钟读取一遍
	public void syncActivityData() throws Exception{
		scheduleService.syncActivityData();
	}


	/**
	 * <b>定时任务，每隔30分钟读取一遍目录结构，读取监理报告 </b>
	 *
	 * @return
	 * @author LuoPeng
	 * @date 2016年12月14日 下午4:39:53
	 * @注意事项 </b>
	 * <b>
	 */
	@Scheduled(cron="0 0/5 * * * ?")//每隔30分钟读取一遍
	public void syncSupervisorData() throws Exception{
		scheduleService.syncSupervisorData();
	}


	/**
	 * <b>定时任务，每隔10分钟读取一遍目录结构，读取勘查信息 </b>
	 *
	 * @return
	 * @author LuoPeng
	 * @date 2016年12月14日 下午4:39:53
	 * @注意事项 </b>
	 * <b>
	 */
	@Scheduled(cron="0 0/5 * * * ?")//每隔10分钟读取一遍
	public void syncSurveyData() throws Exception{
		scheduleService.syncSurveyData();
	}

	/**
	 * <b>定时任务，将初审通过且已经有风评报告的活动状态变更为受理中 </b>
	 *
	 * @return
	 * @author LuoPeng
	 * @注意事项 </b>
	 * <b>
	 */
	@Scheduled(cron="0 */30 * * * ?")//每30分钟执行一次
	public void syncApproval() {
		scheduleService.repairApproval2SL();
	}


	/**
	 * <b>定时任务，修复勘查数据 </b>
	 *
	 * @return
	 * @author LuoPeng
	 * @注意事项 </b>
	 * <b>
	 */
	@Scheduled(cron="0 */5 * * * ?")//每10分钟执行一次
	public void repairSurveyData() {
		scheduleService.repairSurveyData();
	}


	/**
	 * <b>定时任务，修复活动的同步状态 </b>
	 *
	 * @return
	 * @author LuoPeng
	 * @注意事项 </b>
	 * <b>
	 */
	@Scheduled(cron="0 */5 * * * ?")//每5分钟执行一次
	public void repairActivitySyncData() {
		scheduleService.repairActivitySyncData();
	}


	/**
	 * <b>定时任务，修复文件的同步状态 </b>
	 *
	 * @return
	 * @author LuoPeng
	 * @注意事项 </b>
	 * <b>
	 */
	@Scheduled(cron="0 */10 * * * ?")//每10分钟执行一次
	public void repairFileSyncData() throws Exception {
		scheduleService.repairFileSyncData();
	}


	/**
	 * <b>定时任务，生成申报系统传过来的文件读取结果文件 </b>
	 *
	 * @return
	 * @author LuoPeng
	 * @注意事项 </b>
	 * <b>
	 */
	@Scheduled(cron="0 0 22 * * ?")//每天变更一次
	public void generateSBFileReadData() throws Exception {
		scheduleService.generateSBFileReadData();
	}


	/**
	 * <b>定时任务，同步机构 </b>
	 *
	 * @return
	 * @author LuoPeng
	 * @注意事项 </b>
	 * <b>
	 */
	@Scheduled(cron="0 0 23 * * ?")//每天晚上23点触发
	public void syncOrgData() throws Exception {
		scheduleService.syncOrgData();
	}

	/**
	 * <b>定时任务，同步承办者 </b>
	 *
	 * @return
	 * @author zxf
	 * @注意事项 </b>
	 * <b>
	 */
	@Scheduled(cron="0 0/1 * * * ?")//每天晚上23:20点触发
	public void syncContractorData() throws Exception {
		scheduleService.syncContractorData();
	}

	/**
	 * <b>定时任务，同步服务商 </b>
	 *
	 * @return
	 * @author zxf
	 * @注意事项 </b>
	 * <b>
	 */
	@Scheduled(cron="0 0/1 * * * ?")//每天晚上23:40点触发
	public void syncAssessmentData() throws Exception {
		scheduleService.syncAssessmentData();
	}


	/**
	 * <b>定时任务，同步浙江用户数据 </b>
	 *
	 * @return
	 * @author LuoPeng
	 * @注意事项 </b>
	 * <b>
	 */
	@Scheduled(cron="0 0 2 * * ?")//每天凌晨2点触发
	public void syncZJUserData() {
		scheduleService.syncZJUserData();
	}

	/**
	 * <b>定时任务，同步浙江警综平台的人员和部门信息 </b>
	 *
	 * @return
	 * @author LuoPeng
	 * @注意事项 </b>
	 * <b>
	 */
	@Scheduled(cron="0 0/1 * * * ?")//每分钟执行一次
	public void syncZJJZPersonAndDepart() {
		scheduleService.syncZJJZPersonAndDepart();
	}

	/**
	 * <b>定时任务，同步浙江警综平台日志 </b>
	 *
	 * @return
	 * @author LuoPeng
	 * @注意事项 </b>
	 * <b>
	 */
	@Scheduled(cron="0 0/5 * * * ?")//每分钟执行一次
	public void syncZJJZAuditLog() {
		scheduleService.syncZJJZAuditLog();
	}
	//
    //
	///**
	// * <b>定时任务，将文件复制到另外一个目录中 </b>
	// * 目前适用于杭州自动摆渡的情况，杭州摆渡完成后会将源文件删除
	// * @return
	// * @author LuoPeng
	// * @注意事项 </b>
	// * <b>
	// */
	//@Scheduled(cron="0 */12 * * * ?")//每12分钟复制一次
	//public void copyFileData() throws Exception {
	//	scheduleService.copyFileData();
	//}

	/**
	 * <b>定时任务，活动审批状态同步到安保系统 </b>
	 *
	 * @return
	 * @author LuoPeng
	 * @注意事项 </b>
	 * <b>
	 */
	@Scheduled(cron="0 0 */1 * * ?")//每1小时执行一次
	public void syncActivityStatusOut() throws Exception {
		scheduleService.syncActivityStatusOut();
	}

	/**
	 * <b>定时任务，活动信息同步到安保系统 </b>
	 *
	 * @return
	 * @author LuoPeng
	 * @注意事项 </b>
	 * <b>
	 */
	@Scheduled(cron="0 0 21 * * ?")//每天21点执行一次
	public void syncUpdateActivityOut() throws Exception {
		scheduleService.syncUpdateActivityOut();
	}


	/**
	 * <b>定时任务，用户同步 </b>
	 *
	 * @return
	 * @author LuoPeng
	 * @注意事项 </b>
	 * <b>
	 */
	@Scheduled(cron="0 0 1 * * ?")//每天1点执行一次
	public void syncUserChange() throws Exception {
		scheduleService.syncUserChange();
	}

	/**
	 * <b>定时任务，活动信息同步到安保系统 </b>
	 *
	 * @return
	 * @author LuoPeng
	 * @注意事项 </b>
	 * <b>
	 */
	@Scheduled(cron="0 15 1 * * ?")//每天1.15点执行一次
	public void syncSaveActivityOut() throws Exception {
		scheduleService.syncSaveActivityOut();
	}

	/**
	 * <b>定时任务，活动文件同步到安全系统 </b>
	 *
	 * @return
	 * @author LuoPeng
	 * @注意事项 </b>
	 * <b>
	 */
	@Scheduled(cron="0 45 1 * * ?")//每天1.45点执行一次
	public void syncActivityFileOut() throws Exception {
		scheduleService.syncActivityFileOut();
	}
}
