package com.bcxin.sp.work.timer;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.collection.CollectionUtil;
import cn.hutool.core.date.DateUtil;
import cn.hutool.core.text.StrSpliter;
import cn.hutool.core.util.ObjectUtil;
import cn.hutool.core.util.StrUtil;
import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.TypeReference;
import com.baomidou.mybatisplus.mapper.EntityWrapper;
import com.bcxin.sp.work.dao.activity.approve.ApproveHistoryMapper;
import com.bcxin.sp.work.dao.activity.base.ActivityMapper;
import com.bcxin.sp.work.dao.activity.extend.*;
import com.bcxin.sp.work.dao.sys.RegionMapper;
import com.bcxin.sp.work.entity.domain.activity.approve.ApproveHistory;
import com.bcxin.sp.work.entity.domain.activity.base.Activity;
import com.bcxin.sp.work.entity.domain.activity.expand.ActivityContractor;
import com.bcxin.sp.work.entity.domain.activity.expand.ActivityDetail;
import com.bcxin.sp.work.entity.domain.activity.expand.ActivityMaterial;
import com.bcxin.sp.work.entity.domain.activity.expand.SyncTask;
import com.bcxin.sp.work.entity.domain.activity.session.ActivitySession;
import com.bcxin.sp.work.entity.domain.log.ChangeLog;
import com.bcxin.sp.work.entity.domain.log.FileSyncLog;
import com.bcxin.sp.work.entity.domain.upgrade.SystemUpgrade;
import com.bcxin.sp.work.entity.dto.ContractorSPDTO;
import com.bcxin.sp.work.service.activity.approve.ApproveFileService;
import com.bcxin.sp.work.service.activity.approve.ApproveService;
import com.bcxin.sp.work.service.activity.base.ActivityService;
import com.bcxin.sp.work.service.common.NotifyService;
import com.bcxin.sp.work.service.log.ChangeLogService;
import com.bcxin.sp.work.service.log.LogService;
import com.bcxin.sp.work.service.upgrade.SystemUpgradeService;
import com.bcxin.sp.work.util.BcxinDateUtil;
import com.bcxin.sp.work.util.BcxinFileUtil;
import com.bcxin.sp.work.util.Const.DictConst;
import com.bcxin.sp.work.util.Const.GlobalConst;
import com.bcxin.sp.work.util.Const.TipsConst;
import com.bcxin.sp.work.util.StringUtil;
import com.bcxin.sp.work.util.sys.ConfigUtil;
import com.google.common.base.Joiner;
import com.google.common.collect.Lists;
import com.google.common.io.Files;
import lombok.extern.slf4j.Slf4j;
import org.apache.tools.ant.util.FileUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import javax.annotation.Resource;
import java.io.BufferedReader;
import java.io.File;
import java.io.IOException;
import java.math.BigDecimal;
import java.nio.file.*;
import java.nio.file.attribute.BasicFileAttributes;
import java.text.SimpleDateFormat;
import java.util.*;

import static com.google.common.base.CharMatcher.DIGIT;

/**
 * <b>Function </b> 从pss获取活动信息
 *
 * @author LuoPeng
 * @注意事项 </b>
 * <b>
 */
@Service("syncActivityService")
@Transactional
@Slf4j
public class SyncActivityService {

    /**
     * 同步活动详细信息，文件标识
     */
    private final static String ACD = "_acd_";

    /**
     * 同步活动等级评定重新申请原因信息，文件标识
     */
    private final static String ACGR = "_acgr_";

    /**
     * 同步许可审批材料，文件标识
     */
    private final static String AXKSP = "_axksp_";

    /**
     * 同步安全工作方案，文件标识
     */
    private final static String ACAF = "_acaf_";

    /**
     * 同步评估材料，文件标识
     */
    private final static String APGCL = "_apgcl_";

    /**
     * 同步活动评估报告，文件标识
     */
    private final static String ACR = "_acr_";

    /**
     * 同步活动差异日志
     */
    private final static String ACT_CHANGE_LOG = "_ACT_CHANGE_LOG_";

    /**
     * 同步内网升级日志
     */
    private final static String SP_UPGRADE_LOG = "_SP_UPGRADE_LOG_";

    /**
     * 同步承办方信息，文件标识
     */
    private final static String ACC = "_acc_";

    /**
     * 同步活动文件夹名称
     */
    private final static String HD_FOLDER = "hd";

    /**
     * 永久存放文件夹
     */
    private final static String STORE_FOLDER = "store";

    /**
     * 同步审批结果标识，文件标识
     */
    private final static String APPR = "_appr_";

    /**
     * 同步审批文件夹名称
     */
    private final static String SP_FOLDER = "sp";

    /**
     * 将url包装成可下载的路径前缀
     */
    private final static String PACK_DOWNLOAD = "/getResource?path=";

    @Resource
    private ActivityService activityService;

    @Resource
    private NotifyService notifyService;

    @Resource
    private ActivityMapper activityMapper;

    @Resource
    private ActivityMaterialMapper activityMaterialMapper;

    @Resource
    private ApproveHistoryMapper approveHistoryMapper;

    @Resource
    private SyncTaskMapper syncTaskMapper;

    @Resource
    private ActivityContractorMapper activityContractorMapper;
    @Resource
    private ActivitySessionMapper activitySessionMapper;

    @Resource
    private LogService logService;

    @Resource
    private ApproveService approveService;

    @Resource
    private RegionMapper regionMapper;

    @Resource
    private ActivityDetailMapper activityDetailMapper;

    @Resource
    private ApproveFileService approveFileService;

    @Resource
    private SystemUpgradeService upgradeService;

    public List findAllFilesInDirectory(Path pathToDir) throws IOException {

        final List<File> pathsToFiles = new ArrayList<>();
        java.nio.file.Files.walkFileTree(pathToDir, new SimpleFileVisitor() {
            public FileVisitResult visitFile(Path path, BasicFileAttributes attrs) throws IOException {
                log.info("同步的目录文件.findAllFilesInDirectory.path：" + path.toString());
                if (java.nio.file.Files.isRegularFile(path)) {
                    pathsToFiles.add(path.toFile());
                }
                return FileVisitResult.CONTINUE;
            }
        });
        log.info("同步的目录文件.pathsToFiles.size：" + pathsToFiles.size());
        return pathsToFiles;

    }

    /**
     * 同步活动信息
     * 同步报批材料
     *
     * @throws Exception
     */
    public synchronized void importData() throws Exception {
        log.info("开始同步活动信息");
        String month = DateUtil.today().substring(0, 7);
        String envi = ConfigUtil.getValue("envi");
        String mode = ConfigUtil.getValue("pss-communicate-mode");
        String materialPath = ConfigUtil.getValue("stuff-path");
        List<File> allFileList = Lists.newArrayList();

        String[] dateDirs = new String[]{BcxinDateUtil.getCurrentDate(), BcxinDateUtil.getPastDate(1),
                BcxinDateUtil.getPastDate(2), BcxinDateUtil.getPastDate(3),
                BcxinDateUtil.getPastDate(4), BcxinDateUtil.getPastDate(5),
                BcxinDateUtil.getPastDate(6)};

        /* 文件自动读取，只要读两天的文件就可以了 */
        if ("file".equals(mode)) {
            dateDirs = new String[]{BcxinDateUtil.getCurrentDate(), BcxinDateUtil.getPastDate(1)};
        }

        for (String dateDir : dateDirs) {
            //遍历当天的文件夹
            String[] folderPath = new String[]{materialPath, envi, dateDir, HD_FOLDER};
            String dir = BcxinFileUtil.appendFolderPath(folderPath);

            File dirFile = new File(dir);
            log.info("同步的目录：" + dir);
            if (dirFile.exists()) {
                File[] files = dirFile.listFiles();
                if (files != null) {
                    allFileList.addAll(Arrays.asList(files));
                }
            } else {
                dirFile.mkdirs();
            }
            //TODO
            findAllFilesInDirectory(Paths.get(dir));
        }

        if (CollectionUtil.isEmpty(allFileList)) {
            log.info("文件夹是空的");
            return;
        }

        List<String> syncFileNameList = Lists.newArrayList();
        for (File file : allFileList) {
            String fileName = file.getName();
            // 保存差异日志
            if (fileName.startsWith(ACT_CHANGE_LOG)) {
                saveChangeLog(syncFileNameList, file);
                continue;
            }
            // 保存升级日志
            if (fileName.startsWith(SP_UPGRADE_LOG)) {
                saveUpgradeLog(syncFileNameList, file);
                continue;
            }
            FileSyncLog fileSyncLog = logService.findRecord(fileName);
            /*如果文件名存在，证明已经同步过，则不再同步*/
            if (fileSyncLog != null) {
                if (DictConst.Y.equals(fileSyncLog.getMarkRead())) {
                    continue;
                }
            }
            if (syncFileNameList.contains(fileName)) {
                continue;
            }
            if (fileSyncLog == null) {
                fileSyncLog = new FileSyncLog();
            }
            fileSyncLog.setFileName(fileName);
            //同步活动信息
            if (fileName.startsWith(ACD)) {
                String activityId = DIGIT.retainFrom(BcxinFileUtil.filterTimestamp(fileName));
                if (isNotEmpty(activityId)) {
                    try {
                        Activity activity = activityService.findByPssId(Long.parseLong(activityId));
                        //还未开始导入
                        if (activity == null) {
                            log.info("开始解析文件：" + fileName);
                            boolean flag = saveActivity(null, file, allFileList, syncFileNameList);
                            if (flag) {
                                fileSyncLog.setMarkRead(DictConst.Y);
                            }
                        }
                        //已经导入，第二次为修改活动信息
                        else {
                            log.info("开始解析文件：" + fileName);
                            log.info("修改活动信息：" + activity.getFullName());
                            boolean flag = saveActivity(activity, file, allFileList, syncFileNameList);
                            if (flag) {
                                fileSyncLog.setMarkRead(DictConst.Y);
                            }
                        }
                    } catch (Exception e) {
                        e.printStackTrace();
                        continue;
                    }
                }

                logService.mergeMark(fileSyncLog);
                syncFileNameList.add(fileName);
                if (DictConst.Y.equals(fileSyncLog.getMarkRead())) {
                    /* 阅读完后删除文件 */
                    FileUtils.delete(file);
                }
            }
            //同步评估材料
            else if (fileName.startsWith(APGCL)) {
                String activityId = DIGIT.retainFrom(BcxinFileUtil.filterTimestamp(fileName));
                if (isNotEmpty(activityId)) {
                    Activity activity = activityService.findByPssId(Long.parseLong(activityId));
                    if (activity == null) {
                        continue;
                    }
                    /* 是政府项目+备案项目，直接更新材料内容 */
                    if (activity.isGov() && Objects.equals(DictConst.Y, activity.getIsBackUp())) {
                        ActivityMaterial material = activityMaterialMapper.findByActivityId(activity.getId());
                        material.setPgcl(PACK_DOWNLOAD + file.getPath());
                        activityMaterialMapper.updateById(material);

                        // 政府项目：重新提交报备，状态要重置为报备
                        activity.setApproveStatus(DictConst.STATUS_YES);
                        activityMapper.updateById(activity);

                        fileSyncLog.setMarkRead(DictConst.Y);
                        logService.mergeMark(fileSyncLog);
                        syncFileNameList.add(fileName);
                        /* 重新提交报备 */
                        saveBBCLComment(activity, file, allFileList, syncFileNameList);
                        continue;
                    }
                    // 如果活动尚未进行初始化过，则设置报批材料路径
                    if (Objects.equals(activity.getApproveStatus(), DictConst.STATUS_CSZ)) {
                        ActivityMaterial material = activityMaterialMapper.findByActivityId(activity.getId());
                        /* 如果报批材料之前不为空，说明是重新提交的，增加各历史记录 */
                        if (StringUtil.isNotEmpty(material.getPgcl())) {
                            ApproveHistory history = new ApproveHistory();
                            history.setIsReset(DictConst.Y);
                            history.setApproveType(DictConst.APPROVETYPE_CS);
                            history.setAddTime(new Date());
                            history.setActivityId(activity.getId());
                            history.setContent(TipsConst.TJPGCL);
                            history.setUserName(activity.getSponsor());
                            approveHistoryMapper.insert(history);
                            /* 增加通知 */
                            notifyService.cxtjcl(activity);
                        }
                        material.setPgcl(PACK_DOWNLOAD + file.getPath());
                        activityMaterialMapper.updateById(material);

                        fileSyncLog.setMarkRead(DictConst.Y);
                        logService.mergeMark(fileSyncLog);
                    } else {
                        /* 只更新评估材料 */
                        ActivityMaterial material = activityMaterialMapper.findByActivityId(activity.getId());
                        /* 如果评估材料之前不为空，说明是重新提交的，增加各历史记录 */
                        if (StringUtil.isNotEmpty(material.getPgcl())) {
                            ApproveHistory history = new ApproveHistory();
                            history.setIsReset(DictConst.Y);
                            history.setApproveType(DictConst.APPROVETYPE_CS);
                            history.setAddTime(new Date());
                            history.setActivityId(activity.getId());
                            history.setContent(TipsConst.TJPGCL);
                            history.setUserName(activity.getSponsor());
                            approveHistoryMapper.insert(history);
                            /* 增加通知 */
                            notifyService.cxtjpgcl(activity);
                        }
                        material.setPgcl(PACK_DOWNLOAD + file.getPath());
                        activityMaterialMapper.updateById(material);

                        fileSyncLog.setMarkRead(DictConst.Y);
                        logService.mergeMark(fileSyncLog);
                    }
                    syncFileNameList.add(fileName);
                    /* 阅读完后删除文件 */
                    //FileUtils.delete(file);
                    if ("on".equalsIgnoreCase(ConfigUtil.getValue("switch_zjzw20"))) {
                        if ("330000".equals(activity.getProvince())) {
                            activityMapper.updateActivityByIsAddFiles(null,Long.valueOf(activityId), DictConst.Y);
                        }
                    }
                }
            } else if (fileName.startsWith(ACR) && !fileName.contains("_comment")) { //同步评估报告
                String activityId = DIGIT.retainFrom(BcxinFileUtil.filterTimestamp(fileName));
                if (isNotEmpty(activityId)) {
                    Activity activity = activityService.findByPssId(Long.parseLong(activityId));
                    if (activity == null) {
                        continue;
                    }
                    /* 如果是初审通过，则同步报告，变成受理中 */
                    /* 如果是开启开启等级评定，则需要安全工作方案才可以变成受理中，更新评估报告不做处理*/
                    if (DictConst.STATUS_CSTG.equals(activity.getApproveStatus())
                            && !GlobalConst.SWITCH_ON.equals(ConfigUtil.getValue("switch_gradeRank"))) {

                        activity.setApproveStatus(DictConst.STATUS_SLZ);

                        ApproveHistory history = new ApproveHistory();
                        history.setIsReset(DictConst.Y);
                        history.setApproveType(DictConst.APPROVETYPE_SL);
                        history.setAddTime(new Date());
                        history.setActivityId(activity.getId());
                        history.setContent(TipsConst.TJSP);
                        history.setUserName(activity.getSponsor());
                        approveHistoryMapper.insert(history);

                        /* 消息通知 */
                        notifyService.submitApprovalNotify(activity);
                    }

                    // 审批阶段，无需校验人数
                    activityService.createOrUpdate(activity, true);

                    boolean logHistory = false;
                    for (File f : allFileList) {
                        /* 找到评估报告对应的备注 */
                        if (f.getName().equals(Files.getNameWithoutExtension(fileName) + "_comment.txt")) {
                            /* 标记文档同步 */
                            FileSyncLog fileSyncLog2 = logService.findRecord(f.getName());
                            if (fileSyncLog2 == null) {
                                fileSyncLog2 = new FileSyncLog();
                            }
                            fileSyncLog2.setFileName(f.getName());
                            fileSyncLog2.setMarkRead(DictConst.Y);
                            String comment = "";
                            try {
                                /* 读取备注 */
                                Path fpath = Paths.get(f.getPath());
                                BufferedReader bfr = java.nio.file.Files.newBufferedReader(fpath);
                                comment = bfr.readLine();
                                bfr.close();
                            } catch (Exception e) {
                                e.printStackTrace();
                            }
                            ApproveHistory history2 = new ApproveHistory();
                            history2.setIsReset(DictConst.Y);
                            history2.setApproveType(DictConst.APPROVETYPE_SP);
                            history2.setAddTime(new Date());
                            history2.setActivityId(activity.getId());
                            history2.setContent(TipsConst.CXTJPGBG);
                            history2.setUserName(activity.getSponsor());
                            history2.setOpinion(comment);
                            try {
                                approveHistoryMapper.insert(history2);
                                /* 消息通知 */
                                notifyService.resubmitAssessmentNotify(activity);
                                logHistory = true;
                            } catch (Exception e) {
                                fileSyncLog2.setMarkRead(DictConst.N);
                                e.printStackTrace();
                            }
                            logService.mergeMark(fileSyncLog2);
                            syncFileNameList.add(f.getName());
                        }
                    }
                    /* 更新评估报告 */
                    ActivityMaterial material = activityMaterialMapper.findByActivityId(activity.getId());
                    if (fileName.contains("third")) {
                        material.setPgbgProvider("2");
                    } else {
                        material.setPgbgProvider("1");
                    }
                    String[] folderPath = new String[]{materialPath, STORE_FOLDER, month};
                    String dir = BcxinFileUtil.appendFolderPath(folderPath);
                    File newFile = new File(dir + File.separator + file.getName());
                    Files.copy(file, newFile);
                    material.setPgbg(PACK_DOWNLOAD + newFile.getPath());
                    activityMaterialMapper.updateById(material);
                    if (!logHistory) {
                        /* 消息通知 */
                        notifyService.submitAssessmentNotify(activity);
                        /* 记录历史记录 */
                        ApproveHistory history = new ApproveHistory();
                        history.setIsReset(DictConst.Y);
                        history.setApproveType(DictConst.APPROVETYPE_SP);
                        history.setAddTime(new Date());
                        history.setActivityId(activity.getId());
                        history.setContent(TipsConst.TJPGBG);
                        history.setUserName(activity.getSponsor());
                        approveHistoryMapper.insert(history);
                    }
                    fileSyncLog.setMarkRead(DictConst.Y);
                    logService.mergeMark(fileSyncLog);
                    syncFileNameList.add(fileName);
                    /* 阅读完后删除文件 */
                    FileUtils.delete(file);
                }
            } else if (fileName.startsWith(AXKSP)) { //同步许可审批材料
                String activityId = DIGIT.retainFrom(BcxinFileUtil.filterTimestamp(fileName));
                if (isNotEmpty(activityId)) {
                    Activity activity = activityService.findByPssId(Long.parseLong(activityId));
                    if (activity == null) {
                        continue;
                    }
                    /* 如果是等级评定通过，则同步安全工作方案，变成受理中 */
                    /* 如果是开启开启等级评定，则需要安全工作方案才可以变成受理中，更新评估报告不做处理*/
                    if (DictConst.STATUS_CSTG.equals(activity.getApproveStatus())
                            && GlobalConst.SWITCH_ON.equals(ConfigUtil.getValue("switch_gradeRank"))) {
                        activity.setApproveStatus(DictConst.STATUS_SLZ);

                        ApproveHistory history = new ApproveHistory();
                        history.setIsReset(DictConst.Y);
                        history.setApproveType(DictConst.APPROVETYPE_SL);
                        history.setAddTime(new Date());
                        history.setActivityId(activity.getId());
                        history.setContent(TipsConst.TJSL);
                        history.setUserName(activity.getSponsor());
                        approveHistoryMapper.insert(history);
                        /* 消息通知 */
                        notifyService.submitApprovalNotify(activity);
                    }

                    // 审批阶段，无需校验人数
                    activityService.createOrUpdate(activity, true);

                    /* 更新报批材料，许可审批材料 */
                    String[] folderPath = new String[]{materialPath, STORE_FOLDER, month};
                    String dir = BcxinFileUtil.appendFolderPath(folderPath);
                    File newFile = new File(dir + File.separator + file.getName());
                    Files.copy(file, newFile);
                    ActivityMaterial material = activityMaterialMapper.findByActivityId(activity.getId());
                    material.setBpcl(PACK_DOWNLOAD + newFile.getPath());
                    activityMaterialMapper.updateById(material);

                    /* 记录历史记录 */
                    ApproveHistory history = new ApproveHistory();
                    history.setIsReset(DictConst.Y);
                    history.setApproveType(DictConst.APPROVETYPE_SL);
                    history.setAddTime(new Date());
                    history.setActivityId(activity.getId());
                    history.setContent(TipsConst.TJAQGZFA);
                    history.setUserName(activity.getSponsor());
                    approveHistoryMapper.insert(history);

                    fileSyncLog.setMarkRead(DictConst.Y);
                    logService.mergeMark(fileSyncLog);
                    syncFileNameList.add(fileName);
                    /* 阅读完后删除文件 */
                    //FileUtils.delete(file);
                    if ("on".equalsIgnoreCase(ConfigUtil.getValue("switch_zjzw20"))) {
                        if ("330000".equals(activity.getProvince())) {
                            activityMapper.updateActivityByIsAddFiles(null,Long.valueOf(activityId), DictConst.Y);
                        }
                    }
                }
            } else if (fileName.startsWith(ACAF)) { //同步安全工作方案
                String activityId = DIGIT.retainFrom(BcxinFileUtil.filterTimestamp(fileName));
                if (isNotEmpty(activityId)) {
                    Activity activity = activityService.findByPssId(Long.parseLong(activityId));
                    if (activity == null) {
                        continue;
                    }
                    /* 如果是等级评定通过，则同步安全工作方案，变成受理中 */
                    /* 如果是开启开启等级评定，则需要安全工作方案才可以变成受理中，更新评估报告不做处理*/
                    if (DictConst.STATUS_CSTG.equals(activity.getApproveStatus())
                            && GlobalConst.SWITCH_ON.equals(ConfigUtil.getValue("switch_gradeRank"))) {
                        activity.setApproveStatus(DictConst.STATUS_SLZ);

                        ApproveHistory history = new ApproveHistory();
                        history.setIsReset(DictConst.Y);
                        history.setApproveType(DictConst.APPROVETYPE_SL);
                        history.setAddTime(new Date());
                        history.setActivityId(activity.getId());
                        history.setContent(TipsConst.TJSL);
                        history.setUserName(activity.getSponsor());
                        approveHistoryMapper.insert(history);
                        /* 消息通知 */
                        notifyService.submitApprovalNotify(activity);
                    }

                    // 审批阶段，无需校验人数
                    activityService.createOrUpdate(activity, true);

                    /* 更新报批材料，许可审批材料 */
                    String[] folderPath = new String[]{materialPath, STORE_FOLDER, month};
                    String dir = BcxinFileUtil.appendFolderPath(folderPath);
                    File newFile = new File(dir + File.separator + file.getName());
                    Files.copy(file, newFile);
                    ActivityMaterial material = activityMaterialMapper.findByActivityId(activity.getId());
                    material.setAqgzfa(PACK_DOWNLOAD + newFile.getPath());
                    activityMaterialMapper.updateById(material);

                    /* 记录历史记录 */
                    ApproveHistory history = new ApproveHistory();
                    history.setIsReset(DictConst.Y);
                    history.setApproveType(DictConst.APPROVETYPE_SL);
                    history.setAddTime(new Date());
                    history.setActivityId(activity.getId());
                    history.setContent(TipsConst.TJAQGZFA);
                    history.setUserName(activity.getSponsor());
                    approveHistoryMapper.insert(history);

                    fileSyncLog.setMarkRead(DictConst.Y);
                    logService.mergeMark(fileSyncLog);
                    syncFileNameList.add(fileName);
                    /* 阅读完后删除文件 */
                    FileUtils.delete(file);
                }
          } else if (fileName.startsWith(ACC)) { //同步承办方信息
                String activityId = DIGIT.retainFrom(BcxinFileUtil.filterTimestamp(fileName));
                if (isNotEmpty(activityId)) {
                    Activity activity = activityService.findByPssId(Long.parseLong(activityId));
                    if (activity == null) {
                        continue;
                    }
                    /* 读取承办方信息 */
                    String comment = "";
                    try {
                        Path fpath = Paths.get(file.getPath());
                        BufferedReader bfr = java.nio.file.Files.newBufferedReader(fpath);
                        comment = bfr.readLine();
                        bfr.close();
                    } catch (Exception e) {
                        e.printStackTrace();
                    }
                    Map<String, ContractorSPDTO> map = JSON.parseObject(comment, new TypeReference<HashMap<String, ContractorSPDTO>>() {
                    });
                    if (map == null) {
                        continue;
                    }
                    /* 提前先清空原来的承办单位 */
                    activityContractorMapper.deleteByActivityId(activity.getId());
                    StringBuilder stringBuilder = new StringBuilder();
                    for (String key : map.keySet()) {
                        ActivityContractor activityContractor = new ActivityContractor();
                        BeanUtil.copyProperties(map.get(key), activityContractor);
                        if (StringUtil.isEmpty(activityContractor.getFullName())) {
                            activityContractor.setFullName(map.get(key).getName());
                        }
                        activityContractor.setActivityId(activity.getId());

                        /* 值为 610000,610100,610101 */
                        if (StringUtil.isNotEmpty(activityContractor.getAddress())) {
                            List<String> regionList = StrSpliter.split(activityContractor.getAddress(), ",", true, true);
                            List<String> address = Lists.newArrayList();
                            for (String regionId : regionList) {
                                if (StringUtil.isEmpty(regionId)) {
                                    continue;
                                }
                                if ("null".equals(regionId)) {
                                    continue;
                                }
                                String region = regionMapper.findNameById(Long.parseLong(regionId));
                                address.add(region);
                            }
                            String addressCN = Joiner.on("#").skipNulls().join(address);
                            activityContractor.setAddress(addressCN);
                        }
                        activityContractorMapper.insert(activityContractor);
                        stringBuilder.append(activityContractor.getFullName()).append(",");
                    }
                    activity.setSponsor(StringUtil.isEmpty(stringBuilder.toString()) ? stringBuilder.toString() : stringBuilder.toString().substring(0, stringBuilder.toString().length() - 1));
                    fileSyncLog.setMarkRead(DictConst.Y);
                    logService.mergeMark(fileSyncLog);
                    syncFileNameList.add(fileName);
                    /* 阅读完后删除文件 */
                    FileUtils.delete(file);
                }
            } else if (fileName.startsWith(ACGR)) { //同步承办方重新申请重评
                String activityId = DIGIT.retainFrom(BcxinFileUtil.filterTimestamp(fileName));
                if (isNotEmpty(activityId)) {
                    Activity activity = activityService.findByPssId(Long.parseLong(activityId));
                    if (activity == null) {
                        continue;
                    }
                    /* 只有在已评定状态下才能变更为申请重评 */
                    if (DictConst.STATUS_CSTG.equals(activity.getApproveStatus())) {
                        /* 读取重新申请重评原因 */
                        String comment = "";
                        try {
                            Path fpath = Paths.get(file.getPath());
                            BufferedReader bfr = java.nio.file.Files.newBufferedReader(fpath);
                            comment = bfr.readLine();
                            bfr.close();
                        } catch (Exception e) {
                            e.printStackTrace();
                        }

                        /* 修改申请内容，修改状态为承办方重评 */
                        activityMapper.updateActivityReContent(activity.getId(), DictConst.STATUS_SQCP, comment);

                        /* 记录历史记录 */
                        ApproveHistory history = new ApproveHistory();
                        history.setIsReset(DictConst.Y);
                        history.setApproveType(DictConst.APPROVETYPE_CS);
                        history.setAddTime(new Date());
                        history.setActivityId(activity.getId());
                        history.setContent(TipsConst.TJDJPDRE);
                        history.setUserName(activity.getSponsor());
                        history.setOpinion(comment);
                        approveHistoryMapper.insert(history);
                    }

                    fileSyncLog.setMarkRead(DictConst.Y);
                    logService.mergeMark(fileSyncLog);
                    syncFileNameList.add(fileName);
                    /* 阅读完后删除文件 */
                    FileUtils.delete(file);
                }
            }
        }
    }

    private boolean saveActivity(Activity activity, File file, List<File> files, List<String> syncFileNameList) throws Exception {
        String content = BcxinFileUtil.txt2String(file);
        Map<String, String> valueMap = JSON.parseObject(content,Map.class);

        ActivityDetail activityDetail;
        String oldWorkFlowVersion = "";
        String newWorkFlowVersion = "";
        String sourceArea = "";
        // 是否二次提交
        boolean isResubmit = false;
        if (activity == null) {
            activity = new Activity();
            activityDetail = new ActivityDetail();
        } else {
            isResubmit = true;
            activityDetail = activityDetailMapper.findByActivityId(activity.getId());
            oldWorkFlowVersion = activity.getWorkflowVersion();
            sourceArea = getApproveArea(activity.getProvince(), activity.getCity(), activity.getArea());
        }

        if (valueMap.size() == 0) {
            return false;
        }

        if (StringUtil.isEmpty(valueMap.get("activityNo"))) {
            log.info("未能检测到数据");
            return false;
        }

        log.info(valueMap.get("activityNo"));


        // 验证是否政府报备项目转许可项目
        boolean isTransferXK = false;
        // 当前内网是报备活动状态，且审批退回
        if (ObjectUtil.equal(activity.getIsBackUp(), DictConst.Y)) {
            // 传入的isBackUp和内网的不一致,表示政府报备项目转许可项目
            if (!ObjectUtil.equal(valueMap.get("isBackUp"), DictConst.Y)) {
                isTransferXK = true;
            }
        }

        // 报备,报备转许可项目，删除之前的审批记录，否则会影响之后的审批流程
        if (isTransferXK) {
            if (activity.getId() != null) {
                approveService.removeApprove(activity.getId());
            }
        }
        SimpleDateFormat sdf = new SimpleDateFormat("yyyy-MM-dd HH:mm");
        // 是否报备项目
        activity.setIsBackUp(valueMap.get("isBackUp"));
        // 是否需要风评报告
        activity.setIsNeedReport(valueMap.get("isNeedReport"));
        activity.setSponsorAddress(valueMap.get("sponsorAddress"));
        activity.setCoordinate(valueMap.get("coordinate"));
        activity.setIntroduce(valueMap.get("introduce"));
        activity.setPssId(Long.parseLong(valueMap.get("pssId")));
        activity.setActivityNo(valueMap.get("activityNo"));
        activity.setFullName(valueMap.get("name"));
        activity.setTypeCode(valueMap.get("typeCode"));
        activity.setProvince(StringUtil.isEmpty(valueMap.get("province")) ? null : valueMap.get("province"));
        activity.setCity(StringUtil.isEmpty(valueMap.get("city")) ? null : valueMap.get("city"));
        //要给到经开区的特殊处理
        String area = StringUtil.isEmpty(valueMap.get("area")) ? null : valueMap.get("area");
        String unit = StringUtil.isEmpty(valueMap.get("unit")) ? null : valueMap.get("unit");
        if("13040302".equals(area)){
            area = "13049101";
            unit = "13049101";
        }
        activity.setArea(area);
        activity.setUnit(unit);
        activity.setAddress(valueMap.get("address"));
        activity.setNumber(isNotEmpty(valueMap.get("number")) ? new BigDecimal(valueMap.get("number")).intValue() : 0);
        activity.setStartDate(isNotEmpty(valueMap.get("startDate")) ? sdf.parse(valueMap.get("startDate")) : new Date());
        activity.setEndDate(isNotEmpty(valueMap.get("endDate")) ? sdf.parse(valueMap.get("endDate")) : new Date());
        activity.setAmount(isNotEmpty(valueMap.get("amount")) ? new BigDecimal(valueMap.get("amount")).intValue() : 0);
        activity.setOrganizer(isNotEmpty(valueMap.get("organizer")) ? valueMap.get("organizer") : "无");
        activity.setSponsor(isNotEmpty(valueMap.get("sponsor")) ? valueMap.get("sponsor") : "无");
        activity.setZsponsor(isNotEmpty(valueMap.get("zsponsor")) ? valueMap.get("zsponsor") : "无");
        activity.setAssessmentorg(isNotEmpty(valueMap.get("assessmentorg")) ? valueMap.get("assessmentorg") : "无");
        activity.setGov(Objects.equals(valueMap.get("gov"), DictConst.Y));
        activity.setHistory(valueMap.get("history"));
        activity.setIsAddFiles("1");//默认是已经补充完材料

        /* 活动信息详情 */
        activityDetail.setBags(valueMap.get("bags"));
        activityDetail.setHdnr(valueMap.get("hdnr"));
        activityDetail.setBaryzs(valueMap.get("baryzs"));
        activityDetail.setCdrl(valueMap.get("cdrl"));
        activityDetail.setNzjs(valueMap.get("nzjs"));
        activityDetail.setCdmj(valueMap.get("cdmj"));
        activityDetail.setXccys(valueMap.get("xccys"));
        activityDetail.setZyzzs(valueMap.get("zyzzs"));

        /* 需要初审 */
        if (Objects.equals(valueMap.get("primary"), DictConst.Y) && StrUtil.isEmpty(activity.getApproveStatus())) {
            activity.setApproveStatus(DictConst.STATUS_CSZ);
            activity.setSync(DictConst.N);
        }

        /* 报备项目转许可，也需要初审 */
        if (isTransferXK && Objects.equals(valueMap.get("primary"), DictConst.Y)) {
            activity.setApproveStatus(DictConst.STATUS_CSZ);
            activity.setSync(DictConst.N);
        }

        for (File f : files) {
            if (f.getName().startsWith(APGCL) && f.getName().contains(valueMap.get("pssId"))) {
                /* 还未保存活动信息，不做同步*/
                if (activity.getId() == null) {
                    continue;
                }
                /* 初审中或未审批，说明可以进行同步报备材料*/
                if (StringUtil.isEmpty(activity.getApproveStatus()) || DictConst.STATUS_CSZ.equals(activity.getApproveStatus())) {
                    FileSyncLog fileSyncLog = logService.findRecord(f.getName());
                    /*如果文件名存在，证明已经同步过，则不再同步*/
                    if (fileSyncLog != null) {
                        if (DictConst.Y.equals(fileSyncLog.getMarkRead())) {
                            continue;
                        }
                    } else {
                        fileSyncLog = new FileSyncLog();
                        fileSyncLog.setFileName(f.getName());
                    }
                    fileSyncLog.setMarkRead(DictConst.Y);
                    logService.mergeMark(fileSyncLog);

                    /* 更新评估材料 */
                    ActivityMaterial material = activityMaterialMapper.findByActivityId(activity.getId());
                    material.setPgcl(PACK_DOWNLOAD + f.getPath());
                    activityMaterialMapper.updateById(material);

                    syncFileNameList.add(f.getName());
                }
            }
        }

        /*
         * 是政府项目且是备案项目
         */
        if (activity.isGov() && Objects.equals(activity.getIsBackUp(), DictConst.Y)) {
            activity.setApproveStatus(DictConst.STATUS_YES);

            // 二次提交的政府备案项目，不需要再新增审批历史
            if (!isResubmit) {
                ApproveHistory history = new ApproveHistory();
                history.setIsReset(DictConst.Y);
                history.setApproveType(DictConst.APPROVETYPE_SP);
                history.setAddTime(new Date());
                history.setActivityId(activity.getId());
                history.setContent(TipsConst.TJBB);
                history.setUserName(activity.getSponsor());
                approveHistoryMapper.insert(history);

                /* 消息通知 */
                notifyService.submitReport(activity);
            }
        }else{
            /* 河北强制变成受理中，需要走受理流程 */
            if ("130000".equals(activity.getProvince())) {
                activity.setApproveStatus(DictConst.STATUS_SLZ);
            }
        }


        activityService.createOrUpdate(activity);
        //外网场次信息插入内网数据库关联对应活动
        if(StringUtil.isNotEmpty(valueMap.get("activitySessions")) && !activity.getApproveStatus().equals(DictConst.STATUS_YES)){
            List<Map> maps = JSONArray.parseArray(valueMap.get("activitySessions"),Map.class);
            ActivitySession activitySession;
            if(maps.size()>0){
                //先删除
                activitySessionMapper.deleteByActivityId(activity.getId());
            }
            for (Map map:maps){
                activitySession = new ActivitySession();
                activitySession.setAddTime(new Date());
                activitySession.setActivityId(activity.getId());
                activitySession.setUpdateTime(new Date());
                activitySession.setStartDate(map.get("startDate")+"");
                activitySession.setEndDate(map.get("endDate")+"");
                activitySession.setContactName(map.get("contactName")+"");
                activitySession.setContactPosition(map.get("contactPosition")+"");
                activitySession.setContactPhone(map.get("contactPhone")+"");
                activitySessionMapper.insert(activitySession);
            }
        }

        // 重新提交项目 && 许可项目
        if (isResubmit && Objects.equals(activity.getIsBackUp(), DictConst.N)) {
            // 审批流程发生改变
            newWorkFlowVersion = activity.getWorkflowVersion();
            if (!Objects.equals(oldWorkFlowVersion, newWorkFlowVersion)) {
                // 发送消息给已经审批过的人员
                List<Map> alreadyUserList = activityMapper.findAlreadyApproveUser(activity.getId());
                String transferAddr = getApproveArea(activity.getProvince(), activity.getCity(), activity.getArea());
                notifyService.contractorTransferActNotify(activity, alreadyUserList, transferAddr);

                /* 发送消息给新的审批人员 */
                notifyService.tjcsAndChangeArea(activity, sourceArea, transferAddr);
            }
        }

        /* 更新受理凭证 */
        if (DictConst.fullSPList().contains(activity.getApproveStatus())) {
            /* 生成文书 */
            approveFileService.generateslws(DictConst.STATUS_SL, activity, null);
        }


        if (activityDetail.getId() == null) {
            activityDetail.setActivityId(activity.getId());
            activityDetailMapper.insert(activityDetail);
        } else {
            activityDetailMapper.updateById(activityDetail);
        }
        return true;
    }


    /**
     * 重新提交报备材料
     *
     * @param activity
     * @param file
     * @param files
     * @param syncFileNameList
     * @return
     * @throws Exception
     */
    private boolean saveBBCLComment(Activity activity, File file, List<File> files, List<String> syncFileNameList) {
        if (activity.isGov()) {
            /* 找到报备材料对应的备注 */
            String comment = "";
            for (File f : files) {
                if (f.getName().equals(Files.getNameWithoutExtension(file.getName()) + "_comment.txt")) {
                    /* 标记文档同步 */
                    FileSyncLog fileSyncLog = logService.findRecord(f.getName());
                    if (fileSyncLog == null) {
                        fileSyncLog = new FileSyncLog();
                    }
                    fileSyncLog.setFileName(f.getName());
                    fileSyncLog.setMarkRead(DictConst.Y);
                    try {
                        /* 读取重新提交的原因 */
                        Path fpath = Paths.get(f.getPath());
                        BufferedReader bfr = java.nio.file.Files.newBufferedReader(fpath);
                        comment = bfr.readLine();
                        bfr.close();
                    } catch (Exception e) {
                        e.printStackTrace();
                    }

                    ApproveHistory history = new ApproveHistory();
                    history.setIsReset(DictConst.Y);
                    history.setApproveType(DictConst.APPROVETYPE_SP);
                    history.setAddTime(new Date());
                    history.setActivityId(activity.getId());
                    history.setContent(TipsConst.CXTJBB);
                    history.setUserName(activity.getSponsor());
                    history.setOpinion(comment);
                    try {
                        approveHistoryMapper.insert(history);
                    } catch (Exception e) {
                        fileSyncLog.setMarkRead(DictConst.N);
                        e.printStackTrace();
                    }
                    logService.mergeMark(fileSyncLog);
                    syncFileNameList.add(f.getName());
                }
            }
            // 重新提交报备消息通知
            if (StringUtil.isNotEmpty(comment)) {
                notifyService.resubmitTJBB(activity, comment);
            }
        }
        return true;
    }


    private boolean isNotEmpty(String value) {
        if (value == null) {
            return false;
        }
        if ("".equals(value.trim())) {
            return false;
        }
        return true;
    }


    /*-----------------------------同步审批结果----------------------------------*/

    /**
     * 同步审批结果信息
     *
     * @throws Exception
     */
    public void importApprovalData() throws Exception {
        log.info("开始同步审批结果信息");
        String envi = ConfigUtil.getValue("envi");
        String mode = ConfigUtil.getValue("pss-communicate-mode");
        String upload_path = ConfigUtil.getValue("stuff-path");

        List<File> allFileList = Lists.newArrayList();

        String[] dateDirs = new String[]{BcxinDateUtil.getCurrentDate(), BcxinDateUtil.getPastDate(1),
                BcxinDateUtil.getPastDate(2), BcxinDateUtil.getPastDate(3),
                BcxinDateUtil.getPastDate(4),
                BcxinDateUtil.getPastDate(5), BcxinDateUtil.getPastDate(6)};

        /* 文件自动读取，只要读两天的文件就可以了 */
        if ("file".equals(mode)) {
            dateDirs = new String[]{BcxinDateUtil.getCurrentDate(), BcxinDateUtil.getPastDate(1)};
        }

        for (String dateDir : dateDirs) {
            //遍历当天的文件夹
            String[] folerPath = new String[]{upload_path, envi, dateDir, SP_FOLDER};
            String dir = BcxinFileUtil.appendFolderPath(folerPath);

            File dirFile = new File(dir);
            log.info("同步的目录：" + dir);
            if (dirFile.exists()) {
                File[] files = dirFile.listFiles();
                allFileList.addAll(Arrays.asList(files));
            } else {
                dirFile.mkdirs();
            }
        }

        if (CollectionUtil.isEmpty(allFileList)) {
            log.info("文件夹是空的");
            return;
        }

        List<String> fileNameList = Lists.newArrayList();
        for (File file : allFileList) {
            String fileName = file.getName();
            //同步活动信息
            if (fileName.startsWith(APPR)) {
                FileSyncLog fileSyncLog = logService.findRecord(fileName);
                /*如果文件名存在，证明已经同步过，则不再同步*/
                if (fileSyncLog != null) {
                    if (DictConst.Y.equals(fileSyncLog.getMarkRead())) {
                        continue;
                    }
                }
                if (fileNameList.contains(fileName)) {
                    continue;
                }
                log.info("开始解析文件：" + fileName);

                if (fileSyncLog == null) {
                    fileSyncLog = new FileSyncLog();
                }
                fileSyncLog.setFileName(fileName);
                try {
                    boolean flag = saveApproval(file);
                    if (flag) {
                        fileSyncLog.setMarkRead(DictConst.Y);
                    }
                } catch (Exception e) {
                    e.printStackTrace();
                }

                logService.mergeMark(fileSyncLog);
                fileNameList.add(fileName);
            }
        }

    }


    private boolean saveApproval(File file) throws Exception {
        String content = BcxinFileUtil.txt2String(file);
        List<Map> contentList = JSON.parseArray(content,Map.class);
        List<String> activityNoList = Lists.newArrayList();
        List<String> primaryStatusList = Lists.newArrayList();
        List<String> approvalStatusList = Lists.newArrayList();

        for (Map map : contentList) {
            activityNoList.add(map.get("activityNo").toString());
            primaryStatusList.add(map.get("primaryStatus").toString());
            approvalStatusList.add(map.get("approvalStatus").toString());
        }

        if (CollectionUtil.isNotEmpty(activityNoList)) {
            for (int i = 0; i < activityNoList.size(); i++) {
                Activity activity = activityService.findByActivityNo(activityNoList.get(i));
                if (activity == null) {
                    continue;
                }
                if (approvalStatusList.size() == 0 || approvalStatusList.size() <= i) {
                    activity.setSync(DictConst.Y);
                    activityMapper.updateById(activity);
                    continue;
                }

                /* 提前处理 直接跳过初审通过同步 的任务 */
                if (GlobalConst.SWITCH_ON.equals(ConfigUtil.getValue("switch_redirectsl"))
                        && Objects.equals(primaryStatusList.get(i), DictConst.STATUS_CSTG)) {
                    List<SyncTask> syncTaskList = syncTaskMapper.selectList(new EntityWrapper<SyncTask>()
                            .eq("sync", DictConst.N)
                            .eq("activityId", activity.getId())
                            .eq("approveStatus", DictConst.STATUS_CSTG)
                            .eq("syncTaskType", DictConst.SYNCTASKTYPE_CS));
                    if (CollectionUtil.isNotEmpty(syncTaskList)) {
                        syncTaskList.forEach(s -> {
                            s.setSync(DictConst.Y);
                            syncTaskMapper.updateById(s);
                        });
                    }
                }
                /* 提前处理 直接跳过受理通过同步 的任务 */
                if (GlobalConst.SWITCH_ON.equals(ConfigUtil.getValue("switch_redirectsp"))
                        && Objects.equals(primaryStatusList.get(i), DictConst.STATUS_SL)) {
                    List<SyncTask> syncTaskList = syncTaskMapper.selectList(new EntityWrapper<SyncTask>()
                            .eq("sync", DictConst.N)
                            .eq("activityId", activity.getId())
                            .eq("approveStatus", DictConst.STATUS_SL)
                            .eq("syncTaskType", DictConst.SYNCTASKTYPE_SL));
                    if (CollectionUtil.isNotEmpty(syncTaskList)) {
                        syncTaskList.forEach(s -> {
                            s.setSync(DictConst.Y);
                            syncTaskMapper.updateById(s);
                        });
                    }
                }

                /* 设置打回的状态 */
                List<SyncTask> syncTaskList1 = syncTaskMapper.selectList(new EntityWrapper<SyncTask>()
                        .eq("sync", DictConst.N)
                        .eq("activityId", activity.getId())
                        .eq("approveStatus", DictConst.STATUS_REJECT)
                        .eq("syncTaskType", DictConst.SYNCTASKTYPE_SP));
                if (CollectionUtil.isNotEmpty(syncTaskList1)) {
                    syncTaskList1.forEach(s -> {
                        s.setSync(DictConst.Y);
                        syncTaskMapper.updateById(s);
                    });
                }

                /* 设置转交的状态 */
                List<SyncTask> syncTaskList2 = syncTaskMapper.selectList(new EntityWrapper<SyncTask>()
                        .eq("sync", DictConst.N)
                        .eq("activityId", activity.getId())
                        .eq("approveStatus", DictConst.STATUS_TRANSFER)
                        .eq("syncTaskType", DictConst.SYNCTASKTYPE_TRANSFER));
                if (CollectionUtil.isNotEmpty(syncTaskList2)) {
                    syncTaskList2.forEach(s -> {
                        s.setSync(DictConst.Y);
                        syncTaskMapper.updateById(s);
                    });
                }

                /*如果是审批打回*/
                if (Objects.equals(approvalStatusList.get(i), "4")) {
                    /*判断当前活动是否是审批打回，如果是则修改状态，如果不是，则不修改同步状态，防止同步过快*/
                    if (Objects.equals(activity.getApproveStatus(), DictConst.STATUS_REJECT)) {
                        activity.setSync(DictConst.Y);
                        activityMapper.updateById(activity);
                        continue;
                    }
                }
                /*判断当前活动是初审通过 并且同步活动的状态是初审通过，则修改同步状态*/
                if (Objects.equals(primaryStatusList.get(i), "30")) {
                    if (Objects.equals(activity.getApproveStatus(), DictConst.STATUS_CSTG)) {
                        activity.setSync(DictConst.Y);
                        activityMapper.updateById(activity);
                    }
                    continue;
                }

                /*判断当前活动是受理通过 并且同步活动的状态是受理通过，则修改同步状态*/
                if (Objects.equals(primaryStatusList.get(i), DictConst.STATUS_SL)
                        && Objects.equals(approvalStatusList.get(i), "1")) {
                    if (Objects.equals(activity.getApproveStatus(), DictConst.STATUS_SL)) {
                        /* 进入审批环节 */
                        activity.setApproveStatus(DictConst.STATUS_NONE);
                        activity.setSync(DictConst.N);
                        activityMapper.updateById(activity);
                    }
                    continue;
                }

                /* 这些状态下，说明正在进行中，不需要修改同步状态 */
                if (Objects.equals(primaryStatusList.get(i), DictConst.STATUS_CSZ)
                        || Objects.equals(primaryStatusList.get(i), DictConst.STATUS_SLZ)
                        || Objects.equals(approvalStatusList.get(i), DictConst.STATUS_IN)
                        || Objects.equals(approvalStatusList.get(i), DictConst.STATUS_NONE)) {
                    continue;
                }

                activity.setSync(DictConst.Y);
                activityMapper.updateById(activity);
            }
        }
        return true;
    }


    @Autowired
    private ChangeLogService changeLogService;

    /**
     * 保存差异日志
     *
     * @param file
     */
    public void saveChangeLog(List<String> syncFileNameList, File file) {
        String fileName = file.getName();
        FileSyncLog fileSyncLog = logService.findRecord(fileName);
        /*如果文件名存在，证明已经同步过，则不再同步*/
        if (fileSyncLog != null) {
            if (DictConst.Y.equals(fileSyncLog.getMarkRead())) {
                return;
            }
        }
        if (syncFileNameList.contains(fileName)) {
            return;
        }

        if (fileSyncLog == null) {
            fileSyncLog = new FileSyncLog();
        }
        fileSyncLog.setFileName(fileName);

        // 读取文本数据
        String content = BcxinFileUtil.txt2String(file);
        if (StringUtil.isNotEmpty(content)) {
            // 保存差异日志
            List<ChangeLog> changeLogList = JSON.parseArray(content, ChangeLog.class);
            for (ChangeLog changeLog : changeLogList) {
                changeLogService.deleteBySourceOid(changeLog.getSourceOid());
                changeLogService.save(changeLog);
            }
        }
        fileSyncLog.setMarkRead(DictConst.Y);
        logService.mergeMark(fileSyncLog);
        syncFileNameList.add(fileName);
    }

    /**
     * 保存升级日志
     *
     * @param syncFileNameList
     * @param file
     */
    public void saveUpgradeLog(List<String> syncFileNameList, File file) {
        String fileName = file.getName();
        System.out.println("fileName:" + fileName);
        FileSyncLog fileSyncLog = logService.findRecord(fileName);
        /*如果文件名存在，证明已经同步过，则不再同步*/
        if (fileSyncLog != null) {
            if (DictConst.Y.equals(fileSyncLog.getMarkRead())) {
                return;
            }
        }
        if (syncFileNameList.contains(fileName)) {
            return;
        }

        if (fileSyncLog == null) {
            fileSyncLog = new FileSyncLog();
        }
        fileSyncLog.setFileName(fileName);

        // 读取文本数据
        String upgradeContent = BcxinFileUtil.txt2String(file);
        if (StringUtil.isNotEmpty(upgradeContent)) {
            // 保存升级日志
            Map<String, String> map = JSON.parseObject(upgradeContent, new TypeReference<HashMap<String, String>>() {
            });
            String pssId = map.containsKey("pssId") ? map.get("pssId") : "";
            String title = map.containsKey("title") ? map.get("title") : "";
            String content = map.containsKey("content") ? map.get("content") : "";
            String deleteFlag = map.containsKey("deleteFlag") ? map.get("deleteFlag") : "";
            SystemUpgrade upgrade = null;
            boolean isUpdate = true;
            if (StringUtil.isNotEmpty(pssId)) {
                upgrade = upgradeService.findUpgradeByPssId(Long.parseLong(pssId));
            }
            if (upgrade == null) {
                upgrade = new SystemUpgrade();
                isUpdate = false;
            }

            // 赋值
            upgrade.setContent(content);
            upgrade.setTitle(title);
            if (StringUtil.isNotEmpty(pssId)) {
                upgrade.setPssId(Long.parseLong(pssId));
            }
            if (StringUtil.isNotEmpty(deleteFlag)) {
                upgrade.setDeleteFlag(Integer.parseInt(deleteFlag));
            }
            if (isUpdate) {
                upgrade.setUpdateTime(new Date());
                upgradeService.update(upgrade);
            } else {
                upgrade.setCreateTime(new Date());
                upgrade.setUpdateTime(new Date());
                upgradeService.insert(upgrade);
            }
        }
        fileSyncLog.setMarkRead(DictConst.Y);
        logService.mergeMark(fileSyncLog);
        syncFileNameList.add(fileName);
    }


    /**
     * 获取审批地区
     *
     * @param province
     * @param city
     * @param area
     * @return
     */
    private String getApproveArea(String province, String city, String area) {
        String addr = "";
        if (StringUtil.isNotEmpty(province)) {
            addr += regionMapper.findNameById(Long.parseLong(province));
        }
        if (StringUtil.isNotEmpty(city)) {
            addr += "-" + regionMapper.findNameById(Long.parseLong(city));
        }
        if (StringUtil.isNotEmpty(area)) {
            addr += "-" + regionMapper.findNameById(Long.parseLong(area));
        }
        return addr;
    }

}
