package com.bcxin.sp.work.util;

import javax.crypto.*;
import javax.crypto.spec.IvParameterSpec;
import javax.crypto.spec.SecretKeySpec;
import java.security.InvalidAlgorithmParameterException;
import java.security.InvalidKeyException;
import java.security.NoSuchAlgorithmException;

public class AESUtil {

	/**
	 * 注意key和加密用到的字符串是不一样的 加密还要指定填充的加密模式和填充模式 AES密钥可以是128或者256，加密模式包括ECB, CBC等
	 * ECB模式是分组的模式，CBC是分块加密后，每块与前一块的加密结果异或后再加密 第一块加密的明文是与IV变量进行异或
	 */
	public static final String KEY_ALGORITHM = "AES";
	public static final String ECB_CIPHER_ALGORITHM = "AES/ECB/PKCS5Padding";
	public static final String CBC_CIPHER_ALGORITHM = "AES/CBC/PKCS5Padding";
	public static final String PLAIN_TEXT = "测试内容";
	
	/**
     * IV(Initialization Value)是一个初始值，对于CBC模式来说，它必须是随机选取并且需要保密的
     * 而且它的长度和密码分组相同(比如：对于AES 128为128位，即长度为16的byte类型数组)
     * 
     */
    public static final byte[] IVPARAMETERS = new byte[] { 1, 2, 3, 4, 5, 6, 7,
            8, 9, 10, 11, 12, 13, 14, 15, 16 };
    
    public static void main(String[] arg) {
    	String key = "1231238798214234";
        
        byte[] encodedText = aesEcbEncode(PLAIN_TEXT.getBytes(), key);

        System.out.println("AES ECB decoded: "
                + new String(aesEcbDecode(encodedText, key)));
        
        encodedText = aesCbcEncode(PLAIN_TEXT.getBytes(), key, IVPARAMETERS);
        
        System.out.println("AES CBC decoded: "
                + new String(aesCbcDecode(encodedText, key,
                        IVPARAMETERS)));
    }

    
    
    /**
     * 使用ECB模式进行加密。 加密过程三步走： 1. 传入算法，实例化一个加解密器 2. 传入加密模式和密钥，初始化一个加密器 3.
     * 调用doFinal方法加密
     * 
     * @param plainText
     * @return
     */
    public static byte[] aesEcbEncode(byte[] plainText, String key) {
    	
        try {
        	SecretKey skey = restoreSecretKey(key.getBytes());
            Cipher cipher = Cipher.getInstance(ECB_CIPHER_ALGORITHM);
            cipher.init(Cipher.ENCRYPT_MODE, skey);
            return cipher.doFinal(plainText);
        } catch (NoSuchAlgorithmException | NoSuchPaddingException
                | InvalidKeyException | IllegalBlockSizeException
                | BadPaddingException e) {
            // TODO Auto-generated catch block
            e.printStackTrace();
        }
        return null;
    }

    /**
     * 使用ECB解密，三步走，不说了
     * @param decodedText
     * @param key
     * @return
     */
    public static byte[] aesEcbDecode(byte[] decodedText, String key) {
        try {
        	SecretKey skey = restoreSecretKey(key.getBytes());
            Cipher cipher = Cipher.getInstance(ECB_CIPHER_ALGORITHM);
            cipher.init(Cipher.DECRYPT_MODE, skey);
            return cipher.doFinal(decodedText);
        } catch (NoSuchAlgorithmException | NoSuchPaddingException
                | InvalidKeyException | IllegalBlockSizeException
                | BadPaddingException e) {
            // TODO Auto-generated catch block
            e.printStackTrace();
        }
        return null;

    }

    /**
     * CBC加密，三步走，只是在初始化时加了一个初始变量
     * 
     * @param plainText
     * @param key
     * @param IVParameter
     * @return
     */
    public static byte[] aesCbcEncode(byte[] plainText, String key,
            byte[] IVParameter) {
        try {
        	SecretKey skey = restoreSecretKey(key.getBytes());
            IvParameterSpec ivParameterSpec = new IvParameterSpec(IVParameter);
            Cipher cipher = Cipher.getInstance(CBC_CIPHER_ALGORITHM);
            cipher.init(Cipher.ENCRYPT_MODE, skey, ivParameterSpec);
            return cipher.doFinal(plainText);
        } catch (NoSuchAlgorithmException | NoSuchPaddingException
                | InvalidKeyException | InvalidAlgorithmParameterException
                | IllegalBlockSizeException | BadPaddingException e) {
            // TODO Auto-generated catch block
            e.printStackTrace();
        }
        return null;
    }

    /**
     * CBC 解密
     * 
     * @param decodedText
     * @param key
     * @param IVParameter
     * @return
     */
    public static byte[] aesCbcDecode(byte[] decodedText, String key,
            byte[] IVParameter) {
        IvParameterSpec ivParameterSpec = new IvParameterSpec(IVParameter);
        try {
        	SecretKey skey = restoreSecretKey(key.getBytes());
            Cipher cipher = Cipher.getInstance(CBC_CIPHER_ALGORITHM);
            cipher.init(Cipher.DECRYPT_MODE, skey, ivParameterSpec);
            return cipher.doFinal(decodedText);
        } catch (NoSuchAlgorithmException | NoSuchPaddingException
                | InvalidKeyException | InvalidAlgorithmParameterException
                | IllegalBlockSizeException | BadPaddingException e) {
            e.printStackTrace();
        }
        return null;
    }

    /**
     * 1.创建一个KeyGenerator 2.调用KeyGenerator.generateKey方法
     * 由于某些原因，这里只能是128，如果设置为256会报异常，原因在下面文字说明
     * @return
     */
    public static byte[] generateAESSecretKey() {
        KeyGenerator keyGenerator;
        try {
            keyGenerator = KeyGenerator.getInstance(KEY_ALGORITHM);
            // keyGenerator.init(256);
            return keyGenerator.generateKey().getEncoded();
        } catch (NoSuchAlgorithmException e) {
            // TODO Auto-generated catch block
            e.printStackTrace();
        }
        return null;
    }

    /**
     * 还原密钥
     * 
     * @param secretBytes
     * @return
     */
    public static SecretKey restoreSecretKey(byte[] secretBytes) {
        SecretKey secretKey = new SecretKeySpec(secretBytes, KEY_ALGORITHM);
        return secretKey;
    }

}
