package com.bcxin.sp.work.util;

import cn.hutool.core.date.DateUtil;
import cn.hutool.core.io.FileUtil;
import com.bcxin.sp.work.util.sys.ConfigUtil;
import com.google.common.io.Files;
import org.springframework.web.multipart.MultipartFile;

import javax.servlet.ServletOutputStream;
import javax.servlet.http.HttpServletResponse;
import java.io.*;
import java.text.SimpleDateFormat;
import java.util.Date;

/**
 * 文件处理类
 * @author Ethan_Huang
 */
public class BcxinFileUtil {

	/**
	 * 文件加时间戳的连接符
	 */
	private final static String TI = "_t_";
	
	/**
	 * 根据日期生成文件名字符串
	 * @return
	 */
	public static String generatingFileNameByDate(String fileName) {
		Date date = new Date();
		SimpleDateFormat sdf = new SimpleDateFormat("yyyyMMddHHmmss");
		String str = sdf.format(date);
		return fileName + "_" + str;
	}

	/**
	 * 获取文件名名，包括后缀名
	 * @param url
	 * @return
	 */
	public static String getFileName(String url) {
		if (url.isEmpty()) {
			return null;
		}
		/* 说明url进行了转码*/
		if (url.contains("%2F")) {
			url = url.replace("%2F","/");

		}
		return Files.getNameWithoutExtension(url) + "." + Files.getFileExtension(url);
	}

	/**
	 * 获取文件名后缀名
	 * @param fileName
	 * @return
	 */
	public static String getFileExtension(String fileName) {
		if (!fileName.isEmpty()) {
			return fileName.substring(fileName.lastIndexOf(".")+1);
		}
		return null;
	}

	/**
	 * 删除文件或文件夹
	 * @param filePath
	 */
	public static void deleteFolder(String filePath) {
		File file = new File(filePath);
		if(file.exists()) {
			if(file.isDirectory()) {
				for(File f : file.listFiles()) {
					deleteFolder(f.getAbsolutePath());
				}
				file.delete();
			} else {
				System.out.println(file.delete());
			}
		}
	}
	
	/**
	 * 递归删除文件
	 * @param folder
	 * @param d
	 */
	public static void deleteFile(File folder, Date d) {
		File[] files = folder.listFiles();
		for(File f : files) {
			if(f.isDirectory()) {
				deleteFile(f, d);
				if(f.list().length == 0) {
					f.delete();
				}
			} else {
				if(f.lastModified() < d.getTime()) {
					f.delete();
				}
			}
		}
	}
	
	/**
	 * 复制文件夹
	 */
	public static void copyFolder(File resFile, File objFolderFile) throws IOException { 
        if (!resFile.exists()) return; 
        if (!objFolderFile.exists()) objFolderFile.mkdirs(); 
        if (resFile.isFile()) { 
            File objFile = new File(objFolderFile.getPath() + File.separator + resFile.getName()); 
            //复制文件到目标地 
            InputStream ins = new FileInputStream(resFile); 
            FileOutputStream outs = new FileOutputStream(objFile); 
            byte[] buffer = new byte[1024 * 512]; 
            int length; 
            while ((length = ins.read(buffer)) != -1) { 
                outs.write(buffer, 0, length); 
            } 
            ins.close(); 
            outs.flush(); 
            outs.close(); 
        } else { 
            String objFolder = objFolderFile.getPath() + File.separator + resFile.getName(); 
            File _objFolderFile = new File(objFolder); 
            _objFolderFile.mkdirs(); 
            for (File sf : resFile.listFiles()) { 
            	copyFolder(sf, new File(objFolder)); 
            } 
        } 
	}
	
	/**
	 * 根据文件获取byte数组
	 * @param filePath
	 * @return
	 */
	public static byte[] getBytes(String filePath){  
        byte[] buffer = null;  
        try {  
            File file = new File(filePath);  
            FileInputStream fis = new FileInputStream(file);  
            ByteArrayOutputStream bos = new ByteArrayOutputStream(1000);  
            byte[] b = new byte[1000];  
            int n;  
            while ((n = fis.read(b)) != -1) {  
                bos.write(b, 0, n);  
            }  
            fis.close();  
            bos.close();  
            buffer = bos.toByteArray();  
        } catch (FileNotFoundException e) {  
            e.printStackTrace();  
        } catch (IOException e) {  
            e.printStackTrace();  
        }  
        return buffer;  
    }
	
	/**
	 /**
	 * 创建文件夹
	 * @param dir
	 */
	public static void mkDir(String dir){
		File fileDir = new File(dir);
		if(!fileDir.exists()) {
			fileDir.mkdirs();
		}
	}


	/**
	 * 处理文件夹路径
	 * @param paths
	 * @return
	 */
	public static String appendFolderPath(String[] paths){
		StringBuffer sb = new StringBuffer();
		for (String path:paths) {
			if (sb.length()==0) {
				sb.append(path);
			} else {
				if (sb.toString().endsWith("/")) {
					sb.append(path).append("/");
				} else {
					sb.append("/").append(path).append("/");
				}
			}
		}
		if (!FileUtil.isDirectory(sb.toString())) {
			FileUtil.mkdir(sb.toString());
		}
		return sb.toString();
	}

	/**
	 * 为文件名增加时间戳
	 * @return
	 */
	public static String packTimestamp(String fileName){
		if (StringUtil.isEmpty(fileName)) {
			return "";
		}
		if (fileName.contains(".")) {
			return Files.getNameWithoutExtension(fileName) + TI + BcxinDateUtil.getTimestamp() + Files.getFileExtension(fileName);
		} else {
			return fileName + TI + BcxinDateUtil.getTimestamp() ;
		}
	}

	/**
	 * 为文件名去掉时间戳
	 * 例如文件名：_acd_100021_t_20170101010101.txt
	 * 处理后：_acd_100021.txt
	 * @return
	 */
	public static String filterTimestamp(String fileName){
		if (StringUtil.isEmpty(fileName)) {
			return "";
		}
		if (fileName.contains("_t_")) {
			String fileType = Files.getFileExtension(fileName);
			String disposeFileName = fileName.substring(0,fileName.lastIndexOf("_t_"));
			return disposeFileName + "." + fileType;
		} else {
			return fileName;
		}
	}


	/**
	 * 根据文件路径下载文件
	 * @param response
	 * @param filePath
	 * @param reName
	 */
	public void downloadFile(HttpServletResponse response, String filePath , String reName) {
		try {
			File file = new File(filePath);
			String fileName = file.getName();
			if (StringUtil.isNotEmpty(reName)) {
				fileName = reName;
			}
			if (file != null) {
				ServletOutputStream out = response.getOutputStream();
				response.addHeader("Content-Disposition", "attachment;filename=" + fileName);
				response.setContentLengthLong(file.length());
				InputStream is = new FileInputStream(file);
				int read = 0;
				byte[] buffer = new byte[8192];
				while ((read = is.read(buffer)) != -1) {
					out.write(buffer, 0, read);
				}
				is.close();
				out.flush();
				out.close();
			}
		} catch (Exception e){
			e.printStackTrace();
		}
	}



	/**
	 * <b>Function </b> 本地文件存储
	 * @author LuoPeng
	 * <b>
	 */
	public static String saveFile(MultipartFile multipartFile) {
		if ( multipartFile != null ) {
			if (StringUtil.isNotEmpty(multipartFile.getOriginalFilename())) {
				try {
					Date now = new Date();
					String materialFileName = now.getTime() + StringUtil.randomString(5) + ".";
					String fileType = Files.getFileExtension(multipartFile.getOriginalFilename());
					materialFileName = materialFileName + fileType;
					String dirDate = DateUtil.today();
					File dir = new File(ConfigUtil.getValue("stuff-path") + dirDate);
					if(!dir.exists()) {
						dir.mkdirs();
					}
					String url = "/getResource?path=" + dir.getPath() + "/" + materialFileName;
					String targetPath = ConfigUtil.getValue("stuff-path") + dirDate + "/" + materialFileName;
					File targetFile = new File(targetPath);
					multipartFile.transferTo(targetFile);
					return url;
				} catch(Exception e) {
					e.printStackTrace();
					return null;
				}
			}
		}
		return null;
	}


	/**
	 * 读取文本
	 *
	 * @param file
	 */
	public static String txt2String(File file) {
		StringBuilder result = new StringBuilder();
		try {
			//构造一个BufferedReader类来读取文件
			InputStreamReader isr = new InputStreamReader(new FileInputStream(file), "UTF-8");
			BufferedReader read = new BufferedReader(isr);
			String s = null;
			//使用readLine方法，一次读一行
			while ((s = read.readLine()) != null) {
				result.append(System.lineSeparator() + s);
			}
			read.close();
		} catch (Exception e) {
			e.printStackTrace();
		}
		return result.toString();
	}

	public static void main(String[] args) {
		System.out.println(txt2String(new File("C:\\Users\\PVer\\Desktop\\_acd_1167_t_20201009160111709.txt")));
	}

}