package com.bcxin.sp.work.util;

import com.google.common.collect.Maps;
import org.apache.commons.lang.StringUtils;

import javax.servlet.http.HttpServletRequest;
import java.net.InetAddress;
import java.net.UnknownHostException;
import java.util.*;

public class WebUtil {
	

    /**
     * 取得request中所有的参数名
     *
     * @param request
     * @return
     */
    @SuppressWarnings("unchecked")
    public static List<String> getRequestParamNames(HttpServletRequest request) {

        Enumeration<String> paramNameEnum = request.getParameterNames();
        List<String> result = new ArrayList<String>();

        //先将Enumeration中参数转成LIST
        while (paramNameEnum.hasMoreElements()) {
            result.add(paramNameEnum.nextElement().trim());
        }

        return result;
    }

    /**
     * 取得请求中的所有参数的键值对
     * add by chenmk 2009.12.25
     *
     * @param request
     * @return
     */
    public static Map<String, String> getParameterMap(HttpServletRequest request) {
        List<String> paramNameList = getRequestParamNames(request);

        Map<String, String> result = Maps.newHashMap();

        if (paramNameList == null || paramNameList.size() == 0) {
            return result;
        }

        for(String paramName : paramNameList){
            result.put(paramName, request.getParameter(paramName));
        }

        return result;
    }


    /** 获取客户端IP */
    public static final String getIP(HttpServletRequest request) {
        if(request==null){
            return "";
        }
        String ip = request.getHeader("X-Forwarded-For");
        if (StringUtils.isBlank(ip) || "unknown".equalsIgnoreCase(ip)) {
            ip = request.getHeader("Proxy-Client-IP");
        }
        if (StringUtils.isBlank(ip) || "unknown".equalsIgnoreCase(ip)) {
            ip = request.getHeader("WL-Proxy-Client-IP");
        }
        if (StringUtils.isBlank(ip) || "unknown".equalsIgnoreCase(ip)) {
            ip = request.getHeader("X-Real-IP");
        }
        if (StringUtils.isBlank(ip) || "unknown".equalsIgnoreCase(ip)) {
            ip = request.getRemoteAddr();
        }
        if ("127.0.0.1".equals(ip)) {
            InetAddress inet = null;
            try { // 根据网卡取本机配置的IP
                inet = InetAddress.getLocalHost();
            } catch (UnknownHostException e) {
                e.printStackTrace();
            }
            ip = inet.getHostAddress();
        }
        // 对于通过多个代理的情况，第一个IP为客户端真实IP,多个IP按照','分割
        if (ip != null && ip.length() > 15) {
            if (ip.indexOf(",") > 0) {
                ip = ip.substring(0, ip.indexOf(","));
            }
        }
        return ip;
    }

    /**
     * 是否是Ajax异步请求
     */
    public static boolean isAjaxRequest(HttpServletRequest request){
        String accept = request.getHeader("accept");
        if (accept != null && accept.indexOf("application/json") != -1)
        {
            return true;
        }

        String xRequestedWith = request.getHeader("X-Requested-With");
        if (xRequestedWith != null && xRequestedWith.indexOf("XMLHttpRequest") != -1)
        {
            return true;
        }
        return false;
    }



}
